# testops_api.TestProjectApi

All URIs are relative to *http://localhost:8443*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create1**](TestProjectApi.md#create1) | **POST** /api/v1/test-projects/{id}/schedulers | Creates a new schedule for a Test Plan. Returns the created schedule detail.
[**create_git_repo**](TestProjectApi.md#create_git_repo) | **POST** /api/v1/git/create | Creates a Git Test Project. Returns the Git Test Project detail.
[**create_sample**](TestProjectApi.md#create_sample) | **POST** /api/v1/test-projects/sample | Creates a new sample Test Project. Returns the created Test Project.
[**create_sample_git_test_project**](TestProjectApi.md#create_sample_git_test_project) | **POST** /api/v1/test-projects/sample-git-test-project | Creates a new sample Git Test Project when setting up a Git Repository. Returns the created Sample Git Test Project.
[**delete**](TestProjectApi.md#delete) | **DELETE** /api/v1/test-projects/{id} | Deletes a Test Project. Returns the deleted Test Project.
[**delete1**](TestProjectApi.md#delete1) | **DELETE** /api/v1/test-projects/{id}/schedulers/{schedulerId} | Deletes a schedule. Returns the deleted schedule detail.
[**download**](TestProjectApi.md#download) | **GET** /api/v1/test-projects/{id}/download | Downloads a Test Project package. Returns the latest Test Project package file.
[**get3**](TestProjectApi.md#get3) | **GET** /api/v1/test-projects/{id} | Returns a Test Project detail.
[**get_default_test_project**](TestProjectApi.md#get_default_test_project) | **GET** /api/v1/test-projects/default | Get default Test Project of a Project. Returns Test Project resource if exist.
[**get_scheduler**](TestProjectApi.md#get_scheduler) | **GET** /api/v1/test-projects/{id}/schedulers/{schedulerId} | Returns a schedule detail.
[**get_test_project_git**](TestProjectApi.md#get_test_project_git) | **GET** /api/v1/git/{testProjectGitId} | Returns a Git Test Project detail.
[**refresh_tsc**](TestProjectApi.md#refresh_tsc) | **POST** /api/v1/test-projects/{id}/refresh-tsc | Refresh Test Suite Collection list of Git Test Project
[**run**](TestProjectApi.md#run) | **PUT** /api/v1/run-configurations/{id}/execute | Executes a Test Plan. Returns the build information.
[**update**](TestProjectApi.md#update) | **PUT** /api/v1/test-projects/{id} | Updates a Test Project detail. Returns the updated Test Project detail.
[**update1**](TestProjectApi.md#update1) | **PUT** /api/v1/test-projects/{id}/schedulers/{schedulerId} | Updates a schedule detail. Returns the updated schedule detail.
[**update_git_repo**](TestProjectApi.md#update_git_repo) | **POST** /api/v1/git/update | Updates a Git Test Project detail. Returns the updated Git Test Project detail.
[**update_script_repo**](TestProjectApi.md#update_script_repo) | **POST** /api/v1/test-projects/{id}/update-script-repo | Update a Test Project package. Returns the updated Test Project detail. Use to update script repository
[**upload_script_repo**](TestProjectApi.md#upload_script_repo) | **POST** /api/v1/test-projects/upload-script-repo | Creates a new Test Project. Returns the created Test Project. Use to create script repository


# **create1**
> SchedulerResource create1(id, scheduler_resource)

Creates a new schedule for a Test Plan. Returns the created schedule detail.

### Example

* Basic Authentication (basicScheme):
```python
import time
import testops_api
from testops_api.api import test_project_api
from testops_api.model.scheduler_resource import SchedulerResource
from pprint import pprint
# Defining the host is optional and defaults to http://localhost:8443
# See configuration.py for a list of all supported configuration parameters.
configuration = testops_api.Configuration(
    host = "http://localhost:8443"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicScheme
configuration = testops_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Enter a context with an instance of the API client
with testops_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = test_project_api.TestProjectApi(api_client)
    id = 1 # int | 
    scheduler_resource = SchedulerResource(
        id=1,
        name="name_example",
        start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
        next_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
        end_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
        active=True,
        interval=1,
        interval_unit="MINUTE",
        run_configuration_id=1,
        run_configuration=RunConfigurationResource(
            id=1,
            name="name_example",
            command="command_example",
            project_id=1,
            team_id=1,
            test_project_id=1,
            release_id=1,
            test_suite_collection_id=1,
            test_suite_id=1,
            execution_profile_id=1,
            baseline_collection_group_order=1,
            time_out=1,
            kobiton_device_id="kobiton_device_id_example",
            config_type="TSC",
            test_project=TestProjectResource(
                id=1,
                name="name_example",
                description="description_example",
                default_test_project=True,
                upload_file_id=1,
                project_id=1,
                team_id=1,
                created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                latest_job=JobResource(
                    id=1,
                    build_number=1,
                    status="QUEUED",
                    queued_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    stop_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    test_project=TestProjectResource(TestProjectResource),
                    execution=ExecutionResource(
                        status="PASSED",
                        start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        end_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        duration=1,
                        elapsed_duration=1,
                        total_tests=1,
                        total_passed_tests=1,
                        total_failed_tests=1,
                        total_error_tests=1,
                        total_incomplete_tests=1,
                        total_skipped_tests=1,
                        total_diff_tests=1,
                        total_diff_passed_tests=1,
                        total_diff_failed_tests=1,
                        total_diff_error_tests=1,
                        total_diff_incomplete_tests=1,
                        id=1,
                        project_id=1,
                        project=ProjectResource(
                            id=1,
                            name="name_example",
                            team_id=1,
                            team=TeamResource(
                                id=1,
                                name="name_example",
                                role="OWNER",
                                users=[
                                    UserResource(
                                        id=1,
                                        email="email_example",
                                        first_name="first_name_example",
                                        last_name="last_name_example",
                                        password="password_example",
                                        inviting_url="inviting_url_example",
                                        avatar="avatar_example",
                                        configs=ConfigResource(
                                            web_socket_url="web_socket_url_example",
                                            store_url="store_url_example",
                                            profiles=[
                                                "profiles_example",
                                            ],
                                            stripe_public_api="stripe_public_api_example",
                                            build_version="build_version_example",
                                            commit_id="commit_id_example",
                                            sentry_dsn="sentry_dsn_example",
                                            sentry_env="sentry_env_example",
                                            sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                                            server_url="server_url_example",
                                            io_server_url="io_server_url_example",
                                            proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                                            max_execution_comparison=1,
                                            max_execution_download=1,
                                            agent_download_urls={
                                                "key": "key_example",
                                            },
                                            proxy_tunnel_download_urls={
                                                "key": "key_example",
                                            },
                                            report_uploader_download_url="report_uploader_download_url_example",
                                            report_uploader_latest_version="report_uploader_latest_version_example",
                                            sub_domain_pattern="sub_domain_pattern_example",
                                            cancellation_survey_url="cancellation_survey_url_example",
                                            launch_darkly_client_id="launch_darkly_client_id_example",
                                            launch_darkly_default_user="launch_darkly_default_user_example",
                                            launch_darkly_prefix="launch_darkly_prefix_example",
                                            min_test_execution_ordered=1,
                                            user_flow_token="user_flow_token_example",
                                            demo_project_url="demo_project_url_example",
                                            advanced_feature_enabled=True,
                                            using_sub_domain=True,
                                            test_ops_subscription_enabled=True,
                                            frameworks_integration_enabled=True,
                                        ),
                                        projects=[
                                            ProjectResource(ProjectResource),
                                        ],
                                        teams=[
                                            TeamResource(TeamResource),
                                        ],
                                        organizations=[
                                            OrganizationResource(
                                                id=1,
                                                name="name_example",
                                                role="OWNER",
                                                org_feature_flag=OrganizationFeatureFlagResource(
                                                    organization_id=1,
                                                    sub_domain=True,
                                                    strict_domain=True,
                                                    sso=True,
                                                    whitelist_ip=True,
                                                    circle_ci=True,
                                                    test_ops_integration=True,
                                                ),
                                                quota_kse=1,
                                                machine_quota_kse=1,
                                                quota_unlimited_kse=1,
                                                quota_engine=1,
                                                machine_quota_engine=1,
                                                quota_unlimited_engine=1,
                                                used_kse=1,
                                                used_unlimited_kse=1,
                                                used_engine=1,
                                                used_unlimited_engine=1,
                                                quota_test_ops=1,
                                                used_test_ops=1,
                                                number_user=1,
                                                quota_floating_engine=1,
                                                used_floating_engine=1,
                                                can_create_offline_kse=True,
                                                can_create_offline_unlimited_kse=True,
                                                can_create_offline_re=True,
                                                can_create_offline_unlimited_engine=True,
                                                subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscribed=True,
                                                kse_paygo=True,
                                                kre_paygo=True,
                                                paygo_quota=1,
                                                domain="domain_example",
                                                subdomain_url="subdomain_url_example",
                                                strict_domain=True,
                                                logo_url="logo_url_example",
                                                saml_sso=True,
                                                kre_license=True,
                                                most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                account_id=1,
                                                test_ops_feature="KSE",
                                                platform_feature="KSE",
                                                tier="FREE",
                                                requested_user_verified=True,
                                            ),
                                        ],
                                        organization_feature=[
                                            UserOrganizationFeatureResource(
                                                user=UserResource(UserResource),
                                                user_id=1,
                                                organization_id=1,
                                                user_email="user_email_example",
                                                organization=OrganizationResource(
                                                    id=1,
                                                    name="name_example",
                                                    role="OWNER",
                                                    org_feature_flag=OrganizationFeatureFlagResource(
                                                        organization_id=1,
                                                        sub_domain=True,
                                                        strict_domain=True,
                                                        sso=True,
                                                        whitelist_ip=True,
                                                        circle_ci=True,
                                                        test_ops_integration=True,
                                                    ),
                                                    quota_kse=1,
                                                    machine_quota_kse=1,
                                                    quota_unlimited_kse=1,
                                                    quota_engine=1,
                                                    machine_quota_engine=1,
                                                    quota_unlimited_engine=1,
                                                    used_kse=1,
                                                    used_unlimited_kse=1,
                                                    used_engine=1,
                                                    used_unlimited_engine=1,
                                                    quota_test_ops=1,
                                                    used_test_ops=1,
                                                    number_user=1,
                                                    quota_floating_engine=1,
                                                    used_floating_engine=1,
                                                    can_create_offline_kse=True,
                                                    can_create_offline_unlimited_kse=True,
                                                    can_create_offline_re=True,
                                                    can_create_offline_unlimited_engine=True,
                                                    subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    subscribed=True,
                                                    kse_paygo=True,
                                                    kre_paygo=True,
                                                    paygo_quota=1,
                                                    domain="domain_example",
                                                    subdomain_url="subdomain_url_example",
                                                    strict_domain=True,
                                                    logo_url="logo_url_example",
                                                    saml_sso=True,
                                                    kre_license=True,
                                                    most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    account_id=1,
                                                    test_ops_feature="KSE",
                                                    platform_feature="KSE",
                                                    tier="FREE",
                                                    requested_user_verified=True,
                                                ),
                                                feature="KSE",
                                            ),
                                        ],
                                        trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        system_role="USER",
                                        survey_status="NOT_SUBMITTED",
                                        session_timeout=1,
                                        business_user=True,
                                        can_create_offline_kse=True,
                                        can_create_offline_re=True,
                                        saml_sso=True,
                                        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        full_name="full_name_example",
                                    ),
                                ],
                                organization=OrganizationResource(
                                    id=1,
                                    name="name_example",
                                    role="OWNER",
                                    org_feature_flag=OrganizationFeatureFlagResource(
                                        organization_id=1,
                                        sub_domain=True,
                                        strict_domain=True,
                                        sso=True,
                                        whitelist_ip=True,
                                        circle_ci=True,
                                        test_ops_integration=True,
                                    ),
                                    quota_kse=1,
                                    machine_quota_kse=1,
                                    quota_unlimited_kse=1,
                                    quota_engine=1,
                                    machine_quota_engine=1,
                                    quota_unlimited_engine=1,
                                    used_kse=1,
                                    used_unlimited_kse=1,
                                    used_engine=1,
                                    used_unlimited_engine=1,
                                    quota_test_ops=1,
                                    used_test_ops=1,
                                    number_user=1,
                                    quota_floating_engine=1,
                                    used_floating_engine=1,
                                    can_create_offline_kse=True,
                                    can_create_offline_unlimited_kse=True,
                                    can_create_offline_re=True,
                                    can_create_offline_unlimited_engine=True,
                                    subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscribed=True,
                                    kse_paygo=True,
                                    kre_paygo=True,
                                    paygo_quota=1,
                                    domain="domain_example",
                                    subdomain_url="subdomain_url_example",
                                    strict_domain=True,
                                    logo_url="logo_url_example",
                                    saml_sso=True,
                                    kre_license=True,
                                    most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    account_id=1,
                                    test_ops_feature="KSE",
                                    platform_feature="KSE",
                                    tier="FREE",
                                    requested_user_verified=True,
                                ),
                                organization_id=1,
                            ),
                            timezone="timezone_example",
                            status="ARCHIVE",
                        ),
                        build_id=1,
                        order=1,
                        execution_stage="RUNNING",
                        web_url="web_url_example",
                        test_suite_collections=[
                            TestSuiteCollectionEntityResource(
                                id=1,
                                name="name_example",
                                project=ProjectResource(
                                    id=1,
                                    name="name_example",
                                    team_id=1,
                                    team=TeamResource(
                                        id=1,
                                        name="name_example",
                                        role="OWNER",
                                        users=[],
                                        organization=OrganizationResource(
                                            id=1,
                                            name="name_example",
                                            role="OWNER",
                                            org_feature_flag=OrganizationFeatureFlagResource(
                                                organization_id=1,
                                                sub_domain=True,
                                                strict_domain=True,
                                                sso=True,
                                                whitelist_ip=True,
                                                circle_ci=True,
                                                test_ops_integration=True,
                                            ),
                                            quota_kse=1,
                                            machine_quota_kse=1,
                                            quota_unlimited_kse=1,
                                            quota_engine=1,
                                            machine_quota_engine=1,
                                            quota_unlimited_engine=1,
                                            used_kse=1,
                                            used_unlimited_kse=1,
                                            used_engine=1,
                                            used_unlimited_engine=1,
                                            quota_test_ops=1,
                                            used_test_ops=1,
                                            number_user=1,
                                            quota_floating_engine=1,
                                            used_floating_engine=1,
                                            can_create_offline_kse=True,
                                            can_create_offline_unlimited_kse=True,
                                            can_create_offline_re=True,
                                            can_create_offline_unlimited_engine=True,
                                            subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            subscribed=True,
                                            kse_paygo=True,
                                            kre_paygo=True,
                                            paygo_quota=1,
                                            domain="domain_example",
                                            subdomain_url="subdomain_url_example",
                                            strict_domain=True,
                                            logo_url="logo_url_example",
                                            saml_sso=True,
                                            kre_license=True,
                                            most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            account_id=1,
                                            test_ops_feature="KSE",
                                            platform_feature="KSE",
                                            tier="FREE",
                                            requested_user_verified=True,
                                        ),
                                        organization_id=1,
                                    ),
                                    timezone="timezone_example",
                                    status="ARCHIVE",
                                ),
                                path="path_example",
                                url_id="url_id_example",
                            ),
                        ],
                        execution_test_suite_resources=[
                            ExecutionTestSuiteResource(
                                status="PASSED",
                                start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                end_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                duration=1,
                                elapsed_duration=1,
                                total_tests=1,
                                total_passed_tests=1,
                                total_failed_tests=1,
                                total_error_tests=1,
                                total_incomplete_tests=1,
                                total_skipped_tests=1,
                                total_diff_tests=1,
                                total_diff_passed_tests=1,
                                total_diff_failed_tests=1,
                                total_diff_error_tests=1,
                                total_diff_incomplete_tests=1,
                                id=1,
                                execution=ExecutionResource(ExecutionResource),
                                test_suite=TestSuiteResource(
                                    id=1,
                                    name="name_example",
                                    path="path_example",
                                    test_results=[
                                        ExecutionTestResultResource(
                                            id=1,
                                            test_case=TestCaseResource(
                                                id=1,
                                                name="name_example",
                                                path="path_example",
                                                previous_status="PASSED",
                                                alias="alias_example",
                                                test_module_id=1,
                                                web_url="web_url_example",
                                                description="description_example",
                                                project=ProjectResource(
                                                    id=1,
                                                    name="name_example",
                                                    team_id=1,
                                                    team=TeamResource(
                                                        id=1,
                                                        name="name_example",
                                                        role="OWNER",
                                                        users=[],
                                                        organization=OrganizationResource(
                                                            id=1,
                                                            name="name_example",
                                                            role="OWNER",
                                                            org_feature_flag=OrganizationFeatureFlagResource(
                                                                organization_id=1,
                                                                sub_domain=True,
                                                                strict_domain=True,
                                                                sso=True,
                                                                whitelist_ip=True,
                                                                circle_ci=True,
                                                                test_ops_integration=True,
                                                            ),
                                                            quota_kse=1,
                                                            machine_quota_kse=1,
                                                            quota_unlimited_kse=1,
                                                            quota_engine=1,
                                                            machine_quota_engine=1,
                                                            quota_unlimited_engine=1,
                                                            used_kse=1,
                                                            used_unlimited_kse=1,
                                                            used_engine=1,
                                                            used_unlimited_engine=1,
                                                            quota_test_ops=1,
                                                            used_test_ops=1,
                                                            number_user=1,
                                                            quota_floating_engine=1,
                                                            used_floating_engine=1,
                                                            can_create_offline_kse=True,
                                                            can_create_offline_unlimited_kse=True,
                                                            can_create_offline_re=True,
                                                            can_create_offline_unlimited_engine=True,
                                                            subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                            subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                            subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                            subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                            subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                            subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                            subscribed=True,
                                                            kse_paygo=True,
                                                            kre_paygo=True,
                                                            paygo_quota=1,
                                                            domain="domain_example",
                                                            subdomain_url="subdomain_url_example",
                                                            strict_domain=True,
                                                            logo_url="logo_url_example",
                                                            saml_sso=True,
                                                            kre_license=True,
                                                            most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                            account_id=1,
                                                            test_ops_feature="KSE",
                                                            platform_feature="KSE",
                                                            tier="FREE",
                                                            requested_user_verified=True,
                                                        ),
                                                        organization_id=1,
                                                    ),
                                                    timezone="timezone_example",
                                                    status="ARCHIVE",
                                                ),
                                                last_execution_test_case=ExecutionTestCaseResource(
                                                    status="PASSED",
                                                    start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    end_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    duration=1,
                                                    elapsed_duration=1,
                                                    total_tests=1,
                                                    total_passed_tests=1,
                                                    total_failed_tests=1,
                                                    total_error_tests=1,
                                                    total_incomplete_tests=1,
                                                    total_skipped_tests=1,
                                                    total_diff_tests=1,
                                                    total_diff_passed_tests=1,
                                                    total_diff_failed_tests=1,
                                                    total_diff_error_tests=1,
                                                    total_diff_incomplete_tests=1,
                                                    execution_id=1,
                                                    execution_order=1,
                                                    test_case_id=1,
                                                    project_id=1,
                                                ),
                                                external_issues=[
                                                    ExternalIssueResource(
                                                        id=1,
                                                        issue_id="issue_id_example",
                                                        summary="summary_example",
                                                        status="status_example",
                                                        issue_type_icon="issue_type_icon_example",
                                                        issue_type_name="issue_type_name_example",
                                                        url="url_example",
                                                        feature_name="feature_name_example",
                                                        test_cases=[
                                                            TestCaseResource(TestCaseResource),
                                                        ],
                                                    ),
                                                ],
                                                custom_field_options=[
                                                    CustomFieldOptionResource(
                                                        id=1,
                                                        value="value_example",
                                                        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                        definition_id=1,
                                                    ),
                                                ],
                                                type="TEST_CASE",
                                                average_duration=3.14,
                                                max_duration=1,
                                                min_duration=1,
                                                flakiness=3.14,
                                                platform_statistics={
                                                    "key": TestCasePlatformStatisticsResource(
                                                        total_tests=1,
                                                        total_passed_tests=1,
                                                        total_failed_tests=1,
                                                        total_error_tests=1,
                                                        total_incomplete_tests=1,
                                                        total_skipped_tests=1,
                                                        platform=PlatformResource(
                                                            id=1,
                                                            os_name="os_name_example",
                                                            os_version="os_version_example",
                                                            browser_name="browser_name_example",
                                                            browser_version="browser_version_example",
                                                            device_name="device_name_example",
                                                            app_name="app_name_example",
                                                        ),
                                                        platform_id=1,
                                                    ),
                                                },
                                                maintainer=UserResource(
                                                    id=1,
                                                    email="email_example",
                                                    first_name="first_name_example",
                                                    last_name="last_name_example",
                                                    password="password_example",
                                                    inviting_url="inviting_url_example",
                                                    avatar="avatar_example",
                                                    configs=ConfigResource(
                                                        web_socket_url="web_socket_url_example",
                                                        store_url="store_url_example",
                                                        profiles=[],
                                                        stripe_public_api="stripe_public_api_example",
                                                        build_version="build_version_example",
                                                        commit_id="commit_id_example",
                                                        sentry_dsn="sentry_dsn_example",
                                                        sentry_env="sentry_env_example",
                                                        sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                                                        server_url="server_url_example",
                                                        io_server_url="io_server_url_example",
                                                        proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                                                        max_execution_comparison=1,
                                                        max_execution_download=1,
                                                        agent_download_urls={},
                                                        proxy_tunnel_download_urls={},
                                                        report_uploader_download_url="report_uploader_download_url_example",
                                                        report_uploader_latest_version="report_uploader_latest_version_example",
                                                        sub_domain_pattern="sub_domain_pattern_example",
                                                        cancellation_survey_url="cancellation_survey_url_example",
                                                        launch_darkly_client_id="launch_darkly_client_id_example",
                                                        launch_darkly_default_user="launch_darkly_default_user_example",
                                                        launch_darkly_prefix="launch_darkly_prefix_example",
                                                        min_test_execution_ordered=1,
                                                        user_flow_token="user_flow_token_example",
                                                        demo_project_url="demo_project_url_example",
                                                        advanced_feature_enabled=True,
                                                        using_sub_domain=True,
                                                        test_ops_subscription_enabled=True,
                                                        frameworks_integration_enabled=True,
                                                    ),
                                                    projects=[],
                                                    teams=[],
                                                    organizations=[],
                                                    organization_feature=[],
                                                    trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    system_role="USER",
                                                    survey_status="NOT_SUBMITTED",
                                                    session_timeout=1,
                                                    business_user=True,
                                                    can_create_offline_kse=True,
                                                    can_create_offline_re=True,
                                                    saml_sso=True,
                                                    created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    full_name="full_name_example",
                                                ),
                                                test_result_assertion=TestResultAssertionResource(
                                                    execution_test_result_id=1,
                                                    execution_test_result=ExecutionTestResultResource(ExecutionTestResultResource),
                                                    total_assertion=1,
                                                    passed_assertion=1,
                                                    failed_assertion=1,
                                                ),
                                                updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                test_project=TestProjectResource(TestProjectResource),
                                                number_of_executions=1,
                                                url_id="url_id_example",
                                            ),
                                            execution=ExecutionResource(ExecutionResource),
                                            platform=PlatformResource(
                                                id=1,
                                                os_name="os_name_example",
                                                os_version="os_version_example",
                                                browser_name="browser_name_example",
                                                browser_version="browser_version_example",
                                                device_name="device_name_example",
                                                app_name="app_name_example",
                                            ),
                                            status="PASSED",
                                            same_status_period=1,
                                            error_details_id=1,
                                            stdout_id=1,
                                            description_id=1,
                                            log_id=1,
                                            attachments=[
                                                FileResource(
                                                    id=1,
                                                    upload_file_id=1,
                                                    _self="_self_example",
                                                    name="name_example",
                                                    path="path_example",
                                                    url="url_example",
                                                    hash="hash_example",
                                                    size=1,
                                                    upload_url="upload_url_example",
                                                    signed_url="signed_url_example",
                                                    thumbnail_url="thumbnail_url_example",
                                                ),
                                            ],
                                            test_result_assertions_failed=[
                                                TestResultAssertionFailedResource(
                                                    id=1,
                                                    execution_test_result_id=1,
                                                    execution_test_result_resource=ExecutionTestResultResource(ExecutionTestResultResource),
                                                    stacktrace="stacktrace_example",
                                                    message="message_example",
                                                    log_time="log_time_example",
                                                ),
                                            ],
                                            start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            end_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            duration=1,
                                            same_failure_results=[
                                                ExecutionTestResultIdentifyResource(
                                                    id=1,
                                                    execution_id=1,
                                                    url_id="url_id_example",
                                                ),
                                            ],
                                            test_suite=TestSuiteResource(TestSuiteResource),
                                            execution_test_suite=ExecutionTestSuiteResource(ExecutionTestSuiteResource),
                                            incidents=[
                                                IncidentResource(
                                                    id=1,
                                                    name="name_example",
                                                    description="description_example",
                                                    project_id=1,
                                                    team_id=1,
                                                    url_ids=[
                                                        "url_ids_example",
                                                    ],
                                                    execution_test_result_ids=[
                                                        1,
                                                    ],
                                                    order=1,
                                                    created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                ),
                                            ],
                                            profile="profile_example",
                                            has_comment=True,
                                            error_message="error_message_example",
                                            error_detail="error_detail_example",
                                            web_url="web_url_example",
                                            external_issues=[],
                                            failed_test_result_category="APPLICATION",
                                            total_test_object=1,
                                            total_defects=1,
                                            total_assertion=1,
                                            passed_assertion=1,
                                            failed_assertion=1,
                                            retried=True,
                                            last_retry_test_id=1,
                                            current_retry=1,
                                            original_status="PASSED",
                                            last_changed_by=UserResource(
                                                id=1,
                                                email="email_example",
                                                first_name="first_name_example",
                                                last_name="last_name_example",
                                                password="password_example",
                                                inviting_url="inviting_url_example",
                                                avatar="avatar_example",
                                                configs=ConfigResource(
                                                    web_socket_url="web_socket_url_example",
                                                    store_url="store_url_example",
                                                    profiles=[],
                                                    stripe_public_api="stripe_public_api_example",
                                                    build_version="build_version_example",
                                                    commit_id="commit_id_example",
                                                    sentry_dsn="sentry_dsn_example",
                                                    sentry_env="sentry_env_example",
                                                    sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                                                    server_url="server_url_example",
                                                    io_server_url="io_server_url_example",
                                                    proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                                                    max_execution_comparison=1,
                                                    max_execution_download=1,
                                                    agent_download_urls={},
                                                    proxy_tunnel_download_urls={},
                                                    report_uploader_download_url="report_uploader_download_url_example",
                                                    report_uploader_latest_version="report_uploader_latest_version_example",
                                                    sub_domain_pattern="sub_domain_pattern_example",
                                                    cancellation_survey_url="cancellation_survey_url_example",
                                                    launch_darkly_client_id="launch_darkly_client_id_example",
                                                    launch_darkly_default_user="launch_darkly_default_user_example",
                                                    launch_darkly_prefix="launch_darkly_prefix_example",
                                                    min_test_execution_ordered=1,
                                                    user_flow_token="user_flow_token_example",
                                                    demo_project_url="demo_project_url_example",
                                                    advanced_feature_enabled=True,
                                                    using_sub_domain=True,
                                                    test_ops_subscription_enabled=True,
                                                    frameworks_integration_enabled=True,
                                                ),
                                                projects=[],
                                                teams=[],
                                                organizations=[],
                                                organization_feature=[],
                                                trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                system_role="USER",
                                                survey_status="NOT_SUBMITTED",
                                                session_timeout=1,
                                                business_user=True,
                                                can_create_offline_kse=True,
                                                can_create_offline_re=True,
                                                saml_sso=True,
                                                created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                full_name="full_name_example",
                                            ),
                                            error_keyword="error_keyword_example",
                                            status_edited=True,
                                            url_id="url_id_example",
                                        ),
                                    ],
                                    project=ProjectResource(
                                        id=1,
                                        name="name_example",
                                        team_id=1,
                                        team=TeamResource(
                                            id=1,
                                            name="name_example",
                                            role="OWNER",
                                            users=[],
                                            organization=OrganizationResource(
                                                id=1,
                                                name="name_example",
                                                role="OWNER",
                                                org_feature_flag=OrganizationFeatureFlagResource(
                                                    organization_id=1,
                                                    sub_domain=True,
                                                    strict_domain=True,
                                                    sso=True,
                                                    whitelist_ip=True,
                                                    circle_ci=True,
                                                    test_ops_integration=True,
                                                ),
                                                quota_kse=1,
                                                machine_quota_kse=1,
                                                quota_unlimited_kse=1,
                                                quota_engine=1,
                                                machine_quota_engine=1,
                                                quota_unlimited_engine=1,
                                                used_kse=1,
                                                used_unlimited_kse=1,
                                                used_engine=1,
                                                used_unlimited_engine=1,
                                                quota_test_ops=1,
                                                used_test_ops=1,
                                                number_user=1,
                                                quota_floating_engine=1,
                                                used_floating_engine=1,
                                                can_create_offline_kse=True,
                                                can_create_offline_unlimited_kse=True,
                                                can_create_offline_re=True,
                                                can_create_offline_unlimited_engine=True,
                                                subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscribed=True,
                                                kse_paygo=True,
                                                kre_paygo=True,
                                                paygo_quota=1,
                                                domain="domain_example",
                                                subdomain_url="subdomain_url_example",
                                                strict_domain=True,
                                                logo_url="logo_url_example",
                                                saml_sso=True,
                                                kre_license=True,
                                                most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                account_id=1,
                                                test_ops_feature="KSE",
                                                platform_feature="KSE",
                                                tier="FREE",
                                                requested_user_verified=True,
                                            ),
                                            organization_id=1,
                                        ),
                                        timezone="timezone_example",
                                        status="ARCHIVE",
                                    ),
                                    alias="alias_example",
                                    last_execution_test_suite=ExecutionTestSuiteResource(ExecutionTestSuiteResource),
                                    updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    test_cases=[],
                                    test_project=TestProjectResource(TestProjectResource),
                                    created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    user=UserResource(
                                        id=1,
                                        email="email_example",
                                        first_name="first_name_example",
                                        last_name="last_name_example",
                                        password="password_example",
                                        inviting_url="inviting_url_example",
                                        avatar="avatar_example",
                                        configs=ConfigResource(
                                            web_socket_url="web_socket_url_example",
                                            store_url="store_url_example",
                                            profiles=[],
                                            stripe_public_api="stripe_public_api_example",
                                            build_version="build_version_example",
                                            commit_id="commit_id_example",
                                            sentry_dsn="sentry_dsn_example",
                                            sentry_env="sentry_env_example",
                                            sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                                            server_url="server_url_example",
                                            io_server_url="io_server_url_example",
                                            proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                                            max_execution_comparison=1,
                                            max_execution_download=1,
                                            agent_download_urls={},
                                            proxy_tunnel_download_urls={},
                                            report_uploader_download_url="report_uploader_download_url_example",
                                            report_uploader_latest_version="report_uploader_latest_version_example",
                                            sub_domain_pattern="sub_domain_pattern_example",
                                            cancellation_survey_url="cancellation_survey_url_example",
                                            launch_darkly_client_id="launch_darkly_client_id_example",
                                            launch_darkly_default_user="launch_darkly_default_user_example",
                                            launch_darkly_prefix="launch_darkly_prefix_example",
                                            min_test_execution_ordered=1,
                                            user_flow_token="user_flow_token_example",
                                            demo_project_url="demo_project_url_example",
                                            advanced_feature_enabled=True,
                                            using_sub_domain=True,
                                            test_ops_subscription_enabled=True,
                                            frameworks_integration_enabled=True,
                                        ),
                                        projects=[],
                                        teams=[],
                                        organizations=[],
                                        organization_feature=[],
                                        trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        system_role="USER",
                                        survey_status="NOT_SUBMITTED",
                                        session_timeout=1,
                                        business_user=True,
                                        can_create_offline_kse=True,
                                        can_create_offline_re=True,
                                        saml_sso=True,
                                        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        full_name="full_name_example",
                                    ),
                                    type="KATALON_STUDIO",
                                    test_folder=TestFolderResource(
                                        id=1,
                                        name="name_example",
                                        raw_path="raw_path_example",
                                        test_project=TestProjectResource(TestProjectResource),
                                        tree_path="tree_path_example",
                                        parent_id=1,
                                    ),
                                    url_id="url_id_example",
                                ),
                                platform=PlatformResource(
                                    id=1,
                                    os_name="os_name_example",
                                    os_version="os_version_example",
                                    browser_name="browser_name_example",
                                    browser_version="browser_version_example",
                                    device_name="device_name_example",
                                    app_name="app_name_example",
                                ),
                                execution_id=1,
                                profiles=[],
                                has_comment=True,
                                url_id="url_id_example",
                            ),
                        ],
                        release=ReleaseResource(
                            id=1,
                            name="name_example",
                            start_time=dateutil_parser('1970-01-01').date(),
                            end_time=dateutil_parser('1970-01-01').date(),
                            description="description_example",
                            project_id=1,
                            closed=True,
                            created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            external_release=ExternalReleaseResource(
                                id=1,
                                release_id="release_id_example",
                                description="description_example",
                                name="name_example",
                                archived=True,
                                released=True,
                                project_id="project_id_example",
                                external_project=ExternalProjectResource(
                                    id=1,
                                    external_project_id="external_project_id_example",
                                    external_project_key="external_project_key_example",
                                    name="name_example",
                                ),
                                web_url="web_url_example",
                                jira_release_status="RELEASED",
                                start_date=dateutil_parser('1970-01-01').date(),
                                release_date=dateutil_parser('1970-01-01').date(),
                            ),
                            release_statistics=ReleaseStatisticsResource(
                                id=1,
                                release=ReleaseResource(ReleaseResource),
                                total_passed=1,
                                total_failed=1,
                                total_execution=1,
                                total_defect=1,
                                total_duration=1,
                            ),
                            builds=[
                                BuildResource(
                                    id=1,
                                    project_id=1,
                                    project=ProjectResource(
                                        id=1,
                                        name="name_example",
                                        team_id=1,
                                        team=TeamResource(
                                            id=1,
                                            name="name_example",
                                            role="OWNER",
                                            users=[],
                                            organization=OrganizationResource(
                                                id=1,
                                                name="name_example",
                                                role="OWNER",
                                                org_feature_flag=OrganizationFeatureFlagResource(
                                                    organization_id=1,
                                                    sub_domain=True,
                                                    strict_domain=True,
                                                    sso=True,
                                                    whitelist_ip=True,
                                                    circle_ci=True,
                                                    test_ops_integration=True,
                                                ),
                                                quota_kse=1,
                                                machine_quota_kse=1,
                                                quota_unlimited_kse=1,
                                                quota_engine=1,
                                                machine_quota_engine=1,
                                                quota_unlimited_engine=1,
                                                used_kse=1,
                                                used_unlimited_kse=1,
                                                used_engine=1,
                                                used_unlimited_engine=1,
                                                quota_test_ops=1,
                                                used_test_ops=1,
                                                number_user=1,
                                                quota_floating_engine=1,
                                                used_floating_engine=1,
                                                can_create_offline_kse=True,
                                                can_create_offline_unlimited_kse=True,
                                                can_create_offline_re=True,
                                                can_create_offline_unlimited_engine=True,
                                                subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscribed=True,
                                                kse_paygo=True,
                                                kre_paygo=True,
                                                paygo_quota=1,
                                                domain="domain_example",
                                                subdomain_url="subdomain_url_example",
                                                strict_domain=True,
                                                logo_url="logo_url_example",
                                                saml_sso=True,
                                                kre_license=True,
                                                most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                account_id=1,
                                                test_ops_feature="KSE",
                                                platform_feature="KSE",
                                                tier="FREE",
                                                requested_user_verified=True,
                                            ),
                                            organization_id=1,
                                        ),
                                        timezone="timezone_example",
                                        status="ARCHIVE",
                                    ),
                                    release_id=1,
                                    release=ReleaseResource(ReleaseResource),
                                    build_statistics=BuildStatisticsResource(
                                        id=1,
                                        build=BuildResource(BuildResource),
                                        total_execution=1,
                                        total_passed=1,
                                        total_failed=1,
                                    ),
                                    name="name_example",
                                    description="description_example",
                                    date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                ),
                            ],
                            release_status="NOT_READY",
                        ),
                        build=BuildResource(
                            id=1,
                            project_id=1,
                            project=ProjectResource(
                                id=1,
                                name="name_example",
                                team_id=1,
                                team=TeamResource(
                                    id=1,
                                    name="name_example",
                                    role="OWNER",
                                    users=[],
                                    organization=OrganizationResource(
                                        id=1,
                                        name="name_example",
                                        role="OWNER",
                                        org_feature_flag=OrganizationFeatureFlagResource(
                                            organization_id=1,
                                            sub_domain=True,
                                            strict_domain=True,
                                            sso=True,
                                            whitelist_ip=True,
                                            circle_ci=True,
                                            test_ops_integration=True,
                                        ),
                                        quota_kse=1,
                                        machine_quota_kse=1,
                                        quota_unlimited_kse=1,
                                        quota_engine=1,
                                        machine_quota_engine=1,
                                        quota_unlimited_engine=1,
                                        used_kse=1,
                                        used_unlimited_kse=1,
                                        used_engine=1,
                                        used_unlimited_engine=1,
                                        quota_test_ops=1,
                                        used_test_ops=1,
                                        number_user=1,
                                        quota_floating_engine=1,
                                        used_floating_engine=1,
                                        can_create_offline_kse=True,
                                        can_create_offline_unlimited_kse=True,
                                        can_create_offline_re=True,
                                        can_create_offline_unlimited_engine=True,
                                        subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscribed=True,
                                        kse_paygo=True,
                                        kre_paygo=True,
                                        paygo_quota=1,
                                        domain="domain_example",
                                        subdomain_url="subdomain_url_example",
                                        strict_domain=True,
                                        logo_url="logo_url_example",
                                        saml_sso=True,
                                        kre_license=True,
                                        most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        account_id=1,
                                        test_ops_feature="KSE",
                                        platform_feature="KSE",
                                        tier="FREE",
                                        requested_user_verified=True,
                                    ),
                                    organization_id=1,
                                ),
                                timezone="timezone_example",
                                status="ARCHIVE",
                            ),
                            release_id=1,
                            release=ReleaseResource(
                                id=1,
                                name="name_example",
                                start_time=dateutil_parser('1970-01-01').date(),
                                end_time=dateutil_parser('1970-01-01').date(),
                                description="description_example",
                                project_id=1,
                                closed=True,
                                created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                external_release=ExternalReleaseResource(
                                    id=1,
                                    release_id="release_id_example",
                                    description="description_example",
                                    name="name_example",
                                    archived=True,
                                    released=True,
                                    project_id="project_id_example",
                                    external_project=ExternalProjectResource(
                                        id=1,
                                        external_project_id="external_project_id_example",
                                        external_project_key="external_project_key_example",
                                        name="name_example",
                                    ),
                                    web_url="web_url_example",
                                    jira_release_status="RELEASED",
                                    start_date=dateutil_parser('1970-01-01').date(),
                                    release_date=dateutil_parser('1970-01-01').date(),
                                ),
                                release_statistics=ReleaseStatisticsResource(
                                    id=1,
                                    release=ReleaseResource(ReleaseResource),
                                    total_passed=1,
                                    total_failed=1,
                                    total_execution=1,
                                    total_defect=1,
                                    total_duration=1,
                                ),
                                builds=[],
                                release_status="NOT_READY",
                            ),
                            build_statistics=BuildStatisticsResource(
                                id=1,
                                build=BuildResource(BuildResource),
                                total_execution=1,
                                total_passed=1,
                                total_failed=1,
                            ),
                            name="name_example",
                            description="description_example",
                            date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        ),
                        has_comment=True,
                        user=UserResource(
                            id=1,
                            email="email_example",
                            first_name="first_name_example",
                            last_name="last_name_example",
                            password="password_example",
                            inviting_url="inviting_url_example",
                            avatar="avatar_example",
                            configs=ConfigResource(
                                web_socket_url="web_socket_url_example",
                                store_url="store_url_example",
                                profiles=[],
                                stripe_public_api="stripe_public_api_example",
                                build_version="build_version_example",
                                commit_id="commit_id_example",
                                sentry_dsn="sentry_dsn_example",
                                sentry_env="sentry_env_example",
                                sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                                server_url="server_url_example",
                                io_server_url="io_server_url_example",
                                proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                                max_execution_comparison=1,
                                max_execution_download=1,
                                agent_download_urls={},
                                proxy_tunnel_download_urls={},
                                report_uploader_download_url="report_uploader_download_url_example",
                                report_uploader_latest_version="report_uploader_latest_version_example",
                                sub_domain_pattern="sub_domain_pattern_example",
                                cancellation_survey_url="cancellation_survey_url_example",
                                launch_darkly_client_id="launch_darkly_client_id_example",
                                launch_darkly_default_user="launch_darkly_default_user_example",
                                launch_darkly_prefix="launch_darkly_prefix_example",
                                min_test_execution_ordered=1,
                                user_flow_token="user_flow_token_example",
                                demo_project_url="demo_project_url_example",
                                advanced_feature_enabled=True,
                                using_sub_domain=True,
                                test_ops_subscription_enabled=True,
                                frameworks_integration_enabled=True,
                            ),
                            projects=[],
                            teams=[],
                            organizations=[],
                            organization_feature=[],
                            trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            system_role="USER",
                            survey_status="NOT_SUBMITTED",
                            session_timeout=1,
                            business_user=True,
                            can_create_offline_kse=True,
                            can_create_offline_re=True,
                            saml_sso=True,
                            created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            full_name="full_name_example",
                        ),
                        session_id="session_id_example",
                        build_label="build_label_example",
                        build_url="build_url_example",
                        type="KATALON",
                        jobs=[
                            JobResource(JobResource),
                        ],
                        use_test_cloud_tunnel=True,
                        getk_eyes_execution=KEyesExecutionResource(
                            id=1,
                            status="RUNNING",
                            execution=ExecutionResource(ExecutionResource),
                            total_checkpoints=1,
                            passed_checkpoints=1,
                            failed_checkpoints=1,
                            unresolved_checkpoints=1,
                            unsaved=True,
                            baseline_collection=BaselineCollectionResource(
                                id=1,
                                version=1,
                                baselines=[
                                    BaselineResource(
                                        id=1,
                                        upload_file=UploadFileResource(
                                            path="path_example",
                                            file_name="file_name_example",
                                            type="TSC_EXECUTION",
                                            base64_content="base64_content_example",
                                            file_handle_id=1,
                                            thumbnail_id=1,
                                        ),
                                        screenshot_id=1,
                                        execution=ExecutionResource(ExecutionResource),
                                        screenshot=ScreenshotResource(
                                            name="name_example",
                                            width=3.14,
                                            height=3.14,
                                        ),
                                        width=3.14,
                                        height=3.14,
                                        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        draft_ignoring_zones=[
                                            IgnoringZoneResource(
                                                uuid="uuid_example",
                                                x=1,
                                                y=1,
                                                w=1,
                                                h=1,
                                                type="ALL",
                                            ),
                                        ],
                                        ignoring_zones=[
                                            IgnoringZoneResource(
                                                uuid="uuid_example",
                                                x=1,
                                                y=1,
                                                w=1,
                                                h=1,
                                                type="ALL",
                                            ),
                                        ],
                                    ),
                                ],
                                number_of_baselines=1,
                                updated_by=UserResource(
                                    id=1,
                                    email="email_example",
                                    first_name="first_name_example",
                                    last_name="last_name_example",
                                    password="password_example",
                                    inviting_url="inviting_url_example",
                                    avatar="avatar_example",
                                    configs=ConfigResource(
                                        web_socket_url="web_socket_url_example",
                                        store_url="store_url_example",
                                        profiles=[],
                                        stripe_public_api="stripe_public_api_example",
                                        build_version="build_version_example",
                                        commit_id="commit_id_example",
                                        sentry_dsn="sentry_dsn_example",
                                        sentry_env="sentry_env_example",
                                        sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                                        server_url="server_url_example",
                                        io_server_url="io_server_url_example",
                                        proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                                        max_execution_comparison=1,
                                        max_execution_download=1,
                                        agent_download_urls={},
                                        proxy_tunnel_download_urls={},
                                        report_uploader_download_url="report_uploader_download_url_example",
                                        report_uploader_latest_version="report_uploader_latest_version_example",
                                        sub_domain_pattern="sub_domain_pattern_example",
                                        cancellation_survey_url="cancellation_survey_url_example",
                                        launch_darkly_client_id="launch_darkly_client_id_example",
                                        launch_darkly_default_user="launch_darkly_default_user_example",
                                        launch_darkly_prefix="launch_darkly_prefix_example",
                                        min_test_execution_ordered=1,
                                        user_flow_token="user_flow_token_example",
                                        demo_project_url="demo_project_url_example",
                                        advanced_feature_enabled=True,
                                        using_sub_domain=True,
                                        test_ops_subscription_enabled=True,
                                        frameworks_integration_enabled=True,
                                    ),
                                    projects=[],
                                    teams=[],
                                    organizations=[],
                                    organization_feature=[],
                                    trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    system_role="USER",
                                    survey_status="NOT_SUBMITTED",
                                    session_timeout=1,
                                    business_user=True,
                                    can_create_offline_kse=True,
                                    can_create_offline_re=True,
                                    saml_sso=True,
                                    created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    full_name="full_name_example",
                                ),
                                baseline_collection_group=BaselineCollectionGroupResource(
                                    id=1,
                                    name="name_example",
                                    latest_version=BaselineCollectionResource(BaselineCollectionResource),
                                    run_configurations=[
                                        RunConfigurationResource(RunConfigurationResource),
                                    ],
                                    updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    order=1,
                                    last_run=KEyesExecutionResource(KEyesExecutionResource),
                                ),
                                unsaved=True,
                                default_method="PIXEL",
                                draft_default_method="PIXEL",
                                threshold=1,
                                draft_threshold=1,
                                create_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            ),
                        ),
                        data_type="USER_DATA",
                    ),
                    agent=AgentResource(
                        id=1,
                        name="name_example",
                        ip="ip_example",
                        uuid="uuid_example",
                        last_ping=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        os="os_example",
                        team_id=1,
                        hostname="hostname_example",
                        active=True,
                        threshold=1,
                        num_executing_jobs=1,
                        num_assigned_jobs=1,
                        agent_version="agent_version_example",
                        deleted=True,
                    ),
                    test_cloud_agent=TestCloudAgentResource(
                        id=1,
                        name="name_example",
                        os="os_example",
                        os_version="os_version_example",
                        browser="browser_example",
                        browser_version="browser_version_example",
                        device_name="device_name_example",
                        app_id="app_id_example",
                        app_group_id="app_group_id_example",
                        app_name="app_name_example",
                        device_id="device_id_example",
                        num_executing_jobs=1,
                        num_assigned_jobs=1,
                        team_id=1,
                        deleted=True,
                        api_key="api_key_example",
                        total_duration=1,
                        headless=True,
                        execution_type="CHROME",
                    ),
                    k8s_agent=K8SAgentResource(
                        id=1,
                        name="name_example",
                        certificate_authority="certificate_authority_example",
                        url="url_example",
                        namespace="namespace_example",
                        username="username_example",
                        password="password_example",
                        token="token_example",
                        cluster="cluster_example",
                        region="region_example",
                        access_key="access_key_example",
                        private_access_key="private_access_key_example",
                        team_id=1,
                        api_key="api_key_example",
                        authentication_type="BASIC_AUTH",
                    ),
                    circle_ci_agent=CircleCIAgentResource(
                        id=1,
                        name="name_example",
                        url="url_example",
                        username="username_example",
                        token="token_example",
                        project="project_example",
                        vcs_type="vcs_type_example",
                        branch="branch_example",
                        team_id=1,
                        api_key="api_key_example",
                    ),
                    run_configuration=RunConfigurationResource(RunConfigurationResource),
                    order=1,
                    parameter=TriggerBuildParameter(
                        download_url="download_url_example",
                        command="command_example",
                        environment_variables=[
                            EnvironmentVariable(
                                name="name_example",
                                value="value_example",
                            ),
                        ],
                        session_id="session_id_example",
                        ks_version="ks_version_example",
                        ks_location="ks_location_example",
                        config_type="TSC",
                        type="KS",
                        git_repository_resource=GitRepositoryResource(
                            id=1,
                            test_project_id=1,
                            name="name_example",
                            repository="repository_example",
                            branch="branch_example",
                            username="username_example",
                            password="password_example",
                            access_key_id="access_key_id_example",
                            secret_access_key="secret_access_key_example",
                            project_id=1,
                            team_id=1,
                            created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            description="description_example",
                            vcs_type="GITHUB",
                            should_merge_test_results_for_new_script_repo=True,
                        ),
                        test_ops_download_url="test_ops_download_url_example",
                        extra_files=[
                            KSFile(
                                content_url="content_url_example",
                                path="path_example",
                                write_mode="OVERRIDE",
                            ),
                        ],
                        organization_id=1,
                    ),
                    trigger_by="MANUAL",
                    duration=1,
                    trigger_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    user=UserResource(
                        id=1,
                        email="email_example",
                        first_name="first_name_example",
                        last_name="last_name_example",
                        password="password_example",
                        inviting_url="inviting_url_example",
                        avatar="avatar_example",
                        configs=ConfigResource(
                            web_socket_url="web_socket_url_example",
                            store_url="store_url_example",
                            profiles=[],
                            stripe_public_api="stripe_public_api_example",
                            build_version="build_version_example",
                            commit_id="commit_id_example",
                            sentry_dsn="sentry_dsn_example",
                            sentry_env="sentry_env_example",
                            sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                            server_url="server_url_example",
                            io_server_url="io_server_url_example",
                            proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                            max_execution_comparison=1,
                            max_execution_download=1,
                            agent_download_urls={},
                            proxy_tunnel_download_urls={},
                            report_uploader_download_url="report_uploader_download_url_example",
                            report_uploader_latest_version="report_uploader_latest_version_example",
                            sub_domain_pattern="sub_domain_pattern_example",
                            cancellation_survey_url="cancellation_survey_url_example",
                            launch_darkly_client_id="launch_darkly_client_id_example",
                            launch_darkly_default_user="launch_darkly_default_user_example",
                            launch_darkly_prefix="launch_darkly_prefix_example",
                            min_test_execution_ordered=1,
                            user_flow_token="user_flow_token_example",
                            demo_project_url="demo_project_url_example",
                            advanced_feature_enabled=True,
                            using_sub_domain=True,
                            test_ops_subscription_enabled=True,
                            frameworks_integration_enabled=True,
                        ),
                        projects=[],
                        teams=[],
                        organizations=[],
                        organization_feature=[],
                        trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        system_role="USER",
                        survey_status="NOT_SUBMITTED",
                        session_timeout=1,
                        business_user=True,
                        can_create_offline_kse=True,
                        can_create_offline_re=True,
                        saml_sso=True,
                        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        full_name="full_name_example",
                    ),
                    scheduler=SchedulerResource(SchedulerResource),
                    project=ProjectResource(
                        id=1,
                        name="name_example",
                        team_id=1,
                        team=TeamResource(
                            id=1,
                            name="name_example",
                            role="OWNER",
                            users=[],
                            organization=OrganizationResource(
                                id=1,
                                name="name_example",
                                role="OWNER",
                                org_feature_flag=OrganizationFeatureFlagResource(
                                    organization_id=1,
                                    sub_domain=True,
                                    strict_domain=True,
                                    sso=True,
                                    whitelist_ip=True,
                                    circle_ci=True,
                                    test_ops_integration=True,
                                ),
                                quota_kse=1,
                                machine_quota_kse=1,
                                quota_unlimited_kse=1,
                                quota_engine=1,
                                machine_quota_engine=1,
                                quota_unlimited_engine=1,
                                used_kse=1,
                                used_unlimited_kse=1,
                                used_engine=1,
                                used_unlimited_engine=1,
                                quota_test_ops=1,
                                used_test_ops=1,
                                number_user=1,
                                quota_floating_engine=1,
                                used_floating_engine=1,
                                can_create_offline_kse=True,
                                can_create_offline_unlimited_kse=True,
                                can_create_offline_re=True,
                                can_create_offline_unlimited_engine=True,
                                subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscribed=True,
                                kse_paygo=True,
                                kre_paygo=True,
                                paygo_quota=1,
                                domain="domain_example",
                                subdomain_url="subdomain_url_example",
                                strict_domain=True,
                                logo_url="logo_url_example",
                                saml_sso=True,
                                kre_license=True,
                                most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                account_id=1,
                                test_ops_feature="KSE",
                                platform_feature="KSE",
                                tier="FREE",
                                requested_user_verified=True,
                            ),
                            organization_id=1,
                        ),
                        timezone="timezone_example",
                        status="ARCHIVE",
                    ),
                    process_id=1,
                    node_status="PENDING_CANCELED",
                    run_configuration_id=1,
                ),
                upload_file_name="upload_file_name_example",
                type="KS",
                git_repository=GitRepositoryResource(
                    id=1,
                    test_project_id=1,
                    name="name_example",
                    repository="repository_example",
                    branch="branch_example",
                    username="username_example",
                    password="password_example",
                    access_key_id="access_key_id_example",
                    secret_access_key="secret_access_key_example",
                    project_id=1,
                    team_id=1,
                    created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    description="description_example",
                    vcs_type="GITHUB",
                    should_merge_test_results_for_new_script_repo=True,
                ),
                test_suite_collections=[
                    TestSuiteCollectionResource(
                        id=1,
                        name="name_example",
                        project=ProjectResource(
                            id=1,
                            name="name_example",
                            team_id=1,
                            team=TeamResource(
                                id=1,
                                name="name_example",
                                role="OWNER",
                                users=[],
                                organization=OrganizationResource(
                                    id=1,
                                    name="name_example",
                                    role="OWNER",
                                    org_feature_flag=OrganizationFeatureFlagResource(
                                        organization_id=1,
                                        sub_domain=True,
                                        strict_domain=True,
                                        sso=True,
                                        whitelist_ip=True,
                                        circle_ci=True,
                                        test_ops_integration=True,
                                    ),
                                    quota_kse=1,
                                    machine_quota_kse=1,
                                    quota_unlimited_kse=1,
                                    quota_engine=1,
                                    machine_quota_engine=1,
                                    quota_unlimited_engine=1,
                                    used_kse=1,
                                    used_unlimited_kse=1,
                                    used_engine=1,
                                    used_unlimited_engine=1,
                                    quota_test_ops=1,
                                    used_test_ops=1,
                                    number_user=1,
                                    quota_floating_engine=1,
                                    used_floating_engine=1,
                                    can_create_offline_kse=True,
                                    can_create_offline_unlimited_kse=True,
                                    can_create_offline_re=True,
                                    can_create_offline_unlimited_engine=True,
                                    subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscribed=True,
                                    kse_paygo=True,
                                    kre_paygo=True,
                                    paygo_quota=1,
                                    domain="domain_example",
                                    subdomain_url="subdomain_url_example",
                                    strict_domain=True,
                                    logo_url="logo_url_example",
                                    saml_sso=True,
                                    kre_license=True,
                                    most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    account_id=1,
                                    test_ops_feature="KSE",
                                    platform_feature="KSE",
                                    tier="FREE",
                                    requested_user_verified=True,
                                ),
                                organization_id=1,
                            ),
                            timezone="timezone_example",
                            status="ARCHIVE",
                        ),
                        test_suite_collection_configurations=[
                            TestSuiteCollectionConfigurationResource(
                                id=1,
                                profile_name="profile_name_example",
                                browser_type="CHROME",
                                run_enabled=True,
                                sort_order=1,
                                test_suite_entity="test_suite_entity_example",
                            ),
                        ],
                        url_id="url_id_example",
                    ),
                ],
                dirty=True,
            ),
            agents=[
                AgentResource(
                    id=1,
                    name="name_example",
                    ip="ip_example",
                    uuid="uuid_example",
                    last_ping=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    os="os_example",
                    team_id=1,
                    hostname="hostname_example",
                    active=True,
                    threshold=1,
                    num_executing_jobs=1,
                    num_assigned_jobs=1,
                    agent_version="agent_version_example",
                    deleted=True,
                ),
            ],
            test_cloud_agents=[
                TestCloudAgentResource(
                    id=1,
                    name="name_example",
                    os="os_example",
                    os_version="os_version_example",
                    browser="browser_example",
                    browser_version="browser_version_example",
                    device_name="device_name_example",
                    app_id="app_id_example",
                    app_group_id="app_group_id_example",
                    app_name="app_name_example",
                    device_id="device_id_example",
                    num_executing_jobs=1,
                    num_assigned_jobs=1,
                    team_id=1,
                    deleted=True,
                    api_key="api_key_example",
                    total_duration=1,
                    headless=True,
                    execution_type="CHROME",
                ),
            ],
            k8s_agents=[
                K8SAgentResource(
                    id=1,
                    name="name_example",
                    certificate_authority="certificate_authority_example",
                    url="url_example",
                    namespace="namespace_example",
                    username="username_example",
                    password="password_example",
                    token="token_example",
                    cluster="cluster_example",
                    region="region_example",
                    access_key="access_key_example",
                    private_access_key="private_access_key_example",
                    team_id=1,
                    api_key="api_key_example",
                    authentication_type="BASIC_AUTH",
                ),
            ],
            circle_ci_agents=[
                CircleCIAgentResource(
                    id=1,
                    name="name_example",
                    url="url_example",
                    username="username_example",
                    token="token_example",
                    project="project_example",
                    vcs_type="vcs_type_example",
                    branch="branch_example",
                    team_id=1,
                    api_key="api_key_example",
                ),
            ],
            test_cloud_test_suite_collection_agents=[
                TestCloudTestSuiteCollectionAgentResource(
                    test_suite_collection_configuration_id=1,
                    test_cloud_agent=TestCloudAgentResource(
                        id=1,
                        name="name_example",
                        os="os_example",
                        os_version="os_version_example",
                        browser="browser_example",
                        browser_version="browser_version_example",
                        device_name="device_name_example",
                        app_id="app_id_example",
                        app_group_id="app_group_id_example",
                        app_name="app_name_example",
                        device_id="device_id_example",
                        num_executing_jobs=1,
                        num_assigned_jobs=1,
                        team_id=1,
                        deleted=True,
                        api_key="api_key_example",
                        total_duration=1,
                        headless=True,
                        execution_type="CHROME",
                    ),
                    updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                ),
            ],
            cloud_type="K8S",
            latest_job=JobResource(
                id=1,
                build_number=1,
                status="QUEUED",
                queued_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                stop_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                test_project=TestProjectResource(
                    id=1,
                    name="name_example",
                    description="description_example",
                    default_test_project=True,
                    upload_file_id=1,
                    project_id=1,
                    team_id=1,
                    created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    latest_job=JobResource(JobResource),
                    upload_file_name="upload_file_name_example",
                    type="KS",
                    git_repository=GitRepositoryResource(
                        id=1,
                        test_project_id=1,
                        name="name_example",
                        repository="repository_example",
                        branch="branch_example",
                        username="username_example",
                        password="password_example",
                        access_key_id="access_key_id_example",
                        secret_access_key="secret_access_key_example",
                        project_id=1,
                        team_id=1,
                        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        description="description_example",
                        vcs_type="GITHUB",
                        should_merge_test_results_for_new_script_repo=True,
                    ),
                    test_suite_collections=[],
                    dirty=True,
                ),
                execution=ExecutionResource(
                    status="PASSED",
                    start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    end_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    duration=1,
                    elapsed_duration=1,
                    total_tests=1,
                    total_passed_tests=1,
                    total_failed_tests=1,
                    total_error_tests=1,
                    total_incomplete_tests=1,
                    total_skipped_tests=1,
                    total_diff_tests=1,
                    total_diff_passed_tests=1,
                    total_diff_failed_tests=1,
                    total_diff_error_tests=1,
                    total_diff_incomplete_tests=1,
                    id=1,
                    project_id=1,
                    project=ProjectResource(
                        id=1,
                        name="name_example",
                        team_id=1,
                        team=TeamResource(
                            id=1,
                            name="name_example",
                            role="OWNER",
                            users=[],
                            organization=OrganizationResource(
                                id=1,
                                name="name_example",
                                role="OWNER",
                                org_feature_flag=OrganizationFeatureFlagResource(
                                    organization_id=1,
                                    sub_domain=True,
                                    strict_domain=True,
                                    sso=True,
                                    whitelist_ip=True,
                                    circle_ci=True,
                                    test_ops_integration=True,
                                ),
                                quota_kse=1,
                                machine_quota_kse=1,
                                quota_unlimited_kse=1,
                                quota_engine=1,
                                machine_quota_engine=1,
                                quota_unlimited_engine=1,
                                used_kse=1,
                                used_unlimited_kse=1,
                                used_engine=1,
                                used_unlimited_engine=1,
                                quota_test_ops=1,
                                used_test_ops=1,
                                number_user=1,
                                quota_floating_engine=1,
                                used_floating_engine=1,
                                can_create_offline_kse=True,
                                can_create_offline_unlimited_kse=True,
                                can_create_offline_re=True,
                                can_create_offline_unlimited_engine=True,
                                subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscribed=True,
                                kse_paygo=True,
                                kre_paygo=True,
                                paygo_quota=1,
                                domain="domain_example",
                                subdomain_url="subdomain_url_example",
                                strict_domain=True,
                                logo_url="logo_url_example",
                                saml_sso=True,
                                kre_license=True,
                                most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                account_id=1,
                                test_ops_feature="KSE",
                                platform_feature="KSE",
                                tier="FREE",
                                requested_user_verified=True,
                            ),
                            organization_id=1,
                        ),
                        timezone="timezone_example",
                        status="ARCHIVE",
                    ),
                    build_id=1,
                    order=1,
                    execution_stage="RUNNING",
                    web_url="web_url_example",
                    test_suite_collections=[],
                    execution_test_suite_resources=[],
                    release=ReleaseResource(
                        id=1,
                        name="name_example",
                        start_time=dateutil_parser('1970-01-01').date(),
                        end_time=dateutil_parser('1970-01-01').date(),
                        description="description_example",
                        project_id=1,
                        closed=True,
                        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        external_release=ExternalReleaseResource(
                            id=1,
                            release_id="release_id_example",
                            description="description_example",
                            name="name_example",
                            archived=True,
                            released=True,
                            project_id="project_id_example",
                            external_project=ExternalProjectResource(
                                id=1,
                                external_project_id="external_project_id_example",
                                external_project_key="external_project_key_example",
                                name="name_example",
                            ),
                            web_url="web_url_example",
                            jira_release_status="RELEASED",
                            start_date=dateutil_parser('1970-01-01').date(),
                            release_date=dateutil_parser('1970-01-01').date(),
                        ),
                        release_statistics=ReleaseStatisticsResource(
                            id=1,
                            release=ReleaseResource(ReleaseResource),
                            total_passed=1,
                            total_failed=1,
                            total_execution=1,
                            total_defect=1,
                            total_duration=1,
                        ),
                        builds=[],
                        release_status="NOT_READY",
                    ),
                    build=BuildResource(
                        id=1,
                        project_id=1,
                        project=ProjectResource(
                            id=1,
                            name="name_example",
                            team_id=1,
                            team=TeamResource(
                                id=1,
                                name="name_example",
                                role="OWNER",
                                users=[],
                                organization=OrganizationResource(
                                    id=1,
                                    name="name_example",
                                    role="OWNER",
                                    org_feature_flag=OrganizationFeatureFlagResource(
                                        organization_id=1,
                                        sub_domain=True,
                                        strict_domain=True,
                                        sso=True,
                                        whitelist_ip=True,
                                        circle_ci=True,
                                        test_ops_integration=True,
                                    ),
                                    quota_kse=1,
                                    machine_quota_kse=1,
                                    quota_unlimited_kse=1,
                                    quota_engine=1,
                                    machine_quota_engine=1,
                                    quota_unlimited_engine=1,
                                    used_kse=1,
                                    used_unlimited_kse=1,
                                    used_engine=1,
                                    used_unlimited_engine=1,
                                    quota_test_ops=1,
                                    used_test_ops=1,
                                    number_user=1,
                                    quota_floating_engine=1,
                                    used_floating_engine=1,
                                    can_create_offline_kse=True,
                                    can_create_offline_unlimited_kse=True,
                                    can_create_offline_re=True,
                                    can_create_offline_unlimited_engine=True,
                                    subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscribed=True,
                                    kse_paygo=True,
                                    kre_paygo=True,
                                    paygo_quota=1,
                                    domain="domain_example",
                                    subdomain_url="subdomain_url_example",
                                    strict_domain=True,
                                    logo_url="logo_url_example",
                                    saml_sso=True,
                                    kre_license=True,
                                    most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    account_id=1,
                                    test_ops_feature="KSE",
                                    platform_feature="KSE",
                                    tier="FREE",
                                    requested_user_verified=True,
                                ),
                                organization_id=1,
                            ),
                            timezone="timezone_example",
                            status="ARCHIVE",
                        ),
                        release_id=1,
                        release=ReleaseResource(
                            id=1,
                            name="name_example",
                            start_time=dateutil_parser('1970-01-01').date(),
                            end_time=dateutil_parser('1970-01-01').date(),
                            description="description_example",
                            project_id=1,
                            closed=True,
                            created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            external_release=ExternalReleaseResource(
                                id=1,
                                release_id="release_id_example",
                                description="description_example",
                                name="name_example",
                                archived=True,
                                released=True,
                                project_id="project_id_example",
                                external_project=ExternalProjectResource(
                                    id=1,
                                    external_project_id="external_project_id_example",
                                    external_project_key="external_project_key_example",
                                    name="name_example",
                                ),
                                web_url="web_url_example",
                                jira_release_status="RELEASED",
                                start_date=dateutil_parser('1970-01-01').date(),
                                release_date=dateutil_parser('1970-01-01').date(),
                            ),
                            release_statistics=ReleaseStatisticsResource(
                                id=1,
                                release=ReleaseResource(ReleaseResource),
                                total_passed=1,
                                total_failed=1,
                                total_execution=1,
                                total_defect=1,
                                total_duration=1,
                            ),
                            builds=[],
                            release_status="NOT_READY",
                        ),
                        build_statistics=BuildStatisticsResource(
                            id=1,
                            build=BuildResource(BuildResource),
                            total_execution=1,
                            total_passed=1,
                            total_failed=1,
                        ),
                        name="name_example",
                        description="description_example",
                        date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    ),
                    has_comment=True,
                    user=UserResource(
                        id=1,
                        email="email_example",
                        first_name="first_name_example",
                        last_name="last_name_example",
                        password="password_example",
                        inviting_url="inviting_url_example",
                        avatar="avatar_example",
                        configs=ConfigResource(
                            web_socket_url="web_socket_url_example",
                            store_url="store_url_example",
                            profiles=[],
                            stripe_public_api="stripe_public_api_example",
                            build_version="build_version_example",
                            commit_id="commit_id_example",
                            sentry_dsn="sentry_dsn_example",
                            sentry_env="sentry_env_example",
                            sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                            server_url="server_url_example",
                            io_server_url="io_server_url_example",
                            proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                            max_execution_comparison=1,
                            max_execution_download=1,
                            agent_download_urls={},
                            proxy_tunnel_download_urls={},
                            report_uploader_download_url="report_uploader_download_url_example",
                            report_uploader_latest_version="report_uploader_latest_version_example",
                            sub_domain_pattern="sub_domain_pattern_example",
                            cancellation_survey_url="cancellation_survey_url_example",
                            launch_darkly_client_id="launch_darkly_client_id_example",
                            launch_darkly_default_user="launch_darkly_default_user_example",
                            launch_darkly_prefix="launch_darkly_prefix_example",
                            min_test_execution_ordered=1,
                            user_flow_token="user_flow_token_example",
                            demo_project_url="demo_project_url_example",
                            advanced_feature_enabled=True,
                            using_sub_domain=True,
                            test_ops_subscription_enabled=True,
                            frameworks_integration_enabled=True,
                        ),
                        projects=[],
                        teams=[],
                        organizations=[],
                        organization_feature=[],
                        trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        system_role="USER",
                        survey_status="NOT_SUBMITTED",
                        session_timeout=1,
                        business_user=True,
                        can_create_offline_kse=True,
                        can_create_offline_re=True,
                        saml_sso=True,
                        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        full_name="full_name_example",
                    ),
                    session_id="session_id_example",
                    build_label="build_label_example",
                    build_url="build_url_example",
                    type="KATALON",
                    jobs=[],
                    use_test_cloud_tunnel=True,
                    getk_eyes_execution=KEyesExecutionResource(
                        id=1,
                        status="RUNNING",
                        execution=ExecutionResource(ExecutionResource),
                        total_checkpoints=1,
                        passed_checkpoints=1,
                        failed_checkpoints=1,
                        unresolved_checkpoints=1,
                        unsaved=True,
                        baseline_collection=BaselineCollectionResource(
                            id=1,
                            version=1,
                            baselines=[],
                            number_of_baselines=1,
                            updated_by=UserResource(
                                id=1,
                                email="email_example",
                                first_name="first_name_example",
                                last_name="last_name_example",
                                password="password_example",
                                inviting_url="inviting_url_example",
                                avatar="avatar_example",
                                configs=ConfigResource(
                                    web_socket_url="web_socket_url_example",
                                    store_url="store_url_example",
                                    profiles=[],
                                    stripe_public_api="stripe_public_api_example",
                                    build_version="build_version_example",
                                    commit_id="commit_id_example",
                                    sentry_dsn="sentry_dsn_example",
                                    sentry_env="sentry_env_example",
                                    sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                                    server_url="server_url_example",
                                    io_server_url="io_server_url_example",
                                    proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                                    max_execution_comparison=1,
                                    max_execution_download=1,
                                    agent_download_urls={},
                                    proxy_tunnel_download_urls={},
                                    report_uploader_download_url="report_uploader_download_url_example",
                                    report_uploader_latest_version="report_uploader_latest_version_example",
                                    sub_domain_pattern="sub_domain_pattern_example",
                                    cancellation_survey_url="cancellation_survey_url_example",
                                    launch_darkly_client_id="launch_darkly_client_id_example",
                                    launch_darkly_default_user="launch_darkly_default_user_example",
                                    launch_darkly_prefix="launch_darkly_prefix_example",
                                    min_test_execution_ordered=1,
                                    user_flow_token="user_flow_token_example",
                                    demo_project_url="demo_project_url_example",
                                    advanced_feature_enabled=True,
                                    using_sub_domain=True,
                                    test_ops_subscription_enabled=True,
                                    frameworks_integration_enabled=True,
                                ),
                                projects=[],
                                teams=[],
                                organizations=[],
                                organization_feature=[],
                                trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                system_role="USER",
                                survey_status="NOT_SUBMITTED",
                                session_timeout=1,
                                business_user=True,
                                can_create_offline_kse=True,
                                can_create_offline_re=True,
                                saml_sso=True,
                                created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                full_name="full_name_example",
                            ),
                            baseline_collection_group=BaselineCollectionGroupResource(
                                id=1,
                                name="name_example",
                                latest_version=BaselineCollectionResource(BaselineCollectionResource),
                                run_configurations=[],
                                updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                order=1,
                                last_run=KEyesExecutionResource(KEyesExecutionResource),
                            ),
                            unsaved=True,
                            default_method="PIXEL",
                            draft_default_method="PIXEL",
                            threshold=1,
                            draft_threshold=1,
                            create_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        ),
                    ),
                    data_type="USER_DATA",
                ),
                agent=AgentResource(
                    id=1,
                    name="name_example",
                    ip="ip_example",
                    uuid="uuid_example",
                    last_ping=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    os="os_example",
                    team_id=1,
                    hostname="hostname_example",
                    active=True,
                    threshold=1,
                    num_executing_jobs=1,
                    num_assigned_jobs=1,
                    agent_version="agent_version_example",
                    deleted=True,
                ),
                test_cloud_agent=TestCloudAgentResource(
                    id=1,
                    name="name_example",
                    os="os_example",
                    os_version="os_version_example",
                    browser="browser_example",
                    browser_version="browser_version_example",
                    device_name="device_name_example",
                    app_id="app_id_example",
                    app_group_id="app_group_id_example",
                    app_name="app_name_example",
                    device_id="device_id_example",
                    num_executing_jobs=1,
                    num_assigned_jobs=1,
                    team_id=1,
                    deleted=True,
                    api_key="api_key_example",
                    total_duration=1,
                    headless=True,
                    execution_type="CHROME",
                ),
                k8s_agent=K8SAgentResource(
                    id=1,
                    name="name_example",
                    certificate_authority="certificate_authority_example",
                    url="url_example",
                    namespace="namespace_example",
                    username="username_example",
                    password="password_example",
                    token="token_example",
                    cluster="cluster_example",
                    region="region_example",
                    access_key="access_key_example",
                    private_access_key="private_access_key_example",
                    team_id=1,
                    api_key="api_key_example",
                    authentication_type="BASIC_AUTH",
                ),
                circle_ci_agent=CircleCIAgentResource(
                    id=1,
                    name="name_example",
                    url="url_example",
                    username="username_example",
                    token="token_example",
                    project="project_example",
                    vcs_type="vcs_type_example",
                    branch="branch_example",
                    team_id=1,
                    api_key="api_key_example",
                ),
                run_configuration=RunConfigurationResource(RunConfigurationResource),
                order=1,
                parameter=TriggerBuildParameter(
                    download_url="download_url_example",
                    command="command_example",
                    environment_variables=[],
                    session_id="session_id_example",
                    ks_version="ks_version_example",
                    ks_location="ks_location_example",
                    config_type="TSC",
                    type="KS",
                    git_repository_resource=GitRepositoryResource(
                        id=1,
                        test_project_id=1,
                        name="name_example",
                        repository="repository_example",
                        branch="branch_example",
                        username="username_example",
                        password="password_example",
                        access_key_id="access_key_id_example",
                        secret_access_key="secret_access_key_example",
                        project_id=1,
                        team_id=1,
                        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        description="description_example",
                        vcs_type="GITHUB",
                        should_merge_test_results_for_new_script_repo=True,
                    ),
                    test_ops_download_url="test_ops_download_url_example",
                    extra_files=[],
                    organization_id=1,
                ),
                trigger_by="MANUAL",
                duration=1,
                trigger_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                user=UserResource(
                    id=1,
                    email="email_example",
                    first_name="first_name_example",
                    last_name="last_name_example",
                    password="password_example",
                    inviting_url="inviting_url_example",
                    avatar="avatar_example",
                    configs=ConfigResource(
                        web_socket_url="web_socket_url_example",
                        store_url="store_url_example",
                        profiles=[],
                        stripe_public_api="stripe_public_api_example",
                        build_version="build_version_example",
                        commit_id="commit_id_example",
                        sentry_dsn="sentry_dsn_example",
                        sentry_env="sentry_env_example",
                        sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                        server_url="server_url_example",
                        io_server_url="io_server_url_example",
                        proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                        max_execution_comparison=1,
                        max_execution_download=1,
                        agent_download_urls={},
                        proxy_tunnel_download_urls={},
                        report_uploader_download_url="report_uploader_download_url_example",
                        report_uploader_latest_version="report_uploader_latest_version_example",
                        sub_domain_pattern="sub_domain_pattern_example",
                        cancellation_survey_url="cancellation_survey_url_example",
                        launch_darkly_client_id="launch_darkly_client_id_example",
                        launch_darkly_default_user="launch_darkly_default_user_example",
                        launch_darkly_prefix="launch_darkly_prefix_example",
                        min_test_execution_ordered=1,
                        user_flow_token="user_flow_token_example",
                        demo_project_url="demo_project_url_example",
                        advanced_feature_enabled=True,
                        using_sub_domain=True,
                        test_ops_subscription_enabled=True,
                        frameworks_integration_enabled=True,
                    ),
                    projects=[],
                    teams=[],
                    organizations=[],
                    organization_feature=[],
                    trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    system_role="USER",
                    survey_status="NOT_SUBMITTED",
                    session_timeout=1,
                    business_user=True,
                    can_create_offline_kse=True,
                    can_create_offline_re=True,
                    saml_sso=True,
                    created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    full_name="full_name_example",
                ),
                scheduler=SchedulerResource(SchedulerResource),
                project=ProjectResource(
                    id=1,
                    name="name_example",
                    team_id=1,
                    team=TeamResource(
                        id=1,
                        name="name_example",
                        role="OWNER",
                        users=[],
                        organization=OrganizationResource(
                            id=1,
                            name="name_example",
                            role="OWNER",
                            org_feature_flag=OrganizationFeatureFlagResource(
                                organization_id=1,
                                sub_domain=True,
                                strict_domain=True,
                                sso=True,
                                whitelist_ip=True,
                                circle_ci=True,
                                test_ops_integration=True,
                            ),
                            quota_kse=1,
                            machine_quota_kse=1,
                            quota_unlimited_kse=1,
                            quota_engine=1,
                            machine_quota_engine=1,
                            quota_unlimited_engine=1,
                            used_kse=1,
                            used_unlimited_kse=1,
                            used_engine=1,
                            used_unlimited_engine=1,
                            quota_test_ops=1,
                            used_test_ops=1,
                            number_user=1,
                            quota_floating_engine=1,
                            used_floating_engine=1,
                            can_create_offline_kse=True,
                            can_create_offline_unlimited_kse=True,
                            can_create_offline_re=True,
                            can_create_offline_unlimited_engine=True,
                            subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscribed=True,
                            kse_paygo=True,
                            kre_paygo=True,
                            paygo_quota=1,
                            domain="domain_example",
                            subdomain_url="subdomain_url_example",
                            strict_domain=True,
                            logo_url="logo_url_example",
                            saml_sso=True,
                            kre_license=True,
                            most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            account_id=1,
                            test_ops_feature="KSE",
                            platform_feature="KSE",
                            tier="FREE",
                            requested_user_verified=True,
                        ),
                        organization_id=1,
                    ),
                    timezone="timezone_example",
                    status="ARCHIVE",
                ),
                process_id=1,
                node_status="PENDING_CANCELED",
                run_configuration_id=1,
            ),
            generic_command="generic_command_example",
            ks_version="ks_version_example",
            ks_location="ks_location_example",
            next_run_scheduler=SchedulerResource(SchedulerResource),
            release=ReleaseResource(
                id=1,
                name="name_example",
                start_time=dateutil_parser('1970-01-01').date(),
                end_time=dateutil_parser('1970-01-01').date(),
                description="description_example",
                project_id=1,
                closed=True,
                created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                external_release=ExternalReleaseResource(
                    id=1,
                    release_id="release_id_example",
                    description="description_example",
                    name="name_example",
                    archived=True,
                    released=True,
                    project_id="project_id_example",
                    external_project=ExternalProjectResource(
                        id=1,
                        external_project_id="external_project_id_example",
                        external_project_key="external_project_key_example",
                        name="name_example",
                    ),
                    web_url="web_url_example",
                    jira_release_status="RELEASED",
                    start_date=dateutil_parser('1970-01-01').date(),
                    release_date=dateutil_parser('1970-01-01').date(),
                ),
                release_statistics=ReleaseStatisticsResource(
                    id=1,
                    release=ReleaseResource(ReleaseResource),
                    total_passed=1,
                    total_failed=1,
                    total_execution=1,
                    total_defect=1,
                    total_duration=1,
                ),
                builds=[],
                release_status="NOT_READY",
            ),
            build=BuildResource(
                id=1,
                project_id=1,
                project=ProjectResource(
                    id=1,
                    name="name_example",
                    team_id=1,
                    team=TeamResource(
                        id=1,
                        name="name_example",
                        role="OWNER",
                        users=[],
                        organization=OrganizationResource(
                            id=1,
                            name="name_example",
                            role="OWNER",
                            org_feature_flag=OrganizationFeatureFlagResource(
                                organization_id=1,
                                sub_domain=True,
                                strict_domain=True,
                                sso=True,
                                whitelist_ip=True,
                                circle_ci=True,
                                test_ops_integration=True,
                            ),
                            quota_kse=1,
                            machine_quota_kse=1,
                            quota_unlimited_kse=1,
                            quota_engine=1,
                            machine_quota_engine=1,
                            quota_unlimited_engine=1,
                            used_kse=1,
                            used_unlimited_kse=1,
                            used_engine=1,
                            used_unlimited_engine=1,
                            quota_test_ops=1,
                            used_test_ops=1,
                            number_user=1,
                            quota_floating_engine=1,
                            used_floating_engine=1,
                            can_create_offline_kse=True,
                            can_create_offline_unlimited_kse=True,
                            can_create_offline_re=True,
                            can_create_offline_unlimited_engine=True,
                            subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscribed=True,
                            kse_paygo=True,
                            kre_paygo=True,
                            paygo_quota=1,
                            domain="domain_example",
                            subdomain_url="subdomain_url_example",
                            strict_domain=True,
                            logo_url="logo_url_example",
                            saml_sso=True,
                            kre_license=True,
                            most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            account_id=1,
                            test_ops_feature="KSE",
                            platform_feature="KSE",
                            tier="FREE",
                            requested_user_verified=True,
                        ),
                        organization_id=1,
                    ),
                    timezone="timezone_example",
                    status="ARCHIVE",
                ),
                release_id=1,
                release=ReleaseResource(
                    id=1,
                    name="name_example",
                    start_time=dateutil_parser('1970-01-01').date(),
                    end_time=dateutil_parser('1970-01-01').date(),
                    description="description_example",
                    project_id=1,
                    closed=True,
                    created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    external_release=ExternalReleaseResource(
                        id=1,
                        release_id="release_id_example",
                        description="description_example",
                        name="name_example",
                        archived=True,
                        released=True,
                        project_id="project_id_example",
                        external_project=ExternalProjectResource(
                            id=1,
                            external_project_id="external_project_id_example",
                            external_project_key="external_project_key_example",
                            name="name_example",
                        ),
                        web_url="web_url_example",
                        jira_release_status="RELEASED",
                        start_date=dateutil_parser('1970-01-01').date(),
                        release_date=dateutil_parser('1970-01-01').date(),
                    ),
                    release_statistics=ReleaseStatisticsResource(
                        id=1,
                        release=ReleaseResource(ReleaseResource),
                        total_passed=1,
                        total_failed=1,
                        total_execution=1,
                        total_defect=1,
                        total_duration=1,
                    ),
                    builds=[],
                    release_status="NOT_READY",
                ),
                build_statistics=BuildStatisticsResource(
                    id=1,
                    build=BuildResource(BuildResource),
                    total_execution=1,
                    total_passed=1,
                    total_failed=1,
                ),
                name="name_example",
                description="description_example",
                date=dateutil_parser('1970-01-01T00:00:00.00Z'),
            ),
            execution_mode="SEQUENTIAL",
            enabled_kobiton_integration=True,
            enabled_test_cloud_tunnel=True,
            trigger_mode="TESTOPS_SCHEDULER",
            browser_type="CHROME",
            xray_import_report_type="PUSH_MANUALLY",
            external_test_plan_id="external_test_plan_id_example",
            custom_field_options=[],
            tags=[
                TagResource(
                    id=1,
                    name="name_example",
                    project_id=1,
                    organization_id=1,
                ),
            ],
        ),
        exceeded_limit_time=True,
    ) # SchedulerResource | 

    # example passing only required values which don't have defaults set
    try:
        # Creates a new schedule for a Test Plan. Returns the created schedule detail.
        api_response = api_instance.create1(id, scheduler_resource)
        pprint(api_response)
    except testops_api.ApiException as e:
        print("Exception when calling TestProjectApi->create1: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**|  |
 **scheduler_resource** | [**SchedulerResource**](SchedulerResource.md)|  |

### Return type

[**SchedulerResource**](SchedulerResource.md)

### Authorization

[basicScheme](../README.md#basicScheme)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: */*

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **create_git_repo**
> GitRepositoryResource create_git_repo(git_repository_resource)

Creates a Git Test Project. Returns the Git Test Project detail.

### Example

* Basic Authentication (basicScheme):
```python
import time
import testops_api
from testops_api.api import test_project_api
from testops_api.model.git_repository_resource import GitRepositoryResource
from pprint import pprint
# Defining the host is optional and defaults to http://localhost:8443
# See configuration.py for a list of all supported configuration parameters.
configuration = testops_api.Configuration(
    host = "http://localhost:8443"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicScheme
configuration = testops_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Enter a context with an instance of the API client
with testops_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = test_project_api.TestProjectApi(api_client)
    git_repository_resource = GitRepositoryResource(
        id=1,
        test_project_id=1,
        name="name_example",
        repository="repository_example",
        branch="branch_example",
        username="username_example",
        password="password_example",
        access_key_id="access_key_id_example",
        secret_access_key="secret_access_key_example",
        project_id=1,
        team_id=1,
        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
        updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
        description="description_example",
        vcs_type="GITHUB",
        should_merge_test_results_for_new_script_repo=True,
    ) # GitRepositoryResource | 

    # example passing only required values which don't have defaults set
    try:
        # Creates a Git Test Project. Returns the Git Test Project detail.
        api_response = api_instance.create_git_repo(git_repository_resource)
        pprint(api_response)
    except testops_api.ApiException as e:
        print("Exception when calling TestProjectApi->create_git_repo: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **git_repository_resource** | [**GitRepositoryResource**](GitRepositoryResource.md)|  |

### Return type

[**GitRepositoryResource**](GitRepositoryResource.md)

### Authorization

[basicScheme](../README.md#basicScheme)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: */*

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **create_sample**
> TestProjectResource create_sample(name, type, project_id)

Creates a new sample Test Project. Returns the created Test Project.

### Example

* Basic Authentication (basicScheme):
```python
import time
import testops_api
from testops_api.api import test_project_api
from testops_api.model.test_project_resource import TestProjectResource
from pprint import pprint
# Defining the host is optional and defaults to http://localhost:8443
# See configuration.py for a list of all supported configuration parameters.
configuration = testops_api.Configuration(
    host = "http://localhost:8443"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicScheme
configuration = testops_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Enter a context with an instance of the API client
with testops_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = test_project_api.TestProjectApi(api_client)
    name = "name_example" # str | 
    type = "KS" # str | 
    project_id = 1 # int | 

    # example passing only required values which don't have defaults set
    try:
        # Creates a new sample Test Project. Returns the created Test Project.
        api_response = api_instance.create_sample(name, type, project_id)
        pprint(api_response)
    except testops_api.ApiException as e:
        print("Exception when calling TestProjectApi->create_sample: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **name** | **str**|  |
 **type** | **str**|  |
 **project_id** | **int**|  |

### Return type

[**TestProjectResource**](TestProjectResource.md)

### Authorization

[basicScheme](../README.md#basicScheme)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **create_sample_git_test_project**
> TestProjectResource create_sample_git_test_project(project_id)

Creates a new sample Git Test Project when setting up a Git Repository. Returns the created Sample Git Test Project.

### Example

* Basic Authentication (basicScheme):
```python
import time
import testops_api
from testops_api.api import test_project_api
from testops_api.model.test_project_resource import TestProjectResource
from pprint import pprint
# Defining the host is optional and defaults to http://localhost:8443
# See configuration.py for a list of all supported configuration parameters.
configuration = testops_api.Configuration(
    host = "http://localhost:8443"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicScheme
configuration = testops_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Enter a context with an instance of the API client
with testops_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = test_project_api.TestProjectApi(api_client)
    project_id = 1 # int | 
    type = "API" # str |  (optional)

    # example passing only required values which don't have defaults set
    try:
        # Creates a new sample Git Test Project when setting up a Git Repository. Returns the created Sample Git Test Project.
        api_response = api_instance.create_sample_git_test_project(project_id)
        pprint(api_response)
    except testops_api.ApiException as e:
        print("Exception when calling TestProjectApi->create_sample_git_test_project: %s\n" % e)

    # example passing only required values which don't have defaults set
    # and optional values
    try:
        # Creates a new sample Git Test Project when setting up a Git Repository. Returns the created Sample Git Test Project.
        api_response = api_instance.create_sample_git_test_project(project_id, type=type)
        pprint(api_response)
    except testops_api.ApiException as e:
        print("Exception when calling TestProjectApi->create_sample_git_test_project: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **project_id** | **int**|  |
 **type** | **str**|  | [optional]

### Return type

[**TestProjectResource**](TestProjectResource.md)

### Authorization

[basicScheme](../README.md#basicScheme)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete**
> TestProjectResource delete(id)

Deletes a Test Project. Returns the deleted Test Project.

### Example

* Basic Authentication (basicScheme):
```python
import time
import testops_api
from testops_api.api import test_project_api
from testops_api.model.test_project_resource import TestProjectResource
from pprint import pprint
# Defining the host is optional and defaults to http://localhost:8443
# See configuration.py for a list of all supported configuration parameters.
configuration = testops_api.Configuration(
    host = "http://localhost:8443"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicScheme
configuration = testops_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Enter a context with an instance of the API client
with testops_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = test_project_api.TestProjectApi(api_client)
    id = 1 # int | 

    # example passing only required values which don't have defaults set
    try:
        # Deletes a Test Project. Returns the deleted Test Project.
        api_response = api_instance.delete(id)
        pprint(api_response)
    except testops_api.ApiException as e:
        print("Exception when calling TestProjectApi->delete: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**|  |

### Return type

[**TestProjectResource**](TestProjectResource.md)

### Authorization

[basicScheme](../README.md#basicScheme)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete1**
> SchedulerResource delete1(id, scheduler_id)

Deletes a schedule. Returns the deleted schedule detail.

### Example

* Basic Authentication (basicScheme):
```python
import time
import testops_api
from testops_api.api import test_project_api
from testops_api.model.scheduler_resource import SchedulerResource
from pprint import pprint
# Defining the host is optional and defaults to http://localhost:8443
# See configuration.py for a list of all supported configuration parameters.
configuration = testops_api.Configuration(
    host = "http://localhost:8443"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicScheme
configuration = testops_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Enter a context with an instance of the API client
with testops_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = test_project_api.TestProjectApi(api_client)
    id = 1 # int | 
    scheduler_id = 1 # int | 

    # example passing only required values which don't have defaults set
    try:
        # Deletes a schedule. Returns the deleted schedule detail.
        api_response = api_instance.delete1(id, scheduler_id)
        pprint(api_response)
    except testops_api.ApiException as e:
        print("Exception when calling TestProjectApi->delete1: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**|  |
 **scheduler_id** | **int**|  |

### Return type

[**SchedulerResource**](SchedulerResource.md)

### Authorization

[basicScheme](../README.md#basicScheme)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **download**
> download(id)

Downloads a Test Project package. Returns the latest Test Project package file.

### Example

* Basic Authentication (basicScheme):
```python
import time
import testops_api
from testops_api.api import test_project_api
from pprint import pprint
# Defining the host is optional and defaults to http://localhost:8443
# See configuration.py for a list of all supported configuration parameters.
configuration = testops_api.Configuration(
    host = "http://localhost:8443"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicScheme
configuration = testops_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Enter a context with an instance of the API client
with testops_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = test_project_api.TestProjectApi(api_client)
    id = 1 # int | 

    # example passing only required values which don't have defaults set
    try:
        # Downloads a Test Project package. Returns the latest Test Project package file.
        api_instance.download(id)
    except testops_api.ApiException as e:
        print("Exception when calling TestProjectApi->download: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**|  |

### Return type

void (empty response body)

### Authorization

[basicScheme](../README.md#basicScheme)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get3**
> TestProjectResource get3(id)

Returns a Test Project detail.

### Example

* Basic Authentication (basicScheme):
```python
import time
import testops_api
from testops_api.api import test_project_api
from testops_api.model.test_project_resource import TestProjectResource
from pprint import pprint
# Defining the host is optional and defaults to http://localhost:8443
# See configuration.py for a list of all supported configuration parameters.
configuration = testops_api.Configuration(
    host = "http://localhost:8443"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicScheme
configuration = testops_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Enter a context with an instance of the API client
with testops_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = test_project_api.TestProjectApi(api_client)
    id = 1 # int | 

    # example passing only required values which don't have defaults set
    try:
        # Returns a Test Project detail.
        api_response = api_instance.get3(id)
        pprint(api_response)
    except testops_api.ApiException as e:
        print("Exception when calling TestProjectApi->get3: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**|  |

### Return type

[**TestProjectResource**](TestProjectResource.md)

### Authorization

[basicScheme](../README.md#basicScheme)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_default_test_project**
> TestProjectResource get_default_test_project(project_id)

Get default Test Project of a Project. Returns Test Project resource if exist.

### Example

* Basic Authentication (basicScheme):
```python
import time
import testops_api
from testops_api.api import test_project_api
from testops_api.model.test_project_resource import TestProjectResource
from pprint import pprint
# Defining the host is optional and defaults to http://localhost:8443
# See configuration.py for a list of all supported configuration parameters.
configuration = testops_api.Configuration(
    host = "http://localhost:8443"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicScheme
configuration = testops_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Enter a context with an instance of the API client
with testops_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = test_project_api.TestProjectApi(api_client)
    project_id = 1 # int | 

    # example passing only required values which don't have defaults set
    try:
        # Get default Test Project of a Project. Returns Test Project resource if exist.
        api_response = api_instance.get_default_test_project(project_id)
        pprint(api_response)
    except testops_api.ApiException as e:
        print("Exception when calling TestProjectApi->get_default_test_project: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **project_id** | **int**|  |

### Return type

[**TestProjectResource**](TestProjectResource.md)

### Authorization

[basicScheme](../README.md#basicScheme)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_scheduler**
> SchedulerResource get_scheduler(id, scheduler_id)

Returns a schedule detail.

### Example

* Basic Authentication (basicScheme):
```python
import time
import testops_api
from testops_api.api import test_project_api
from testops_api.model.scheduler_resource import SchedulerResource
from pprint import pprint
# Defining the host is optional and defaults to http://localhost:8443
# See configuration.py for a list of all supported configuration parameters.
configuration = testops_api.Configuration(
    host = "http://localhost:8443"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicScheme
configuration = testops_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Enter a context with an instance of the API client
with testops_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = test_project_api.TestProjectApi(api_client)
    id = 1 # int | 
    scheduler_id = 1 # int | 

    # example passing only required values which don't have defaults set
    try:
        # Returns a schedule detail.
        api_response = api_instance.get_scheduler(id, scheduler_id)
        pprint(api_response)
    except testops_api.ApiException as e:
        print("Exception when calling TestProjectApi->get_scheduler: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**|  |
 **scheduler_id** | **int**|  |

### Return type

[**SchedulerResource**](SchedulerResource.md)

### Authorization

[basicScheme](../README.md#basicScheme)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_test_project_git**
> GitRepositoryResource get_test_project_git(test_project_git_id)

Returns a Git Test Project detail.

### Example

* Basic Authentication (basicScheme):
```python
import time
import testops_api
from testops_api.api import test_project_api
from testops_api.model.git_repository_resource import GitRepositoryResource
from pprint import pprint
# Defining the host is optional and defaults to http://localhost:8443
# See configuration.py for a list of all supported configuration parameters.
configuration = testops_api.Configuration(
    host = "http://localhost:8443"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicScheme
configuration = testops_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Enter a context with an instance of the API client
with testops_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = test_project_api.TestProjectApi(api_client)
    test_project_git_id = 1 # int | 

    # example passing only required values which don't have defaults set
    try:
        # Returns a Git Test Project detail.
        api_response = api_instance.get_test_project_git(test_project_git_id)
        pprint(api_response)
    except testops_api.ApiException as e:
        print("Exception when calling TestProjectApi->get_test_project_git: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **test_project_git_id** | **int**|  |

### Return type

[**GitRepositoryResource**](GitRepositoryResource.md)

### Authorization

[basicScheme](../README.md#basicScheme)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **refresh_tsc**
> refresh_tsc(id)

Refresh Test Suite Collection list of Git Test Project

### Example

* Basic Authentication (basicScheme):
```python
import time
import testops_api
from testops_api.api import test_project_api
from pprint import pprint
# Defining the host is optional and defaults to http://localhost:8443
# See configuration.py for a list of all supported configuration parameters.
configuration = testops_api.Configuration(
    host = "http://localhost:8443"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicScheme
configuration = testops_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Enter a context with an instance of the API client
with testops_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = test_project_api.TestProjectApi(api_client)
    id = 1 # int | 

    # example passing only required values which don't have defaults set
    try:
        # Refresh Test Suite Collection list of Git Test Project
        api_instance.refresh_tsc(id)
    except testops_api.ApiException as e:
        print("Exception when calling TestProjectApi->refresh_tsc: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**|  |

### Return type

void (empty response body)

### Authorization

[basicScheme](../README.md#basicScheme)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**204** | No Content |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **run**
> [BuildInfo] run(id)

Executes a Test Plan. Returns the build information.

### Example

* Basic Authentication (basicScheme):
```python
import time
import testops_api
from testops_api.api import test_project_api
from testops_api.model.build_info import BuildInfo
from pprint import pprint
# Defining the host is optional and defaults to http://localhost:8443
# See configuration.py for a list of all supported configuration parameters.
configuration = testops_api.Configuration(
    host = "http://localhost:8443"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicScheme
configuration = testops_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Enter a context with an instance of the API client
with testops_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = test_project_api.TestProjectApi(api_client)
    id = 1 # int | 

    # example passing only required values which don't have defaults set
    try:
        # Executes a Test Plan. Returns the build information.
        api_response = api_instance.run(id)
        pprint(api_response)
    except testops_api.ApiException as e:
        print("Exception when calling TestProjectApi->run: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**|  |

### Return type

[**[BuildInfo]**](BuildInfo.md)

### Authorization

[basicScheme](../README.md#basicScheme)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update**
> TestProjectResource update(id, test_project_resource)

Updates a Test Project detail. Returns the updated Test Project detail.

### Example

* Basic Authentication (basicScheme):
```python
import time
import testops_api
from testops_api.api import test_project_api
from testops_api.model.test_project_resource import TestProjectResource
from pprint import pprint
# Defining the host is optional and defaults to http://localhost:8443
# See configuration.py for a list of all supported configuration parameters.
configuration = testops_api.Configuration(
    host = "http://localhost:8443"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicScheme
configuration = testops_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Enter a context with an instance of the API client
with testops_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = test_project_api.TestProjectApi(api_client)
    id = 1 # int | 
    test_project_resource = TestProjectResource(
        id=1,
        name="name_example",
        description="description_example",
        default_test_project=True,
        upload_file_id=1,
        project_id=1,
        team_id=1,
        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
        latest_job=JobResource(
            id=1,
            build_number=1,
            status="QUEUED",
            queued_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
            start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
            stop_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
            test_project=TestProjectResource(TestProjectResource),
            execution=ExecutionResource(
                status="PASSED",
                start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                end_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                duration=1,
                elapsed_duration=1,
                total_tests=1,
                total_passed_tests=1,
                total_failed_tests=1,
                total_error_tests=1,
                total_incomplete_tests=1,
                total_skipped_tests=1,
                total_diff_tests=1,
                total_diff_passed_tests=1,
                total_diff_failed_tests=1,
                total_diff_error_tests=1,
                total_diff_incomplete_tests=1,
                id=1,
                project_id=1,
                project=ProjectResource(
                    id=1,
                    name="name_example",
                    team_id=1,
                    team=TeamResource(
                        id=1,
                        name="name_example",
                        role="OWNER",
                        users=[
                            UserResource(
                                id=1,
                                email="email_example",
                                first_name="first_name_example",
                                last_name="last_name_example",
                                password="password_example",
                                inviting_url="inviting_url_example",
                                avatar="avatar_example",
                                configs=ConfigResource(
                                    web_socket_url="web_socket_url_example",
                                    store_url="store_url_example",
                                    profiles=[
                                        "profiles_example",
                                    ],
                                    stripe_public_api="stripe_public_api_example",
                                    build_version="build_version_example",
                                    commit_id="commit_id_example",
                                    sentry_dsn="sentry_dsn_example",
                                    sentry_env="sentry_env_example",
                                    sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                                    server_url="server_url_example",
                                    io_server_url="io_server_url_example",
                                    proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                                    max_execution_comparison=1,
                                    max_execution_download=1,
                                    agent_download_urls={
                                        "key": "key_example",
                                    },
                                    proxy_tunnel_download_urls={
                                        "key": "key_example",
                                    },
                                    report_uploader_download_url="report_uploader_download_url_example",
                                    report_uploader_latest_version="report_uploader_latest_version_example",
                                    sub_domain_pattern="sub_domain_pattern_example",
                                    cancellation_survey_url="cancellation_survey_url_example",
                                    launch_darkly_client_id="launch_darkly_client_id_example",
                                    launch_darkly_default_user="launch_darkly_default_user_example",
                                    launch_darkly_prefix="launch_darkly_prefix_example",
                                    min_test_execution_ordered=1,
                                    user_flow_token="user_flow_token_example",
                                    demo_project_url="demo_project_url_example",
                                    advanced_feature_enabled=True,
                                    using_sub_domain=True,
                                    test_ops_subscription_enabled=True,
                                    frameworks_integration_enabled=True,
                                ),
                                projects=[
                                    ProjectResource(ProjectResource),
                                ],
                                teams=[
                                    TeamResource(TeamResource),
                                ],
                                organizations=[
                                    OrganizationResource(
                                        id=1,
                                        name="name_example",
                                        role="OWNER",
                                        org_feature_flag=OrganizationFeatureFlagResource(
                                            organization_id=1,
                                            sub_domain=True,
                                            strict_domain=True,
                                            sso=True,
                                            whitelist_ip=True,
                                            circle_ci=True,
                                            test_ops_integration=True,
                                        ),
                                        quota_kse=1,
                                        machine_quota_kse=1,
                                        quota_unlimited_kse=1,
                                        quota_engine=1,
                                        machine_quota_engine=1,
                                        quota_unlimited_engine=1,
                                        used_kse=1,
                                        used_unlimited_kse=1,
                                        used_engine=1,
                                        used_unlimited_engine=1,
                                        quota_test_ops=1,
                                        used_test_ops=1,
                                        number_user=1,
                                        quota_floating_engine=1,
                                        used_floating_engine=1,
                                        can_create_offline_kse=True,
                                        can_create_offline_unlimited_kse=True,
                                        can_create_offline_re=True,
                                        can_create_offline_unlimited_engine=True,
                                        subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscribed=True,
                                        kse_paygo=True,
                                        kre_paygo=True,
                                        paygo_quota=1,
                                        domain="domain_example",
                                        subdomain_url="subdomain_url_example",
                                        strict_domain=True,
                                        logo_url="logo_url_example",
                                        saml_sso=True,
                                        kre_license=True,
                                        most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        account_id=1,
                                        test_ops_feature="KSE",
                                        platform_feature="KSE",
                                        tier="FREE",
                                        requested_user_verified=True,
                                    ),
                                ],
                                organization_feature=[
                                    UserOrganizationFeatureResource(
                                        user=UserResource(UserResource),
                                        user_id=1,
                                        organization_id=1,
                                        user_email="user_email_example",
                                        organization=OrganizationResource(
                                            id=1,
                                            name="name_example",
                                            role="OWNER",
                                            org_feature_flag=OrganizationFeatureFlagResource(
                                                organization_id=1,
                                                sub_domain=True,
                                                strict_domain=True,
                                                sso=True,
                                                whitelist_ip=True,
                                                circle_ci=True,
                                                test_ops_integration=True,
                                            ),
                                            quota_kse=1,
                                            machine_quota_kse=1,
                                            quota_unlimited_kse=1,
                                            quota_engine=1,
                                            machine_quota_engine=1,
                                            quota_unlimited_engine=1,
                                            used_kse=1,
                                            used_unlimited_kse=1,
                                            used_engine=1,
                                            used_unlimited_engine=1,
                                            quota_test_ops=1,
                                            used_test_ops=1,
                                            number_user=1,
                                            quota_floating_engine=1,
                                            used_floating_engine=1,
                                            can_create_offline_kse=True,
                                            can_create_offline_unlimited_kse=True,
                                            can_create_offline_re=True,
                                            can_create_offline_unlimited_engine=True,
                                            subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            subscribed=True,
                                            kse_paygo=True,
                                            kre_paygo=True,
                                            paygo_quota=1,
                                            domain="domain_example",
                                            subdomain_url="subdomain_url_example",
                                            strict_domain=True,
                                            logo_url="logo_url_example",
                                            saml_sso=True,
                                            kre_license=True,
                                            most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            account_id=1,
                                            test_ops_feature="KSE",
                                            platform_feature="KSE",
                                            tier="FREE",
                                            requested_user_verified=True,
                                        ),
                                        feature="KSE",
                                    ),
                                ],
                                trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                system_role="USER",
                                survey_status="NOT_SUBMITTED",
                                session_timeout=1,
                                business_user=True,
                                can_create_offline_kse=True,
                                can_create_offline_re=True,
                                saml_sso=True,
                                created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                full_name="full_name_example",
                            ),
                        ],
                        organization=OrganizationResource(
                            id=1,
                            name="name_example",
                            role="OWNER",
                            org_feature_flag=OrganizationFeatureFlagResource(
                                organization_id=1,
                                sub_domain=True,
                                strict_domain=True,
                                sso=True,
                                whitelist_ip=True,
                                circle_ci=True,
                                test_ops_integration=True,
                            ),
                            quota_kse=1,
                            machine_quota_kse=1,
                            quota_unlimited_kse=1,
                            quota_engine=1,
                            machine_quota_engine=1,
                            quota_unlimited_engine=1,
                            used_kse=1,
                            used_unlimited_kse=1,
                            used_engine=1,
                            used_unlimited_engine=1,
                            quota_test_ops=1,
                            used_test_ops=1,
                            number_user=1,
                            quota_floating_engine=1,
                            used_floating_engine=1,
                            can_create_offline_kse=True,
                            can_create_offline_unlimited_kse=True,
                            can_create_offline_re=True,
                            can_create_offline_unlimited_engine=True,
                            subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscribed=True,
                            kse_paygo=True,
                            kre_paygo=True,
                            paygo_quota=1,
                            domain="domain_example",
                            subdomain_url="subdomain_url_example",
                            strict_domain=True,
                            logo_url="logo_url_example",
                            saml_sso=True,
                            kre_license=True,
                            most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            account_id=1,
                            test_ops_feature="KSE",
                            platform_feature="KSE",
                            tier="FREE",
                            requested_user_verified=True,
                        ),
                        organization_id=1,
                    ),
                    timezone="timezone_example",
                    status="ARCHIVE",
                ),
                build_id=1,
                order=1,
                execution_stage="RUNNING",
                web_url="web_url_example",
                test_suite_collections=[
                    TestSuiteCollectionEntityResource(
                        id=1,
                        name="name_example",
                        project=ProjectResource(
                            id=1,
                            name="name_example",
                            team_id=1,
                            team=TeamResource(
                                id=1,
                                name="name_example",
                                role="OWNER",
                                users=[],
                                organization=OrganizationResource(
                                    id=1,
                                    name="name_example",
                                    role="OWNER",
                                    org_feature_flag=OrganizationFeatureFlagResource(
                                        organization_id=1,
                                        sub_domain=True,
                                        strict_domain=True,
                                        sso=True,
                                        whitelist_ip=True,
                                        circle_ci=True,
                                        test_ops_integration=True,
                                    ),
                                    quota_kse=1,
                                    machine_quota_kse=1,
                                    quota_unlimited_kse=1,
                                    quota_engine=1,
                                    machine_quota_engine=1,
                                    quota_unlimited_engine=1,
                                    used_kse=1,
                                    used_unlimited_kse=1,
                                    used_engine=1,
                                    used_unlimited_engine=1,
                                    quota_test_ops=1,
                                    used_test_ops=1,
                                    number_user=1,
                                    quota_floating_engine=1,
                                    used_floating_engine=1,
                                    can_create_offline_kse=True,
                                    can_create_offline_unlimited_kse=True,
                                    can_create_offline_re=True,
                                    can_create_offline_unlimited_engine=True,
                                    subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscribed=True,
                                    kse_paygo=True,
                                    kre_paygo=True,
                                    paygo_quota=1,
                                    domain="domain_example",
                                    subdomain_url="subdomain_url_example",
                                    strict_domain=True,
                                    logo_url="logo_url_example",
                                    saml_sso=True,
                                    kre_license=True,
                                    most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    account_id=1,
                                    test_ops_feature="KSE",
                                    platform_feature="KSE",
                                    tier="FREE",
                                    requested_user_verified=True,
                                ),
                                organization_id=1,
                            ),
                            timezone="timezone_example",
                            status="ARCHIVE",
                        ),
                        path="path_example",
                        url_id="url_id_example",
                    ),
                ],
                execution_test_suite_resources=[
                    ExecutionTestSuiteResource(
                        status="PASSED",
                        start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        end_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        duration=1,
                        elapsed_duration=1,
                        total_tests=1,
                        total_passed_tests=1,
                        total_failed_tests=1,
                        total_error_tests=1,
                        total_incomplete_tests=1,
                        total_skipped_tests=1,
                        total_diff_tests=1,
                        total_diff_passed_tests=1,
                        total_diff_failed_tests=1,
                        total_diff_error_tests=1,
                        total_diff_incomplete_tests=1,
                        id=1,
                        execution=ExecutionResource(ExecutionResource),
                        test_suite=TestSuiteResource(
                            id=1,
                            name="name_example",
                            path="path_example",
                            test_results=[
                                ExecutionTestResultResource(
                                    id=1,
                                    test_case=TestCaseResource(
                                        id=1,
                                        name="name_example",
                                        path="path_example",
                                        previous_status="PASSED",
                                        alias="alias_example",
                                        test_module_id=1,
                                        web_url="web_url_example",
                                        description="description_example",
                                        project=ProjectResource(
                                            id=1,
                                            name="name_example",
                                            team_id=1,
                                            team=TeamResource(
                                                id=1,
                                                name="name_example",
                                                role="OWNER",
                                                users=[],
                                                organization=OrganizationResource(
                                                    id=1,
                                                    name="name_example",
                                                    role="OWNER",
                                                    org_feature_flag=OrganizationFeatureFlagResource(
                                                        organization_id=1,
                                                        sub_domain=True,
                                                        strict_domain=True,
                                                        sso=True,
                                                        whitelist_ip=True,
                                                        circle_ci=True,
                                                        test_ops_integration=True,
                                                    ),
                                                    quota_kse=1,
                                                    machine_quota_kse=1,
                                                    quota_unlimited_kse=1,
                                                    quota_engine=1,
                                                    machine_quota_engine=1,
                                                    quota_unlimited_engine=1,
                                                    used_kse=1,
                                                    used_unlimited_kse=1,
                                                    used_engine=1,
                                                    used_unlimited_engine=1,
                                                    quota_test_ops=1,
                                                    used_test_ops=1,
                                                    number_user=1,
                                                    quota_floating_engine=1,
                                                    used_floating_engine=1,
                                                    can_create_offline_kse=True,
                                                    can_create_offline_unlimited_kse=True,
                                                    can_create_offline_re=True,
                                                    can_create_offline_unlimited_engine=True,
                                                    subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    subscribed=True,
                                                    kse_paygo=True,
                                                    kre_paygo=True,
                                                    paygo_quota=1,
                                                    domain="domain_example",
                                                    subdomain_url="subdomain_url_example",
                                                    strict_domain=True,
                                                    logo_url="logo_url_example",
                                                    saml_sso=True,
                                                    kre_license=True,
                                                    most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    account_id=1,
                                                    test_ops_feature="KSE",
                                                    platform_feature="KSE",
                                                    tier="FREE",
                                                    requested_user_verified=True,
                                                ),
                                                organization_id=1,
                                            ),
                                            timezone="timezone_example",
                                            status="ARCHIVE",
                                        ),
                                        last_execution_test_case=ExecutionTestCaseResource(
                                            status="PASSED",
                                            start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            end_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            duration=1,
                                            elapsed_duration=1,
                                            total_tests=1,
                                            total_passed_tests=1,
                                            total_failed_tests=1,
                                            total_error_tests=1,
                                            total_incomplete_tests=1,
                                            total_skipped_tests=1,
                                            total_diff_tests=1,
                                            total_diff_passed_tests=1,
                                            total_diff_failed_tests=1,
                                            total_diff_error_tests=1,
                                            total_diff_incomplete_tests=1,
                                            execution_id=1,
                                            execution_order=1,
                                            test_case_id=1,
                                            project_id=1,
                                        ),
                                        external_issues=[
                                            ExternalIssueResource(
                                                id=1,
                                                issue_id="issue_id_example",
                                                summary="summary_example",
                                                status="status_example",
                                                issue_type_icon="issue_type_icon_example",
                                                issue_type_name="issue_type_name_example",
                                                url="url_example",
                                                feature_name="feature_name_example",
                                                test_cases=[
                                                    TestCaseResource(TestCaseResource),
                                                ],
                                            ),
                                        ],
                                        custom_field_options=[
                                            CustomFieldOptionResource(
                                                id=1,
                                                value="value_example",
                                                created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                definition_id=1,
                                            ),
                                        ],
                                        type="TEST_CASE",
                                        average_duration=3.14,
                                        max_duration=1,
                                        min_duration=1,
                                        flakiness=3.14,
                                        platform_statistics={
                                            "key": TestCasePlatformStatisticsResource(
                                                total_tests=1,
                                                total_passed_tests=1,
                                                total_failed_tests=1,
                                                total_error_tests=1,
                                                total_incomplete_tests=1,
                                                total_skipped_tests=1,
                                                platform=PlatformResource(
                                                    id=1,
                                                    os_name="os_name_example",
                                                    os_version="os_version_example",
                                                    browser_name="browser_name_example",
                                                    browser_version="browser_version_example",
                                                    device_name="device_name_example",
                                                    app_name="app_name_example",
                                                ),
                                                platform_id=1,
                                            ),
                                        },
                                        maintainer=UserResource(
                                            id=1,
                                            email="email_example",
                                            first_name="first_name_example",
                                            last_name="last_name_example",
                                            password="password_example",
                                            inviting_url="inviting_url_example",
                                            avatar="avatar_example",
                                            configs=ConfigResource(
                                                web_socket_url="web_socket_url_example",
                                                store_url="store_url_example",
                                                profiles=[],
                                                stripe_public_api="stripe_public_api_example",
                                                build_version="build_version_example",
                                                commit_id="commit_id_example",
                                                sentry_dsn="sentry_dsn_example",
                                                sentry_env="sentry_env_example",
                                                sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                                                server_url="server_url_example",
                                                io_server_url="io_server_url_example",
                                                proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                                                max_execution_comparison=1,
                                                max_execution_download=1,
                                                agent_download_urls={},
                                                proxy_tunnel_download_urls={},
                                                report_uploader_download_url="report_uploader_download_url_example",
                                                report_uploader_latest_version="report_uploader_latest_version_example",
                                                sub_domain_pattern="sub_domain_pattern_example",
                                                cancellation_survey_url="cancellation_survey_url_example",
                                                launch_darkly_client_id="launch_darkly_client_id_example",
                                                launch_darkly_default_user="launch_darkly_default_user_example",
                                                launch_darkly_prefix="launch_darkly_prefix_example",
                                                min_test_execution_ordered=1,
                                                user_flow_token="user_flow_token_example",
                                                demo_project_url="demo_project_url_example",
                                                advanced_feature_enabled=True,
                                                using_sub_domain=True,
                                                test_ops_subscription_enabled=True,
                                                frameworks_integration_enabled=True,
                                            ),
                                            projects=[],
                                            teams=[],
                                            organizations=[],
                                            organization_feature=[],
                                            trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            system_role="USER",
                                            survey_status="NOT_SUBMITTED",
                                            session_timeout=1,
                                            business_user=True,
                                            can_create_offline_kse=True,
                                            can_create_offline_re=True,
                                            saml_sso=True,
                                            created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            full_name="full_name_example",
                                        ),
                                        test_result_assertion=TestResultAssertionResource(
                                            execution_test_result_id=1,
                                            execution_test_result=ExecutionTestResultResource(ExecutionTestResultResource),
                                            total_assertion=1,
                                            passed_assertion=1,
                                            failed_assertion=1,
                                        ),
                                        updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        test_project=TestProjectResource(TestProjectResource),
                                        number_of_executions=1,
                                        url_id="url_id_example",
                                    ),
                                    execution=ExecutionResource(ExecutionResource),
                                    platform=PlatformResource(
                                        id=1,
                                        os_name="os_name_example",
                                        os_version="os_version_example",
                                        browser_name="browser_name_example",
                                        browser_version="browser_version_example",
                                        device_name="device_name_example",
                                        app_name="app_name_example",
                                    ),
                                    status="PASSED",
                                    same_status_period=1,
                                    error_details_id=1,
                                    stdout_id=1,
                                    description_id=1,
                                    log_id=1,
                                    attachments=[
                                        FileResource(
                                            id=1,
                                            upload_file_id=1,
                                            _self="_self_example",
                                            name="name_example",
                                            path="path_example",
                                            url="url_example",
                                            hash="hash_example",
                                            size=1,
                                            upload_url="upload_url_example",
                                            signed_url="signed_url_example",
                                            thumbnail_url="thumbnail_url_example",
                                        ),
                                    ],
                                    test_result_assertions_failed=[
                                        TestResultAssertionFailedResource(
                                            id=1,
                                            execution_test_result_id=1,
                                            execution_test_result_resource=ExecutionTestResultResource(ExecutionTestResultResource),
                                            stacktrace="stacktrace_example",
                                            message="message_example",
                                            log_time="log_time_example",
                                        ),
                                    ],
                                    start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    end_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    duration=1,
                                    same_failure_results=[
                                        ExecutionTestResultIdentifyResource(
                                            id=1,
                                            execution_id=1,
                                            url_id="url_id_example",
                                        ),
                                    ],
                                    test_suite=TestSuiteResource(TestSuiteResource),
                                    execution_test_suite=ExecutionTestSuiteResource(ExecutionTestSuiteResource),
                                    incidents=[
                                        IncidentResource(
                                            id=1,
                                            name="name_example",
                                            description="description_example",
                                            project_id=1,
                                            team_id=1,
                                            url_ids=[
                                                "url_ids_example",
                                            ],
                                            execution_test_result_ids=[
                                                1,
                                            ],
                                            order=1,
                                            created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        ),
                                    ],
                                    profile="profile_example",
                                    has_comment=True,
                                    error_message="error_message_example",
                                    error_detail="error_detail_example",
                                    web_url="web_url_example",
                                    external_issues=[],
                                    failed_test_result_category="APPLICATION",
                                    total_test_object=1,
                                    total_defects=1,
                                    total_assertion=1,
                                    passed_assertion=1,
                                    failed_assertion=1,
                                    retried=True,
                                    last_retry_test_id=1,
                                    current_retry=1,
                                    original_status="PASSED",
                                    last_changed_by=UserResource(
                                        id=1,
                                        email="email_example",
                                        first_name="first_name_example",
                                        last_name="last_name_example",
                                        password="password_example",
                                        inviting_url="inviting_url_example",
                                        avatar="avatar_example",
                                        configs=ConfigResource(
                                            web_socket_url="web_socket_url_example",
                                            store_url="store_url_example",
                                            profiles=[],
                                            stripe_public_api="stripe_public_api_example",
                                            build_version="build_version_example",
                                            commit_id="commit_id_example",
                                            sentry_dsn="sentry_dsn_example",
                                            sentry_env="sentry_env_example",
                                            sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                                            server_url="server_url_example",
                                            io_server_url="io_server_url_example",
                                            proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                                            max_execution_comparison=1,
                                            max_execution_download=1,
                                            agent_download_urls={},
                                            proxy_tunnel_download_urls={},
                                            report_uploader_download_url="report_uploader_download_url_example",
                                            report_uploader_latest_version="report_uploader_latest_version_example",
                                            sub_domain_pattern="sub_domain_pattern_example",
                                            cancellation_survey_url="cancellation_survey_url_example",
                                            launch_darkly_client_id="launch_darkly_client_id_example",
                                            launch_darkly_default_user="launch_darkly_default_user_example",
                                            launch_darkly_prefix="launch_darkly_prefix_example",
                                            min_test_execution_ordered=1,
                                            user_flow_token="user_flow_token_example",
                                            demo_project_url="demo_project_url_example",
                                            advanced_feature_enabled=True,
                                            using_sub_domain=True,
                                            test_ops_subscription_enabled=True,
                                            frameworks_integration_enabled=True,
                                        ),
                                        projects=[],
                                        teams=[],
                                        organizations=[],
                                        organization_feature=[],
                                        trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        system_role="USER",
                                        survey_status="NOT_SUBMITTED",
                                        session_timeout=1,
                                        business_user=True,
                                        can_create_offline_kse=True,
                                        can_create_offline_re=True,
                                        saml_sso=True,
                                        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        full_name="full_name_example",
                                    ),
                                    error_keyword="error_keyword_example",
                                    status_edited=True,
                                    url_id="url_id_example",
                                ),
                            ],
                            project=ProjectResource(
                                id=1,
                                name="name_example",
                                team_id=1,
                                team=TeamResource(
                                    id=1,
                                    name="name_example",
                                    role="OWNER",
                                    users=[],
                                    organization=OrganizationResource(
                                        id=1,
                                        name="name_example",
                                        role="OWNER",
                                        org_feature_flag=OrganizationFeatureFlagResource(
                                            organization_id=1,
                                            sub_domain=True,
                                            strict_domain=True,
                                            sso=True,
                                            whitelist_ip=True,
                                            circle_ci=True,
                                            test_ops_integration=True,
                                        ),
                                        quota_kse=1,
                                        machine_quota_kse=1,
                                        quota_unlimited_kse=1,
                                        quota_engine=1,
                                        machine_quota_engine=1,
                                        quota_unlimited_engine=1,
                                        used_kse=1,
                                        used_unlimited_kse=1,
                                        used_engine=1,
                                        used_unlimited_engine=1,
                                        quota_test_ops=1,
                                        used_test_ops=1,
                                        number_user=1,
                                        quota_floating_engine=1,
                                        used_floating_engine=1,
                                        can_create_offline_kse=True,
                                        can_create_offline_unlimited_kse=True,
                                        can_create_offline_re=True,
                                        can_create_offline_unlimited_engine=True,
                                        subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscribed=True,
                                        kse_paygo=True,
                                        kre_paygo=True,
                                        paygo_quota=1,
                                        domain="domain_example",
                                        subdomain_url="subdomain_url_example",
                                        strict_domain=True,
                                        logo_url="logo_url_example",
                                        saml_sso=True,
                                        kre_license=True,
                                        most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        account_id=1,
                                        test_ops_feature="KSE",
                                        platform_feature="KSE",
                                        tier="FREE",
                                        requested_user_verified=True,
                                    ),
                                    organization_id=1,
                                ),
                                timezone="timezone_example",
                                status="ARCHIVE",
                            ),
                            alias="alias_example",
                            last_execution_test_suite=ExecutionTestSuiteResource(ExecutionTestSuiteResource),
                            updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            test_cases=[],
                            test_project=TestProjectResource(TestProjectResource),
                            created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            user=UserResource(
                                id=1,
                                email="email_example",
                                first_name="first_name_example",
                                last_name="last_name_example",
                                password="password_example",
                                inviting_url="inviting_url_example",
                                avatar="avatar_example",
                                configs=ConfigResource(
                                    web_socket_url="web_socket_url_example",
                                    store_url="store_url_example",
                                    profiles=[],
                                    stripe_public_api="stripe_public_api_example",
                                    build_version="build_version_example",
                                    commit_id="commit_id_example",
                                    sentry_dsn="sentry_dsn_example",
                                    sentry_env="sentry_env_example",
                                    sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                                    server_url="server_url_example",
                                    io_server_url="io_server_url_example",
                                    proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                                    max_execution_comparison=1,
                                    max_execution_download=1,
                                    agent_download_urls={},
                                    proxy_tunnel_download_urls={},
                                    report_uploader_download_url="report_uploader_download_url_example",
                                    report_uploader_latest_version="report_uploader_latest_version_example",
                                    sub_domain_pattern="sub_domain_pattern_example",
                                    cancellation_survey_url="cancellation_survey_url_example",
                                    launch_darkly_client_id="launch_darkly_client_id_example",
                                    launch_darkly_default_user="launch_darkly_default_user_example",
                                    launch_darkly_prefix="launch_darkly_prefix_example",
                                    min_test_execution_ordered=1,
                                    user_flow_token="user_flow_token_example",
                                    demo_project_url="demo_project_url_example",
                                    advanced_feature_enabled=True,
                                    using_sub_domain=True,
                                    test_ops_subscription_enabled=True,
                                    frameworks_integration_enabled=True,
                                ),
                                projects=[],
                                teams=[],
                                organizations=[],
                                organization_feature=[],
                                trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                system_role="USER",
                                survey_status="NOT_SUBMITTED",
                                session_timeout=1,
                                business_user=True,
                                can_create_offline_kse=True,
                                can_create_offline_re=True,
                                saml_sso=True,
                                created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                full_name="full_name_example",
                            ),
                            type="KATALON_STUDIO",
                            test_folder=TestFolderResource(
                                id=1,
                                name="name_example",
                                raw_path="raw_path_example",
                                test_project=TestProjectResource(TestProjectResource),
                                tree_path="tree_path_example",
                                parent_id=1,
                            ),
                            url_id="url_id_example",
                        ),
                        platform=PlatformResource(
                            id=1,
                            os_name="os_name_example",
                            os_version="os_version_example",
                            browser_name="browser_name_example",
                            browser_version="browser_version_example",
                            device_name="device_name_example",
                            app_name="app_name_example",
                        ),
                        execution_id=1,
                        profiles=[],
                        has_comment=True,
                        url_id="url_id_example",
                    ),
                ],
                release=ReleaseResource(
                    id=1,
                    name="name_example",
                    start_time=dateutil_parser('1970-01-01').date(),
                    end_time=dateutil_parser('1970-01-01').date(),
                    description="description_example",
                    project_id=1,
                    closed=True,
                    created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    external_release=ExternalReleaseResource(
                        id=1,
                        release_id="release_id_example",
                        description="description_example",
                        name="name_example",
                        archived=True,
                        released=True,
                        project_id="project_id_example",
                        external_project=ExternalProjectResource(
                            id=1,
                            external_project_id="external_project_id_example",
                            external_project_key="external_project_key_example",
                            name="name_example",
                        ),
                        web_url="web_url_example",
                        jira_release_status="RELEASED",
                        start_date=dateutil_parser('1970-01-01').date(),
                        release_date=dateutil_parser('1970-01-01').date(),
                    ),
                    release_statistics=ReleaseStatisticsResource(
                        id=1,
                        release=ReleaseResource(ReleaseResource),
                        total_passed=1,
                        total_failed=1,
                        total_execution=1,
                        total_defect=1,
                        total_duration=1,
                    ),
                    builds=[
                        BuildResource(
                            id=1,
                            project_id=1,
                            project=ProjectResource(
                                id=1,
                                name="name_example",
                                team_id=1,
                                team=TeamResource(
                                    id=1,
                                    name="name_example",
                                    role="OWNER",
                                    users=[],
                                    organization=OrganizationResource(
                                        id=1,
                                        name="name_example",
                                        role="OWNER",
                                        org_feature_flag=OrganizationFeatureFlagResource(
                                            organization_id=1,
                                            sub_domain=True,
                                            strict_domain=True,
                                            sso=True,
                                            whitelist_ip=True,
                                            circle_ci=True,
                                            test_ops_integration=True,
                                        ),
                                        quota_kse=1,
                                        machine_quota_kse=1,
                                        quota_unlimited_kse=1,
                                        quota_engine=1,
                                        machine_quota_engine=1,
                                        quota_unlimited_engine=1,
                                        used_kse=1,
                                        used_unlimited_kse=1,
                                        used_engine=1,
                                        used_unlimited_engine=1,
                                        quota_test_ops=1,
                                        used_test_ops=1,
                                        number_user=1,
                                        quota_floating_engine=1,
                                        used_floating_engine=1,
                                        can_create_offline_kse=True,
                                        can_create_offline_unlimited_kse=True,
                                        can_create_offline_re=True,
                                        can_create_offline_unlimited_engine=True,
                                        subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscribed=True,
                                        kse_paygo=True,
                                        kre_paygo=True,
                                        paygo_quota=1,
                                        domain="domain_example",
                                        subdomain_url="subdomain_url_example",
                                        strict_domain=True,
                                        logo_url="logo_url_example",
                                        saml_sso=True,
                                        kre_license=True,
                                        most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        account_id=1,
                                        test_ops_feature="KSE",
                                        platform_feature="KSE",
                                        tier="FREE",
                                        requested_user_verified=True,
                                    ),
                                    organization_id=1,
                                ),
                                timezone="timezone_example",
                                status="ARCHIVE",
                            ),
                            release_id=1,
                            release=ReleaseResource(ReleaseResource),
                            build_statistics=BuildStatisticsResource(
                                id=1,
                                build=BuildResource(BuildResource),
                                total_execution=1,
                                total_passed=1,
                                total_failed=1,
                            ),
                            name="name_example",
                            description="description_example",
                            date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        ),
                    ],
                    release_status="NOT_READY",
                ),
                build=BuildResource(
                    id=1,
                    project_id=1,
                    project=ProjectResource(
                        id=1,
                        name="name_example",
                        team_id=1,
                        team=TeamResource(
                            id=1,
                            name="name_example",
                            role="OWNER",
                            users=[],
                            organization=OrganizationResource(
                                id=1,
                                name="name_example",
                                role="OWNER",
                                org_feature_flag=OrganizationFeatureFlagResource(
                                    organization_id=1,
                                    sub_domain=True,
                                    strict_domain=True,
                                    sso=True,
                                    whitelist_ip=True,
                                    circle_ci=True,
                                    test_ops_integration=True,
                                ),
                                quota_kse=1,
                                machine_quota_kse=1,
                                quota_unlimited_kse=1,
                                quota_engine=1,
                                machine_quota_engine=1,
                                quota_unlimited_engine=1,
                                used_kse=1,
                                used_unlimited_kse=1,
                                used_engine=1,
                                used_unlimited_engine=1,
                                quota_test_ops=1,
                                used_test_ops=1,
                                number_user=1,
                                quota_floating_engine=1,
                                used_floating_engine=1,
                                can_create_offline_kse=True,
                                can_create_offline_unlimited_kse=True,
                                can_create_offline_re=True,
                                can_create_offline_unlimited_engine=True,
                                subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscribed=True,
                                kse_paygo=True,
                                kre_paygo=True,
                                paygo_quota=1,
                                domain="domain_example",
                                subdomain_url="subdomain_url_example",
                                strict_domain=True,
                                logo_url="logo_url_example",
                                saml_sso=True,
                                kre_license=True,
                                most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                account_id=1,
                                test_ops_feature="KSE",
                                platform_feature="KSE",
                                tier="FREE",
                                requested_user_verified=True,
                            ),
                            organization_id=1,
                        ),
                        timezone="timezone_example",
                        status="ARCHIVE",
                    ),
                    release_id=1,
                    release=ReleaseResource(
                        id=1,
                        name="name_example",
                        start_time=dateutil_parser('1970-01-01').date(),
                        end_time=dateutil_parser('1970-01-01').date(),
                        description="description_example",
                        project_id=1,
                        closed=True,
                        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        external_release=ExternalReleaseResource(
                            id=1,
                            release_id="release_id_example",
                            description="description_example",
                            name="name_example",
                            archived=True,
                            released=True,
                            project_id="project_id_example",
                            external_project=ExternalProjectResource(
                                id=1,
                                external_project_id="external_project_id_example",
                                external_project_key="external_project_key_example",
                                name="name_example",
                            ),
                            web_url="web_url_example",
                            jira_release_status="RELEASED",
                            start_date=dateutil_parser('1970-01-01').date(),
                            release_date=dateutil_parser('1970-01-01').date(),
                        ),
                        release_statistics=ReleaseStatisticsResource(
                            id=1,
                            release=ReleaseResource(ReleaseResource),
                            total_passed=1,
                            total_failed=1,
                            total_execution=1,
                            total_defect=1,
                            total_duration=1,
                        ),
                        builds=[],
                        release_status="NOT_READY",
                    ),
                    build_statistics=BuildStatisticsResource(
                        id=1,
                        build=BuildResource(BuildResource),
                        total_execution=1,
                        total_passed=1,
                        total_failed=1,
                    ),
                    name="name_example",
                    description="description_example",
                    date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                ),
                has_comment=True,
                user=UserResource(
                    id=1,
                    email="email_example",
                    first_name="first_name_example",
                    last_name="last_name_example",
                    password="password_example",
                    inviting_url="inviting_url_example",
                    avatar="avatar_example",
                    configs=ConfigResource(
                        web_socket_url="web_socket_url_example",
                        store_url="store_url_example",
                        profiles=[],
                        stripe_public_api="stripe_public_api_example",
                        build_version="build_version_example",
                        commit_id="commit_id_example",
                        sentry_dsn="sentry_dsn_example",
                        sentry_env="sentry_env_example",
                        sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                        server_url="server_url_example",
                        io_server_url="io_server_url_example",
                        proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                        max_execution_comparison=1,
                        max_execution_download=1,
                        agent_download_urls={},
                        proxy_tunnel_download_urls={},
                        report_uploader_download_url="report_uploader_download_url_example",
                        report_uploader_latest_version="report_uploader_latest_version_example",
                        sub_domain_pattern="sub_domain_pattern_example",
                        cancellation_survey_url="cancellation_survey_url_example",
                        launch_darkly_client_id="launch_darkly_client_id_example",
                        launch_darkly_default_user="launch_darkly_default_user_example",
                        launch_darkly_prefix="launch_darkly_prefix_example",
                        min_test_execution_ordered=1,
                        user_flow_token="user_flow_token_example",
                        demo_project_url="demo_project_url_example",
                        advanced_feature_enabled=True,
                        using_sub_domain=True,
                        test_ops_subscription_enabled=True,
                        frameworks_integration_enabled=True,
                    ),
                    projects=[],
                    teams=[],
                    organizations=[],
                    organization_feature=[],
                    trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    system_role="USER",
                    survey_status="NOT_SUBMITTED",
                    session_timeout=1,
                    business_user=True,
                    can_create_offline_kse=True,
                    can_create_offline_re=True,
                    saml_sso=True,
                    created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    full_name="full_name_example",
                ),
                session_id="session_id_example",
                build_label="build_label_example",
                build_url="build_url_example",
                type="KATALON",
                jobs=[
                    JobResource(JobResource),
                ],
                use_test_cloud_tunnel=True,
                getk_eyes_execution=KEyesExecutionResource(
                    id=1,
                    status="RUNNING",
                    execution=ExecutionResource(ExecutionResource),
                    total_checkpoints=1,
                    passed_checkpoints=1,
                    failed_checkpoints=1,
                    unresolved_checkpoints=1,
                    unsaved=True,
                    baseline_collection=BaselineCollectionResource(
                        id=1,
                        version=1,
                        baselines=[
                            BaselineResource(
                                id=1,
                                upload_file=UploadFileResource(
                                    path="path_example",
                                    file_name="file_name_example",
                                    type="TSC_EXECUTION",
                                    base64_content="base64_content_example",
                                    file_handle_id=1,
                                    thumbnail_id=1,
                                ),
                                screenshot_id=1,
                                execution=ExecutionResource(ExecutionResource),
                                screenshot=ScreenshotResource(
                                    name="name_example",
                                    width=3.14,
                                    height=3.14,
                                ),
                                width=3.14,
                                height=3.14,
                                created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                draft_ignoring_zones=[
                                    IgnoringZoneResource(
                                        uuid="uuid_example",
                                        x=1,
                                        y=1,
                                        w=1,
                                        h=1,
                                        type="ALL",
                                    ),
                                ],
                                ignoring_zones=[
                                    IgnoringZoneResource(
                                        uuid="uuid_example",
                                        x=1,
                                        y=1,
                                        w=1,
                                        h=1,
                                        type="ALL",
                                    ),
                                ],
                            ),
                        ],
                        number_of_baselines=1,
                        updated_by=UserResource(
                            id=1,
                            email="email_example",
                            first_name="first_name_example",
                            last_name="last_name_example",
                            password="password_example",
                            inviting_url="inviting_url_example",
                            avatar="avatar_example",
                            configs=ConfigResource(
                                web_socket_url="web_socket_url_example",
                                store_url="store_url_example",
                                profiles=[],
                                stripe_public_api="stripe_public_api_example",
                                build_version="build_version_example",
                                commit_id="commit_id_example",
                                sentry_dsn="sentry_dsn_example",
                                sentry_env="sentry_env_example",
                                sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                                server_url="server_url_example",
                                io_server_url="io_server_url_example",
                                proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                                max_execution_comparison=1,
                                max_execution_download=1,
                                agent_download_urls={},
                                proxy_tunnel_download_urls={},
                                report_uploader_download_url="report_uploader_download_url_example",
                                report_uploader_latest_version="report_uploader_latest_version_example",
                                sub_domain_pattern="sub_domain_pattern_example",
                                cancellation_survey_url="cancellation_survey_url_example",
                                launch_darkly_client_id="launch_darkly_client_id_example",
                                launch_darkly_default_user="launch_darkly_default_user_example",
                                launch_darkly_prefix="launch_darkly_prefix_example",
                                min_test_execution_ordered=1,
                                user_flow_token="user_flow_token_example",
                                demo_project_url="demo_project_url_example",
                                advanced_feature_enabled=True,
                                using_sub_domain=True,
                                test_ops_subscription_enabled=True,
                                frameworks_integration_enabled=True,
                            ),
                            projects=[],
                            teams=[],
                            organizations=[],
                            organization_feature=[],
                            trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            system_role="USER",
                            survey_status="NOT_SUBMITTED",
                            session_timeout=1,
                            business_user=True,
                            can_create_offline_kse=True,
                            can_create_offline_re=True,
                            saml_sso=True,
                            created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            full_name="full_name_example",
                        ),
                        baseline_collection_group=BaselineCollectionGroupResource(
                            id=1,
                            name="name_example",
                            latest_version=BaselineCollectionResource(BaselineCollectionResource),
                            run_configurations=[
                                RunConfigurationResource(
                                    id=1,
                                    name="name_example",
                                    command="command_example",
                                    project_id=1,
                                    team_id=1,
                                    test_project_id=1,
                                    release_id=1,
                                    test_suite_collection_id=1,
                                    test_suite_id=1,
                                    execution_profile_id=1,
                                    baseline_collection_group_order=1,
                                    time_out=1,
                                    kobiton_device_id="kobiton_device_id_example",
                                    config_type="TSC",
                                    test_project=TestProjectResource(TestProjectResource),
                                    agents=[
                                        AgentResource(
                                            id=1,
                                            name="name_example",
                                            ip="ip_example",
                                            uuid="uuid_example",
                                            last_ping=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            os="os_example",
                                            team_id=1,
                                            hostname="hostname_example",
                                            active=True,
                                            threshold=1,
                                            num_executing_jobs=1,
                                            num_assigned_jobs=1,
                                            agent_version="agent_version_example",
                                            deleted=True,
                                        ),
                                    ],
                                    test_cloud_agents=[
                                        TestCloudAgentResource(
                                            id=1,
                                            name="name_example",
                                            os="os_example",
                                            os_version="os_version_example",
                                            browser="browser_example",
                                            browser_version="browser_version_example",
                                            device_name="device_name_example",
                                            app_id="app_id_example",
                                            app_group_id="app_group_id_example",
                                            app_name="app_name_example",
                                            device_id="device_id_example",
                                            num_executing_jobs=1,
                                            num_assigned_jobs=1,
                                            team_id=1,
                                            deleted=True,
                                            api_key="api_key_example",
                                            total_duration=1,
                                            headless=True,
                                            execution_type="CHROME",
                                        ),
                                    ],
                                    k8s_agents=[
                                        K8SAgentResource(
                                            id=1,
                                            name="name_example",
                                            certificate_authority="certificate_authority_example",
                                            url="url_example",
                                            namespace="namespace_example",
                                            username="username_example",
                                            password="password_example",
                                            token="token_example",
                                            cluster="cluster_example",
                                            region="region_example",
                                            access_key="access_key_example",
                                            private_access_key="private_access_key_example",
                                            team_id=1,
                                            api_key="api_key_example",
                                            authentication_type="BASIC_AUTH",
                                        ),
                                    ],
                                    circle_ci_agents=[
                                        CircleCIAgentResource(
                                            id=1,
                                            name="name_example",
                                            url="url_example",
                                            username="username_example",
                                            token="token_example",
                                            project="project_example",
                                            vcs_type="vcs_type_example",
                                            branch="branch_example",
                                            team_id=1,
                                            api_key="api_key_example",
                                        ),
                                    ],
                                    test_cloud_test_suite_collection_agents=[
                                        TestCloudTestSuiteCollectionAgentResource(
                                            test_suite_collection_configuration_id=1,
                                            test_cloud_agent=TestCloudAgentResource(
                                                id=1,
                                                name="name_example",
                                                os="os_example",
                                                os_version="os_version_example",
                                                browser="browser_example",
                                                browser_version="browser_version_example",
                                                device_name="device_name_example",
                                                app_id="app_id_example",
                                                app_group_id="app_group_id_example",
                                                app_name="app_name_example",
                                                device_id="device_id_example",
                                                num_executing_jobs=1,
                                                num_assigned_jobs=1,
                                                team_id=1,
                                                deleted=True,
                                                api_key="api_key_example",
                                                total_duration=1,
                                                headless=True,
                                                execution_type="CHROME",
                                            ),
                                            updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        ),
                                    ],
                                    cloud_type="K8S",
                                    latest_job=JobResource(JobResource),
                                    generic_command="generic_command_example",
                                    ks_version="ks_version_example",
                                    ks_location="ks_location_example",
                                    next_run_scheduler=SchedulerResource(
                                        id=1,
                                        name="name_example",
                                        start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        next_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        end_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        active=True,
                                        interval=1,
                                        interval_unit="MINUTE",
                                        run_configuration_id=1,
                                        run_configuration=RunConfigurationResource(RunConfigurationResource),
                                        exceeded_limit_time=True,
                                    ),
                                    release=ReleaseResource(
                                        id=1,
                                        name="name_example",
                                        start_time=dateutil_parser('1970-01-01').date(),
                                        end_time=dateutil_parser('1970-01-01').date(),
                                        description="description_example",
                                        project_id=1,
                                        closed=True,
                                        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        external_release=ExternalReleaseResource(
                                            id=1,
                                            release_id="release_id_example",
                                            description="description_example",
                                            name="name_example",
                                            archived=True,
                                            released=True,
                                            project_id="project_id_example",
                                            external_project=ExternalProjectResource(
                                                id=1,
                                                external_project_id="external_project_id_example",
                                                external_project_key="external_project_key_example",
                                                name="name_example",
                                            ),
                                            web_url="web_url_example",
                                            jira_release_status="RELEASED",
                                            start_date=dateutil_parser('1970-01-01').date(),
                                            release_date=dateutil_parser('1970-01-01').date(),
                                        ),
                                        release_statistics=ReleaseStatisticsResource(
                                            id=1,
                                            release=ReleaseResource(ReleaseResource),
                                            total_passed=1,
                                            total_failed=1,
                                            total_execution=1,
                                            total_defect=1,
                                            total_duration=1,
                                        ),
                                        builds=[],
                                        release_status="NOT_READY",
                                    ),
                                    build=BuildResource(
                                        id=1,
                                        project_id=1,
                                        project=ProjectResource(
                                            id=1,
                                            name="name_example",
                                            team_id=1,
                                            team=TeamResource(
                                                id=1,
                                                name="name_example",
                                                role="OWNER",
                                                users=[],
                                                organization=OrganizationResource(
                                                    id=1,
                                                    name="name_example",
                                                    role="OWNER",
                                                    org_feature_flag=OrganizationFeatureFlagResource(
                                                        organization_id=1,
                                                        sub_domain=True,
                                                        strict_domain=True,
                                                        sso=True,
                                                        whitelist_ip=True,
                                                        circle_ci=True,
                                                        test_ops_integration=True,
                                                    ),
                                                    quota_kse=1,
                                                    machine_quota_kse=1,
                                                    quota_unlimited_kse=1,
                                                    quota_engine=1,
                                                    machine_quota_engine=1,
                                                    quota_unlimited_engine=1,
                                                    used_kse=1,
                                                    used_unlimited_kse=1,
                                                    used_engine=1,
                                                    used_unlimited_engine=1,
                                                    quota_test_ops=1,
                                                    used_test_ops=1,
                                                    number_user=1,
                                                    quota_floating_engine=1,
                                                    used_floating_engine=1,
                                                    can_create_offline_kse=True,
                                                    can_create_offline_unlimited_kse=True,
                                                    can_create_offline_re=True,
                                                    can_create_offline_unlimited_engine=True,
                                                    subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    subscribed=True,
                                                    kse_paygo=True,
                                                    kre_paygo=True,
                                                    paygo_quota=1,
                                                    domain="domain_example",
                                                    subdomain_url="subdomain_url_example",
                                                    strict_domain=True,
                                                    logo_url="logo_url_example",
                                                    saml_sso=True,
                                                    kre_license=True,
                                                    most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    account_id=1,
                                                    test_ops_feature="KSE",
                                                    platform_feature="KSE",
                                                    tier="FREE",
                                                    requested_user_verified=True,
                                                ),
                                                organization_id=1,
                                            ),
                                            timezone="timezone_example",
                                            status="ARCHIVE",
                                        ),
                                        release_id=1,
                                        release=ReleaseResource(
                                            id=1,
                                            name="name_example",
                                            start_time=dateutil_parser('1970-01-01').date(),
                                            end_time=dateutil_parser('1970-01-01').date(),
                                            description="description_example",
                                            project_id=1,
                                            closed=True,
                                            created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            external_release=ExternalReleaseResource(
                                                id=1,
                                                release_id="release_id_example",
                                                description="description_example",
                                                name="name_example",
                                                archived=True,
                                                released=True,
                                                project_id="project_id_example",
                                                external_project=ExternalProjectResource(
                                                    id=1,
                                                    external_project_id="external_project_id_example",
                                                    external_project_key="external_project_key_example",
                                                    name="name_example",
                                                ),
                                                web_url="web_url_example",
                                                jira_release_status="RELEASED",
                                                start_date=dateutil_parser('1970-01-01').date(),
                                                release_date=dateutil_parser('1970-01-01').date(),
                                            ),
                                            release_statistics=ReleaseStatisticsResource(
                                                id=1,
                                                release=ReleaseResource(ReleaseResource),
                                                total_passed=1,
                                                total_failed=1,
                                                total_execution=1,
                                                total_defect=1,
                                                total_duration=1,
                                            ),
                                            builds=[],
                                            release_status="NOT_READY",
                                        ),
                                        build_statistics=BuildStatisticsResource(
                                            id=1,
                                            build=BuildResource(BuildResource),
                                            total_execution=1,
                                            total_passed=1,
                                            total_failed=1,
                                        ),
                                        name="name_example",
                                        description="description_example",
                                        date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    ),
                                    execution_mode="SEQUENTIAL",
                                    enabled_kobiton_integration=True,
                                    enabled_test_cloud_tunnel=True,
                                    trigger_mode="TESTOPS_SCHEDULER",
                                    browser_type="CHROME",
                                    xray_import_report_type="PUSH_MANUALLY",
                                    external_test_plan_id="external_test_plan_id_example",
                                    custom_field_options=[],
                                    tags=[
                                        TagResource(
                                            id=1,
                                            name="name_example",
                                            project_id=1,
                                            organization_id=1,
                                        ),
                                    ],
                                ),
                            ],
                            updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            order=1,
                            last_run=KEyesExecutionResource(KEyesExecutionResource),
                        ),
                        unsaved=True,
                        default_method="PIXEL",
                        draft_default_method="PIXEL",
                        threshold=1,
                        draft_threshold=1,
                        create_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    ),
                ),
                data_type="USER_DATA",
            ),
            agent=AgentResource(
                id=1,
                name="name_example",
                ip="ip_example",
                uuid="uuid_example",
                last_ping=dateutil_parser('1970-01-01T00:00:00.00Z'),
                os="os_example",
                team_id=1,
                hostname="hostname_example",
                active=True,
                threshold=1,
                num_executing_jobs=1,
                num_assigned_jobs=1,
                agent_version="agent_version_example",
                deleted=True,
            ),
            test_cloud_agent=TestCloudAgentResource(
                id=1,
                name="name_example",
                os="os_example",
                os_version="os_version_example",
                browser="browser_example",
                browser_version="browser_version_example",
                device_name="device_name_example",
                app_id="app_id_example",
                app_group_id="app_group_id_example",
                app_name="app_name_example",
                device_id="device_id_example",
                num_executing_jobs=1,
                num_assigned_jobs=1,
                team_id=1,
                deleted=True,
                api_key="api_key_example",
                total_duration=1,
                headless=True,
                execution_type="CHROME",
            ),
            k8s_agent=K8SAgentResource(
                id=1,
                name="name_example",
                certificate_authority="certificate_authority_example",
                url="url_example",
                namespace="namespace_example",
                username="username_example",
                password="password_example",
                token="token_example",
                cluster="cluster_example",
                region="region_example",
                access_key="access_key_example",
                private_access_key="private_access_key_example",
                team_id=1,
                api_key="api_key_example",
                authentication_type="BASIC_AUTH",
            ),
            circle_ci_agent=CircleCIAgentResource(
                id=1,
                name="name_example",
                url="url_example",
                username="username_example",
                token="token_example",
                project="project_example",
                vcs_type="vcs_type_example",
                branch="branch_example",
                team_id=1,
                api_key="api_key_example",
            ),
            run_configuration=RunConfigurationResource(
                id=1,
                name="name_example",
                command="command_example",
                project_id=1,
                team_id=1,
                test_project_id=1,
                release_id=1,
                test_suite_collection_id=1,
                test_suite_id=1,
                execution_profile_id=1,
                baseline_collection_group_order=1,
                time_out=1,
                kobiton_device_id="kobiton_device_id_example",
                config_type="TSC",
                test_project=TestProjectResource(TestProjectResource),
                agents=[],
                test_cloud_agents=[],
                k8s_agents=[],
                circle_ci_agents=[],
                test_cloud_test_suite_collection_agents=[],
                cloud_type="K8S",
                latest_job=JobResource(JobResource),
                generic_command="generic_command_example",
                ks_version="ks_version_example",
                ks_location="ks_location_example",
                next_run_scheduler=SchedulerResource(
                    id=1,
                    name="name_example",
                    start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    next_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    end_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    active=True,
                    interval=1,
                    interval_unit="MINUTE",
                    run_configuration_id=1,
                    run_configuration=RunConfigurationResource(RunConfigurationResource),
                    exceeded_limit_time=True,
                ),
                release=ReleaseResource(
                    id=1,
                    name="name_example",
                    start_time=dateutil_parser('1970-01-01').date(),
                    end_time=dateutil_parser('1970-01-01').date(),
                    description="description_example",
                    project_id=1,
                    closed=True,
                    created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    external_release=ExternalReleaseResource(
                        id=1,
                        release_id="release_id_example",
                        description="description_example",
                        name="name_example",
                        archived=True,
                        released=True,
                        project_id="project_id_example",
                        external_project=ExternalProjectResource(
                            id=1,
                            external_project_id="external_project_id_example",
                            external_project_key="external_project_key_example",
                            name="name_example",
                        ),
                        web_url="web_url_example",
                        jira_release_status="RELEASED",
                        start_date=dateutil_parser('1970-01-01').date(),
                        release_date=dateutil_parser('1970-01-01').date(),
                    ),
                    release_statistics=ReleaseStatisticsResource(
                        id=1,
                        release=ReleaseResource(ReleaseResource),
                        total_passed=1,
                        total_failed=1,
                        total_execution=1,
                        total_defect=1,
                        total_duration=1,
                    ),
                    builds=[],
                    release_status="NOT_READY",
                ),
                build=BuildResource(
                    id=1,
                    project_id=1,
                    project=ProjectResource(
                        id=1,
                        name="name_example",
                        team_id=1,
                        team=TeamResource(
                            id=1,
                            name="name_example",
                            role="OWNER",
                            users=[],
                            organization=OrganizationResource(
                                id=1,
                                name="name_example",
                                role="OWNER",
                                org_feature_flag=OrganizationFeatureFlagResource(
                                    organization_id=1,
                                    sub_domain=True,
                                    strict_domain=True,
                                    sso=True,
                                    whitelist_ip=True,
                                    circle_ci=True,
                                    test_ops_integration=True,
                                ),
                                quota_kse=1,
                                machine_quota_kse=1,
                                quota_unlimited_kse=1,
                                quota_engine=1,
                                machine_quota_engine=1,
                                quota_unlimited_engine=1,
                                used_kse=1,
                                used_unlimited_kse=1,
                                used_engine=1,
                                used_unlimited_engine=1,
                                quota_test_ops=1,
                                used_test_ops=1,
                                number_user=1,
                                quota_floating_engine=1,
                                used_floating_engine=1,
                                can_create_offline_kse=True,
                                can_create_offline_unlimited_kse=True,
                                can_create_offline_re=True,
                                can_create_offline_unlimited_engine=True,
                                subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscribed=True,
                                kse_paygo=True,
                                kre_paygo=True,
                                paygo_quota=1,
                                domain="domain_example",
                                subdomain_url="subdomain_url_example",
                                strict_domain=True,
                                logo_url="logo_url_example",
                                saml_sso=True,
                                kre_license=True,
                                most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                account_id=1,
                                test_ops_feature="KSE",
                                platform_feature="KSE",
                                tier="FREE",
                                requested_user_verified=True,
                            ),
                            organization_id=1,
                        ),
                        timezone="timezone_example",
                        status="ARCHIVE",
                    ),
                    release_id=1,
                    release=ReleaseResource(
                        id=1,
                        name="name_example",
                        start_time=dateutil_parser('1970-01-01').date(),
                        end_time=dateutil_parser('1970-01-01').date(),
                        description="description_example",
                        project_id=1,
                        closed=True,
                        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        external_release=ExternalReleaseResource(
                            id=1,
                            release_id="release_id_example",
                            description="description_example",
                            name="name_example",
                            archived=True,
                            released=True,
                            project_id="project_id_example",
                            external_project=ExternalProjectResource(
                                id=1,
                                external_project_id="external_project_id_example",
                                external_project_key="external_project_key_example",
                                name="name_example",
                            ),
                            web_url="web_url_example",
                            jira_release_status="RELEASED",
                            start_date=dateutil_parser('1970-01-01').date(),
                            release_date=dateutil_parser('1970-01-01').date(),
                        ),
                        release_statistics=ReleaseStatisticsResource(
                            id=1,
                            release=ReleaseResource(ReleaseResource),
                            total_passed=1,
                            total_failed=1,
                            total_execution=1,
                            total_defect=1,
                            total_duration=1,
                        ),
                        builds=[],
                        release_status="NOT_READY",
                    ),
                    build_statistics=BuildStatisticsResource(
                        id=1,
                        build=BuildResource(BuildResource),
                        total_execution=1,
                        total_passed=1,
                        total_failed=1,
                    ),
                    name="name_example",
                    description="description_example",
                    date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                ),
                execution_mode="SEQUENTIAL",
                enabled_kobiton_integration=True,
                enabled_test_cloud_tunnel=True,
                trigger_mode="TESTOPS_SCHEDULER",
                browser_type="CHROME",
                xray_import_report_type="PUSH_MANUALLY",
                external_test_plan_id="external_test_plan_id_example",
                custom_field_options=[],
                tags=[],
            ),
            order=1,
            parameter=TriggerBuildParameter(
                download_url="download_url_example",
                command="command_example",
                environment_variables=[
                    EnvironmentVariable(
                        name="name_example",
                        value="value_example",
                    ),
                ],
                session_id="session_id_example",
                ks_version="ks_version_example",
                ks_location="ks_location_example",
                config_type="TSC",
                type="KS",
                git_repository_resource=GitRepositoryResource(
                    id=1,
                    test_project_id=1,
                    name="name_example",
                    repository="repository_example",
                    branch="branch_example",
                    username="username_example",
                    password="password_example",
                    access_key_id="access_key_id_example",
                    secret_access_key="secret_access_key_example",
                    project_id=1,
                    team_id=1,
                    created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    description="description_example",
                    vcs_type="GITHUB",
                    should_merge_test_results_for_new_script_repo=True,
                ),
                test_ops_download_url="test_ops_download_url_example",
                extra_files=[
                    KSFile(
                        content_url="content_url_example",
                        path="path_example",
                        write_mode="OVERRIDE",
                    ),
                ],
                organization_id=1,
            ),
            trigger_by="MANUAL",
            duration=1,
            trigger_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
            user=UserResource(
                id=1,
                email="email_example",
                first_name="first_name_example",
                last_name="last_name_example",
                password="password_example",
                inviting_url="inviting_url_example",
                avatar="avatar_example",
                configs=ConfigResource(
                    web_socket_url="web_socket_url_example",
                    store_url="store_url_example",
                    profiles=[],
                    stripe_public_api="stripe_public_api_example",
                    build_version="build_version_example",
                    commit_id="commit_id_example",
                    sentry_dsn="sentry_dsn_example",
                    sentry_env="sentry_env_example",
                    sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                    server_url="server_url_example",
                    io_server_url="io_server_url_example",
                    proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                    max_execution_comparison=1,
                    max_execution_download=1,
                    agent_download_urls={},
                    proxy_tunnel_download_urls={},
                    report_uploader_download_url="report_uploader_download_url_example",
                    report_uploader_latest_version="report_uploader_latest_version_example",
                    sub_domain_pattern="sub_domain_pattern_example",
                    cancellation_survey_url="cancellation_survey_url_example",
                    launch_darkly_client_id="launch_darkly_client_id_example",
                    launch_darkly_default_user="launch_darkly_default_user_example",
                    launch_darkly_prefix="launch_darkly_prefix_example",
                    min_test_execution_ordered=1,
                    user_flow_token="user_flow_token_example",
                    demo_project_url="demo_project_url_example",
                    advanced_feature_enabled=True,
                    using_sub_domain=True,
                    test_ops_subscription_enabled=True,
                    frameworks_integration_enabled=True,
                ),
                projects=[],
                teams=[],
                organizations=[],
                organization_feature=[],
                trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                system_role="USER",
                survey_status="NOT_SUBMITTED",
                session_timeout=1,
                business_user=True,
                can_create_offline_kse=True,
                can_create_offline_re=True,
                saml_sso=True,
                created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                full_name="full_name_example",
            ),
            scheduler=SchedulerResource(
                id=1,
                name="name_example",
                start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                next_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                end_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                active=True,
                interval=1,
                interval_unit="MINUTE",
                run_configuration_id=1,
                run_configuration=RunConfigurationResource(
                    id=1,
                    name="name_example",
                    command="command_example",
                    project_id=1,
                    team_id=1,
                    test_project_id=1,
                    release_id=1,
                    test_suite_collection_id=1,
                    test_suite_id=1,
                    execution_profile_id=1,
                    baseline_collection_group_order=1,
                    time_out=1,
                    kobiton_device_id="kobiton_device_id_example",
                    config_type="TSC",
                    test_project=TestProjectResource(TestProjectResource),
                    agents=[],
                    test_cloud_agents=[],
                    k8s_agents=[],
                    circle_ci_agents=[],
                    test_cloud_test_suite_collection_agents=[],
                    cloud_type="K8S",
                    latest_job=JobResource(JobResource),
                    generic_command="generic_command_example",
                    ks_version="ks_version_example",
                    ks_location="ks_location_example",
                    next_run_scheduler=SchedulerResource(SchedulerResource),
                    release=ReleaseResource(
                        id=1,
                        name="name_example",
                        start_time=dateutil_parser('1970-01-01').date(),
                        end_time=dateutil_parser('1970-01-01').date(),
                        description="description_example",
                        project_id=1,
                        closed=True,
                        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        external_release=ExternalReleaseResource(
                            id=1,
                            release_id="release_id_example",
                            description="description_example",
                            name="name_example",
                            archived=True,
                            released=True,
                            project_id="project_id_example",
                            external_project=ExternalProjectResource(
                                id=1,
                                external_project_id="external_project_id_example",
                                external_project_key="external_project_key_example",
                                name="name_example",
                            ),
                            web_url="web_url_example",
                            jira_release_status="RELEASED",
                            start_date=dateutil_parser('1970-01-01').date(),
                            release_date=dateutil_parser('1970-01-01').date(),
                        ),
                        release_statistics=ReleaseStatisticsResource(
                            id=1,
                            release=ReleaseResource(ReleaseResource),
                            total_passed=1,
                            total_failed=1,
                            total_execution=1,
                            total_defect=1,
                            total_duration=1,
                        ),
                        builds=[],
                        release_status="NOT_READY",
                    ),
                    build=BuildResource(
                        id=1,
                        project_id=1,
                        project=ProjectResource(
                            id=1,
                            name="name_example",
                            team_id=1,
                            team=TeamResource(
                                id=1,
                                name="name_example",
                                role="OWNER",
                                users=[],
                                organization=OrganizationResource(
                                    id=1,
                                    name="name_example",
                                    role="OWNER",
                                    org_feature_flag=OrganizationFeatureFlagResource(
                                        organization_id=1,
                                        sub_domain=True,
                                        strict_domain=True,
                                        sso=True,
                                        whitelist_ip=True,
                                        circle_ci=True,
                                        test_ops_integration=True,
                                    ),
                                    quota_kse=1,
                                    machine_quota_kse=1,
                                    quota_unlimited_kse=1,
                                    quota_engine=1,
                                    machine_quota_engine=1,
                                    quota_unlimited_engine=1,
                                    used_kse=1,
                                    used_unlimited_kse=1,
                                    used_engine=1,
                                    used_unlimited_engine=1,
                                    quota_test_ops=1,
                                    used_test_ops=1,
                                    number_user=1,
                                    quota_floating_engine=1,
                                    used_floating_engine=1,
                                    can_create_offline_kse=True,
                                    can_create_offline_unlimited_kse=True,
                                    can_create_offline_re=True,
                                    can_create_offline_unlimited_engine=True,
                                    subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscribed=True,
                                    kse_paygo=True,
                                    kre_paygo=True,
                                    paygo_quota=1,
                                    domain="domain_example",
                                    subdomain_url="subdomain_url_example",
                                    strict_domain=True,
                                    logo_url="logo_url_example",
                                    saml_sso=True,
                                    kre_license=True,
                                    most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    account_id=1,
                                    test_ops_feature="KSE",
                                    platform_feature="KSE",
                                    tier="FREE",
                                    requested_user_verified=True,
                                ),
                                organization_id=1,
                            ),
                            timezone="timezone_example",
                            status="ARCHIVE",
                        ),
                        release_id=1,
                        release=ReleaseResource(
                            id=1,
                            name="name_example",
                            start_time=dateutil_parser('1970-01-01').date(),
                            end_time=dateutil_parser('1970-01-01').date(),
                            description="description_example",
                            project_id=1,
                            closed=True,
                            created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            external_release=ExternalReleaseResource(
                                id=1,
                                release_id="release_id_example",
                                description="description_example",
                                name="name_example",
                                archived=True,
                                released=True,
                                project_id="project_id_example",
                                external_project=ExternalProjectResource(
                                    id=1,
                                    external_project_id="external_project_id_example",
                                    external_project_key="external_project_key_example",
                                    name="name_example",
                                ),
                                web_url="web_url_example",
                                jira_release_status="RELEASED",
                                start_date=dateutil_parser('1970-01-01').date(),
                                release_date=dateutil_parser('1970-01-01').date(),
                            ),
                            release_statistics=ReleaseStatisticsResource(
                                id=1,
                                release=ReleaseResource(ReleaseResource),
                                total_passed=1,
                                total_failed=1,
                                total_execution=1,
                                total_defect=1,
                                total_duration=1,
                            ),
                            builds=[],
                            release_status="NOT_READY",
                        ),
                        build_statistics=BuildStatisticsResource(
                            id=1,
                            build=BuildResource(BuildResource),
                            total_execution=1,
                            total_passed=1,
                            total_failed=1,
                        ),
                        name="name_example",
                        description="description_example",
                        date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    ),
                    execution_mode="SEQUENTIAL",
                    enabled_kobiton_integration=True,
                    enabled_test_cloud_tunnel=True,
                    trigger_mode="TESTOPS_SCHEDULER",
                    browser_type="CHROME",
                    xray_import_report_type="PUSH_MANUALLY",
                    external_test_plan_id="external_test_plan_id_example",
                    custom_field_options=[],
                    tags=[],
                ),
                exceeded_limit_time=True,
            ),
            project=ProjectResource(
                id=1,
                name="name_example",
                team_id=1,
                team=TeamResource(
                    id=1,
                    name="name_example",
                    role="OWNER",
                    users=[],
                    organization=OrganizationResource(
                        id=1,
                        name="name_example",
                        role="OWNER",
                        org_feature_flag=OrganizationFeatureFlagResource(
                            organization_id=1,
                            sub_domain=True,
                            strict_domain=True,
                            sso=True,
                            whitelist_ip=True,
                            circle_ci=True,
                            test_ops_integration=True,
                        ),
                        quota_kse=1,
                        machine_quota_kse=1,
                        quota_unlimited_kse=1,
                        quota_engine=1,
                        machine_quota_engine=1,
                        quota_unlimited_engine=1,
                        used_kse=1,
                        used_unlimited_kse=1,
                        used_engine=1,
                        used_unlimited_engine=1,
                        quota_test_ops=1,
                        used_test_ops=1,
                        number_user=1,
                        quota_floating_engine=1,
                        used_floating_engine=1,
                        can_create_offline_kse=True,
                        can_create_offline_unlimited_kse=True,
                        can_create_offline_re=True,
                        can_create_offline_unlimited_engine=True,
                        subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        subscribed=True,
                        kse_paygo=True,
                        kre_paygo=True,
                        paygo_quota=1,
                        domain="domain_example",
                        subdomain_url="subdomain_url_example",
                        strict_domain=True,
                        logo_url="logo_url_example",
                        saml_sso=True,
                        kre_license=True,
                        most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        account_id=1,
                        test_ops_feature="KSE",
                        platform_feature="KSE",
                        tier="FREE",
                        requested_user_verified=True,
                    ),
                    organization_id=1,
                ),
                timezone="timezone_example",
                status="ARCHIVE",
            ),
            process_id=1,
            node_status="PENDING_CANCELED",
            run_configuration_id=1,
        ),
        upload_file_name="upload_file_name_example",
        type="KS",
        git_repository=GitRepositoryResource(
            id=1,
            test_project_id=1,
            name="name_example",
            repository="repository_example",
            branch="branch_example",
            username="username_example",
            password="password_example",
            access_key_id="access_key_id_example",
            secret_access_key="secret_access_key_example",
            project_id=1,
            team_id=1,
            created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
            updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
            description="description_example",
            vcs_type="GITHUB",
            should_merge_test_results_for_new_script_repo=True,
        ),
        test_suite_collections=[
            TestSuiteCollectionResource(
                id=1,
                name="name_example",
                project=ProjectResource(
                    id=1,
                    name="name_example",
                    team_id=1,
                    team=TeamResource(
                        id=1,
                        name="name_example",
                        role="OWNER",
                        users=[],
                        organization=OrganizationResource(
                            id=1,
                            name="name_example",
                            role="OWNER",
                            org_feature_flag=OrganizationFeatureFlagResource(
                                organization_id=1,
                                sub_domain=True,
                                strict_domain=True,
                                sso=True,
                                whitelist_ip=True,
                                circle_ci=True,
                                test_ops_integration=True,
                            ),
                            quota_kse=1,
                            machine_quota_kse=1,
                            quota_unlimited_kse=1,
                            quota_engine=1,
                            machine_quota_engine=1,
                            quota_unlimited_engine=1,
                            used_kse=1,
                            used_unlimited_kse=1,
                            used_engine=1,
                            used_unlimited_engine=1,
                            quota_test_ops=1,
                            used_test_ops=1,
                            number_user=1,
                            quota_floating_engine=1,
                            used_floating_engine=1,
                            can_create_offline_kse=True,
                            can_create_offline_unlimited_kse=True,
                            can_create_offline_re=True,
                            can_create_offline_unlimited_engine=True,
                            subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscribed=True,
                            kse_paygo=True,
                            kre_paygo=True,
                            paygo_quota=1,
                            domain="domain_example",
                            subdomain_url="subdomain_url_example",
                            strict_domain=True,
                            logo_url="logo_url_example",
                            saml_sso=True,
                            kre_license=True,
                            most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            account_id=1,
                            test_ops_feature="KSE",
                            platform_feature="KSE",
                            tier="FREE",
                            requested_user_verified=True,
                        ),
                        organization_id=1,
                    ),
                    timezone="timezone_example",
                    status="ARCHIVE",
                ),
                test_suite_collection_configurations=[
                    TestSuiteCollectionConfigurationResource(
                        id=1,
                        profile_name="profile_name_example",
                        browser_type="CHROME",
                        run_enabled=True,
                        sort_order=1,
                        test_suite_entity="test_suite_entity_example",
                    ),
                ],
                url_id="url_id_example",
            ),
        ],
        dirty=True,
    ) # TestProjectResource | 

    # example passing only required values which don't have defaults set
    try:
        # Updates a Test Project detail. Returns the updated Test Project detail.
        api_response = api_instance.update(id, test_project_resource)
        pprint(api_response)
    except testops_api.ApiException as e:
        print("Exception when calling TestProjectApi->update: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**|  |
 **test_project_resource** | [**TestProjectResource**](TestProjectResource.md)|  |

### Return type

[**TestProjectResource**](TestProjectResource.md)

### Authorization

[basicScheme](../README.md#basicScheme)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: */*

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update1**
> SchedulerResource update1(id, scheduler_id, scheduler_resource)

Updates a schedule detail. Returns the updated schedule detail.

### Example

* Basic Authentication (basicScheme):
```python
import time
import testops_api
from testops_api.api import test_project_api
from testops_api.model.scheduler_resource import SchedulerResource
from pprint import pprint
# Defining the host is optional and defaults to http://localhost:8443
# See configuration.py for a list of all supported configuration parameters.
configuration = testops_api.Configuration(
    host = "http://localhost:8443"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicScheme
configuration = testops_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Enter a context with an instance of the API client
with testops_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = test_project_api.TestProjectApi(api_client)
    id = 1 # int | 
    scheduler_id = 1 # int | 
    scheduler_resource = SchedulerResource(
        id=1,
        name="name_example",
        start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
        next_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
        end_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
        active=True,
        interval=1,
        interval_unit="MINUTE",
        run_configuration_id=1,
        run_configuration=RunConfigurationResource(
            id=1,
            name="name_example",
            command="command_example",
            project_id=1,
            team_id=1,
            test_project_id=1,
            release_id=1,
            test_suite_collection_id=1,
            test_suite_id=1,
            execution_profile_id=1,
            baseline_collection_group_order=1,
            time_out=1,
            kobiton_device_id="kobiton_device_id_example",
            config_type="TSC",
            test_project=TestProjectResource(
                id=1,
                name="name_example",
                description="description_example",
                default_test_project=True,
                upload_file_id=1,
                project_id=1,
                team_id=1,
                created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                latest_job=JobResource(
                    id=1,
                    build_number=1,
                    status="QUEUED",
                    queued_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    stop_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    test_project=TestProjectResource(TestProjectResource),
                    execution=ExecutionResource(
                        status="PASSED",
                        start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        end_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        duration=1,
                        elapsed_duration=1,
                        total_tests=1,
                        total_passed_tests=1,
                        total_failed_tests=1,
                        total_error_tests=1,
                        total_incomplete_tests=1,
                        total_skipped_tests=1,
                        total_diff_tests=1,
                        total_diff_passed_tests=1,
                        total_diff_failed_tests=1,
                        total_diff_error_tests=1,
                        total_diff_incomplete_tests=1,
                        id=1,
                        project_id=1,
                        project=ProjectResource(
                            id=1,
                            name="name_example",
                            team_id=1,
                            team=TeamResource(
                                id=1,
                                name="name_example",
                                role="OWNER",
                                users=[
                                    UserResource(
                                        id=1,
                                        email="email_example",
                                        first_name="first_name_example",
                                        last_name="last_name_example",
                                        password="password_example",
                                        inviting_url="inviting_url_example",
                                        avatar="avatar_example",
                                        configs=ConfigResource(
                                            web_socket_url="web_socket_url_example",
                                            store_url="store_url_example",
                                            profiles=[
                                                "profiles_example",
                                            ],
                                            stripe_public_api="stripe_public_api_example",
                                            build_version="build_version_example",
                                            commit_id="commit_id_example",
                                            sentry_dsn="sentry_dsn_example",
                                            sentry_env="sentry_env_example",
                                            sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                                            server_url="server_url_example",
                                            io_server_url="io_server_url_example",
                                            proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                                            max_execution_comparison=1,
                                            max_execution_download=1,
                                            agent_download_urls={
                                                "key": "key_example",
                                            },
                                            proxy_tunnel_download_urls={
                                                "key": "key_example",
                                            },
                                            report_uploader_download_url="report_uploader_download_url_example",
                                            report_uploader_latest_version="report_uploader_latest_version_example",
                                            sub_domain_pattern="sub_domain_pattern_example",
                                            cancellation_survey_url="cancellation_survey_url_example",
                                            launch_darkly_client_id="launch_darkly_client_id_example",
                                            launch_darkly_default_user="launch_darkly_default_user_example",
                                            launch_darkly_prefix="launch_darkly_prefix_example",
                                            min_test_execution_ordered=1,
                                            user_flow_token="user_flow_token_example",
                                            demo_project_url="demo_project_url_example",
                                            advanced_feature_enabled=True,
                                            using_sub_domain=True,
                                            test_ops_subscription_enabled=True,
                                            frameworks_integration_enabled=True,
                                        ),
                                        projects=[
                                            ProjectResource(ProjectResource),
                                        ],
                                        teams=[
                                            TeamResource(TeamResource),
                                        ],
                                        organizations=[
                                            OrganizationResource(
                                                id=1,
                                                name="name_example",
                                                role="OWNER",
                                                org_feature_flag=OrganizationFeatureFlagResource(
                                                    organization_id=1,
                                                    sub_domain=True,
                                                    strict_domain=True,
                                                    sso=True,
                                                    whitelist_ip=True,
                                                    circle_ci=True,
                                                    test_ops_integration=True,
                                                ),
                                                quota_kse=1,
                                                machine_quota_kse=1,
                                                quota_unlimited_kse=1,
                                                quota_engine=1,
                                                machine_quota_engine=1,
                                                quota_unlimited_engine=1,
                                                used_kse=1,
                                                used_unlimited_kse=1,
                                                used_engine=1,
                                                used_unlimited_engine=1,
                                                quota_test_ops=1,
                                                used_test_ops=1,
                                                number_user=1,
                                                quota_floating_engine=1,
                                                used_floating_engine=1,
                                                can_create_offline_kse=True,
                                                can_create_offline_unlimited_kse=True,
                                                can_create_offline_re=True,
                                                can_create_offline_unlimited_engine=True,
                                                subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscribed=True,
                                                kse_paygo=True,
                                                kre_paygo=True,
                                                paygo_quota=1,
                                                domain="domain_example",
                                                subdomain_url="subdomain_url_example",
                                                strict_domain=True,
                                                logo_url="logo_url_example",
                                                saml_sso=True,
                                                kre_license=True,
                                                most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                account_id=1,
                                                test_ops_feature="KSE",
                                                platform_feature="KSE",
                                                tier="FREE",
                                                requested_user_verified=True,
                                            ),
                                        ],
                                        organization_feature=[
                                            UserOrganizationFeatureResource(
                                                user=UserResource(UserResource),
                                                user_id=1,
                                                organization_id=1,
                                                user_email="user_email_example",
                                                organization=OrganizationResource(
                                                    id=1,
                                                    name="name_example",
                                                    role="OWNER",
                                                    org_feature_flag=OrganizationFeatureFlagResource(
                                                        organization_id=1,
                                                        sub_domain=True,
                                                        strict_domain=True,
                                                        sso=True,
                                                        whitelist_ip=True,
                                                        circle_ci=True,
                                                        test_ops_integration=True,
                                                    ),
                                                    quota_kse=1,
                                                    machine_quota_kse=1,
                                                    quota_unlimited_kse=1,
                                                    quota_engine=1,
                                                    machine_quota_engine=1,
                                                    quota_unlimited_engine=1,
                                                    used_kse=1,
                                                    used_unlimited_kse=1,
                                                    used_engine=1,
                                                    used_unlimited_engine=1,
                                                    quota_test_ops=1,
                                                    used_test_ops=1,
                                                    number_user=1,
                                                    quota_floating_engine=1,
                                                    used_floating_engine=1,
                                                    can_create_offline_kse=True,
                                                    can_create_offline_unlimited_kse=True,
                                                    can_create_offline_re=True,
                                                    can_create_offline_unlimited_engine=True,
                                                    subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    subscribed=True,
                                                    kse_paygo=True,
                                                    kre_paygo=True,
                                                    paygo_quota=1,
                                                    domain="domain_example",
                                                    subdomain_url="subdomain_url_example",
                                                    strict_domain=True,
                                                    logo_url="logo_url_example",
                                                    saml_sso=True,
                                                    kre_license=True,
                                                    most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    account_id=1,
                                                    test_ops_feature="KSE",
                                                    platform_feature="KSE",
                                                    tier="FREE",
                                                    requested_user_verified=True,
                                                ),
                                                feature="KSE",
                                            ),
                                        ],
                                        trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        system_role="USER",
                                        survey_status="NOT_SUBMITTED",
                                        session_timeout=1,
                                        business_user=True,
                                        can_create_offline_kse=True,
                                        can_create_offline_re=True,
                                        saml_sso=True,
                                        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        full_name="full_name_example",
                                    ),
                                ],
                                organization=OrganizationResource(
                                    id=1,
                                    name="name_example",
                                    role="OWNER",
                                    org_feature_flag=OrganizationFeatureFlagResource(
                                        organization_id=1,
                                        sub_domain=True,
                                        strict_domain=True,
                                        sso=True,
                                        whitelist_ip=True,
                                        circle_ci=True,
                                        test_ops_integration=True,
                                    ),
                                    quota_kse=1,
                                    machine_quota_kse=1,
                                    quota_unlimited_kse=1,
                                    quota_engine=1,
                                    machine_quota_engine=1,
                                    quota_unlimited_engine=1,
                                    used_kse=1,
                                    used_unlimited_kse=1,
                                    used_engine=1,
                                    used_unlimited_engine=1,
                                    quota_test_ops=1,
                                    used_test_ops=1,
                                    number_user=1,
                                    quota_floating_engine=1,
                                    used_floating_engine=1,
                                    can_create_offline_kse=True,
                                    can_create_offline_unlimited_kse=True,
                                    can_create_offline_re=True,
                                    can_create_offline_unlimited_engine=True,
                                    subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscribed=True,
                                    kse_paygo=True,
                                    kre_paygo=True,
                                    paygo_quota=1,
                                    domain="domain_example",
                                    subdomain_url="subdomain_url_example",
                                    strict_domain=True,
                                    logo_url="logo_url_example",
                                    saml_sso=True,
                                    kre_license=True,
                                    most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    account_id=1,
                                    test_ops_feature="KSE",
                                    platform_feature="KSE",
                                    tier="FREE",
                                    requested_user_verified=True,
                                ),
                                organization_id=1,
                            ),
                            timezone="timezone_example",
                            status="ARCHIVE",
                        ),
                        build_id=1,
                        order=1,
                        execution_stage="RUNNING",
                        web_url="web_url_example",
                        test_suite_collections=[
                            TestSuiteCollectionEntityResource(
                                id=1,
                                name="name_example",
                                project=ProjectResource(
                                    id=1,
                                    name="name_example",
                                    team_id=1,
                                    team=TeamResource(
                                        id=1,
                                        name="name_example",
                                        role="OWNER",
                                        users=[],
                                        organization=OrganizationResource(
                                            id=1,
                                            name="name_example",
                                            role="OWNER",
                                            org_feature_flag=OrganizationFeatureFlagResource(
                                                organization_id=1,
                                                sub_domain=True,
                                                strict_domain=True,
                                                sso=True,
                                                whitelist_ip=True,
                                                circle_ci=True,
                                                test_ops_integration=True,
                                            ),
                                            quota_kse=1,
                                            machine_quota_kse=1,
                                            quota_unlimited_kse=1,
                                            quota_engine=1,
                                            machine_quota_engine=1,
                                            quota_unlimited_engine=1,
                                            used_kse=1,
                                            used_unlimited_kse=1,
                                            used_engine=1,
                                            used_unlimited_engine=1,
                                            quota_test_ops=1,
                                            used_test_ops=1,
                                            number_user=1,
                                            quota_floating_engine=1,
                                            used_floating_engine=1,
                                            can_create_offline_kse=True,
                                            can_create_offline_unlimited_kse=True,
                                            can_create_offline_re=True,
                                            can_create_offline_unlimited_engine=True,
                                            subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            subscribed=True,
                                            kse_paygo=True,
                                            kre_paygo=True,
                                            paygo_quota=1,
                                            domain="domain_example",
                                            subdomain_url="subdomain_url_example",
                                            strict_domain=True,
                                            logo_url="logo_url_example",
                                            saml_sso=True,
                                            kre_license=True,
                                            most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            account_id=1,
                                            test_ops_feature="KSE",
                                            platform_feature="KSE",
                                            tier="FREE",
                                            requested_user_verified=True,
                                        ),
                                        organization_id=1,
                                    ),
                                    timezone="timezone_example",
                                    status="ARCHIVE",
                                ),
                                path="path_example",
                                url_id="url_id_example",
                            ),
                        ],
                        execution_test_suite_resources=[
                            ExecutionTestSuiteResource(
                                status="PASSED",
                                start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                end_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                duration=1,
                                elapsed_duration=1,
                                total_tests=1,
                                total_passed_tests=1,
                                total_failed_tests=1,
                                total_error_tests=1,
                                total_incomplete_tests=1,
                                total_skipped_tests=1,
                                total_diff_tests=1,
                                total_diff_passed_tests=1,
                                total_diff_failed_tests=1,
                                total_diff_error_tests=1,
                                total_diff_incomplete_tests=1,
                                id=1,
                                execution=ExecutionResource(ExecutionResource),
                                test_suite=TestSuiteResource(
                                    id=1,
                                    name="name_example",
                                    path="path_example",
                                    test_results=[
                                        ExecutionTestResultResource(
                                            id=1,
                                            test_case=TestCaseResource(
                                                id=1,
                                                name="name_example",
                                                path="path_example",
                                                previous_status="PASSED",
                                                alias="alias_example",
                                                test_module_id=1,
                                                web_url="web_url_example",
                                                description="description_example",
                                                project=ProjectResource(
                                                    id=1,
                                                    name="name_example",
                                                    team_id=1,
                                                    team=TeamResource(
                                                        id=1,
                                                        name="name_example",
                                                        role="OWNER",
                                                        users=[],
                                                        organization=OrganizationResource(
                                                            id=1,
                                                            name="name_example",
                                                            role="OWNER",
                                                            org_feature_flag=OrganizationFeatureFlagResource(
                                                                organization_id=1,
                                                                sub_domain=True,
                                                                strict_domain=True,
                                                                sso=True,
                                                                whitelist_ip=True,
                                                                circle_ci=True,
                                                                test_ops_integration=True,
                                                            ),
                                                            quota_kse=1,
                                                            machine_quota_kse=1,
                                                            quota_unlimited_kse=1,
                                                            quota_engine=1,
                                                            machine_quota_engine=1,
                                                            quota_unlimited_engine=1,
                                                            used_kse=1,
                                                            used_unlimited_kse=1,
                                                            used_engine=1,
                                                            used_unlimited_engine=1,
                                                            quota_test_ops=1,
                                                            used_test_ops=1,
                                                            number_user=1,
                                                            quota_floating_engine=1,
                                                            used_floating_engine=1,
                                                            can_create_offline_kse=True,
                                                            can_create_offline_unlimited_kse=True,
                                                            can_create_offline_re=True,
                                                            can_create_offline_unlimited_engine=True,
                                                            subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                            subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                            subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                            subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                            subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                            subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                            subscribed=True,
                                                            kse_paygo=True,
                                                            kre_paygo=True,
                                                            paygo_quota=1,
                                                            domain="domain_example",
                                                            subdomain_url="subdomain_url_example",
                                                            strict_domain=True,
                                                            logo_url="logo_url_example",
                                                            saml_sso=True,
                                                            kre_license=True,
                                                            most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                            account_id=1,
                                                            test_ops_feature="KSE",
                                                            platform_feature="KSE",
                                                            tier="FREE",
                                                            requested_user_verified=True,
                                                        ),
                                                        organization_id=1,
                                                    ),
                                                    timezone="timezone_example",
                                                    status="ARCHIVE",
                                                ),
                                                last_execution_test_case=ExecutionTestCaseResource(
                                                    status="PASSED",
                                                    start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    end_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    duration=1,
                                                    elapsed_duration=1,
                                                    total_tests=1,
                                                    total_passed_tests=1,
                                                    total_failed_tests=1,
                                                    total_error_tests=1,
                                                    total_incomplete_tests=1,
                                                    total_skipped_tests=1,
                                                    total_diff_tests=1,
                                                    total_diff_passed_tests=1,
                                                    total_diff_failed_tests=1,
                                                    total_diff_error_tests=1,
                                                    total_diff_incomplete_tests=1,
                                                    execution_id=1,
                                                    execution_order=1,
                                                    test_case_id=1,
                                                    project_id=1,
                                                ),
                                                external_issues=[
                                                    ExternalIssueResource(
                                                        id=1,
                                                        issue_id="issue_id_example",
                                                        summary="summary_example",
                                                        status="status_example",
                                                        issue_type_icon="issue_type_icon_example",
                                                        issue_type_name="issue_type_name_example",
                                                        url="url_example",
                                                        feature_name="feature_name_example",
                                                        test_cases=[
                                                            TestCaseResource(TestCaseResource),
                                                        ],
                                                    ),
                                                ],
                                                custom_field_options=[
                                                    CustomFieldOptionResource(
                                                        id=1,
                                                        value="value_example",
                                                        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                        definition_id=1,
                                                    ),
                                                ],
                                                type="TEST_CASE",
                                                average_duration=3.14,
                                                max_duration=1,
                                                min_duration=1,
                                                flakiness=3.14,
                                                platform_statistics={
                                                    "key": TestCasePlatformStatisticsResource(
                                                        total_tests=1,
                                                        total_passed_tests=1,
                                                        total_failed_tests=1,
                                                        total_error_tests=1,
                                                        total_incomplete_tests=1,
                                                        total_skipped_tests=1,
                                                        platform=PlatformResource(
                                                            id=1,
                                                            os_name="os_name_example",
                                                            os_version="os_version_example",
                                                            browser_name="browser_name_example",
                                                            browser_version="browser_version_example",
                                                            device_name="device_name_example",
                                                            app_name="app_name_example",
                                                        ),
                                                        platform_id=1,
                                                    ),
                                                },
                                                maintainer=UserResource(
                                                    id=1,
                                                    email="email_example",
                                                    first_name="first_name_example",
                                                    last_name="last_name_example",
                                                    password="password_example",
                                                    inviting_url="inviting_url_example",
                                                    avatar="avatar_example",
                                                    configs=ConfigResource(
                                                        web_socket_url="web_socket_url_example",
                                                        store_url="store_url_example",
                                                        profiles=[],
                                                        stripe_public_api="stripe_public_api_example",
                                                        build_version="build_version_example",
                                                        commit_id="commit_id_example",
                                                        sentry_dsn="sentry_dsn_example",
                                                        sentry_env="sentry_env_example",
                                                        sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                                                        server_url="server_url_example",
                                                        io_server_url="io_server_url_example",
                                                        proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                                                        max_execution_comparison=1,
                                                        max_execution_download=1,
                                                        agent_download_urls={},
                                                        proxy_tunnel_download_urls={},
                                                        report_uploader_download_url="report_uploader_download_url_example",
                                                        report_uploader_latest_version="report_uploader_latest_version_example",
                                                        sub_domain_pattern="sub_domain_pattern_example",
                                                        cancellation_survey_url="cancellation_survey_url_example",
                                                        launch_darkly_client_id="launch_darkly_client_id_example",
                                                        launch_darkly_default_user="launch_darkly_default_user_example",
                                                        launch_darkly_prefix="launch_darkly_prefix_example",
                                                        min_test_execution_ordered=1,
                                                        user_flow_token="user_flow_token_example",
                                                        demo_project_url="demo_project_url_example",
                                                        advanced_feature_enabled=True,
                                                        using_sub_domain=True,
                                                        test_ops_subscription_enabled=True,
                                                        frameworks_integration_enabled=True,
                                                    ),
                                                    projects=[],
                                                    teams=[],
                                                    organizations=[],
                                                    organization_feature=[],
                                                    trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    system_role="USER",
                                                    survey_status="NOT_SUBMITTED",
                                                    session_timeout=1,
                                                    business_user=True,
                                                    can_create_offline_kse=True,
                                                    can_create_offline_re=True,
                                                    saml_sso=True,
                                                    created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    full_name="full_name_example",
                                                ),
                                                test_result_assertion=TestResultAssertionResource(
                                                    execution_test_result_id=1,
                                                    execution_test_result=ExecutionTestResultResource(ExecutionTestResultResource),
                                                    total_assertion=1,
                                                    passed_assertion=1,
                                                    failed_assertion=1,
                                                ),
                                                updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                test_project=TestProjectResource(TestProjectResource),
                                                number_of_executions=1,
                                                url_id="url_id_example",
                                            ),
                                            execution=ExecutionResource(ExecutionResource),
                                            platform=PlatformResource(
                                                id=1,
                                                os_name="os_name_example",
                                                os_version="os_version_example",
                                                browser_name="browser_name_example",
                                                browser_version="browser_version_example",
                                                device_name="device_name_example",
                                                app_name="app_name_example",
                                            ),
                                            status="PASSED",
                                            same_status_period=1,
                                            error_details_id=1,
                                            stdout_id=1,
                                            description_id=1,
                                            log_id=1,
                                            attachments=[
                                                FileResource(
                                                    id=1,
                                                    upload_file_id=1,
                                                    _self="_self_example",
                                                    name="name_example",
                                                    path="path_example",
                                                    url="url_example",
                                                    hash="hash_example",
                                                    size=1,
                                                    upload_url="upload_url_example",
                                                    signed_url="signed_url_example",
                                                    thumbnail_url="thumbnail_url_example",
                                                ),
                                            ],
                                            test_result_assertions_failed=[
                                                TestResultAssertionFailedResource(
                                                    id=1,
                                                    execution_test_result_id=1,
                                                    execution_test_result_resource=ExecutionTestResultResource(ExecutionTestResultResource),
                                                    stacktrace="stacktrace_example",
                                                    message="message_example",
                                                    log_time="log_time_example",
                                                ),
                                            ],
                                            start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            end_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                            duration=1,
                                            same_failure_results=[
                                                ExecutionTestResultIdentifyResource(
                                                    id=1,
                                                    execution_id=1,
                                                    url_id="url_id_example",
                                                ),
                                            ],
                                            test_suite=TestSuiteResource(TestSuiteResource),
                                            execution_test_suite=ExecutionTestSuiteResource(ExecutionTestSuiteResource),
                                            incidents=[
                                                IncidentResource(
                                                    id=1,
                                                    name="name_example",
                                                    description="description_example",
                                                    project_id=1,
                                                    team_id=1,
                                                    url_ids=[
                                                        "url_ids_example",
                                                    ],
                                                    execution_test_result_ids=[
                                                        1,
                                                    ],
                                                    order=1,
                                                    created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                    updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                ),
                                            ],
                                            profile="profile_example",
                                            has_comment=True,
                                            error_message="error_message_example",
                                            error_detail="error_detail_example",
                                            web_url="web_url_example",
                                            external_issues=[],
                                            failed_test_result_category="APPLICATION",
                                            total_test_object=1,
                                            total_defects=1,
                                            total_assertion=1,
                                            passed_assertion=1,
                                            failed_assertion=1,
                                            retried=True,
                                            last_retry_test_id=1,
                                            current_retry=1,
                                            original_status="PASSED",
                                            last_changed_by=UserResource(
                                                id=1,
                                                email="email_example",
                                                first_name="first_name_example",
                                                last_name="last_name_example",
                                                password="password_example",
                                                inviting_url="inviting_url_example",
                                                avatar="avatar_example",
                                                configs=ConfigResource(
                                                    web_socket_url="web_socket_url_example",
                                                    store_url="store_url_example",
                                                    profiles=[],
                                                    stripe_public_api="stripe_public_api_example",
                                                    build_version="build_version_example",
                                                    commit_id="commit_id_example",
                                                    sentry_dsn="sentry_dsn_example",
                                                    sentry_env="sentry_env_example",
                                                    sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                                                    server_url="server_url_example",
                                                    io_server_url="io_server_url_example",
                                                    proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                                                    max_execution_comparison=1,
                                                    max_execution_download=1,
                                                    agent_download_urls={},
                                                    proxy_tunnel_download_urls={},
                                                    report_uploader_download_url="report_uploader_download_url_example",
                                                    report_uploader_latest_version="report_uploader_latest_version_example",
                                                    sub_domain_pattern="sub_domain_pattern_example",
                                                    cancellation_survey_url="cancellation_survey_url_example",
                                                    launch_darkly_client_id="launch_darkly_client_id_example",
                                                    launch_darkly_default_user="launch_darkly_default_user_example",
                                                    launch_darkly_prefix="launch_darkly_prefix_example",
                                                    min_test_execution_ordered=1,
                                                    user_flow_token="user_flow_token_example",
                                                    demo_project_url="demo_project_url_example",
                                                    advanced_feature_enabled=True,
                                                    using_sub_domain=True,
                                                    test_ops_subscription_enabled=True,
                                                    frameworks_integration_enabled=True,
                                                ),
                                                projects=[],
                                                teams=[],
                                                organizations=[],
                                                organization_feature=[],
                                                trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                system_role="USER",
                                                survey_status="NOT_SUBMITTED",
                                                session_timeout=1,
                                                business_user=True,
                                                can_create_offline_kse=True,
                                                can_create_offline_re=True,
                                                saml_sso=True,
                                                created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                full_name="full_name_example",
                                            ),
                                            error_keyword="error_keyword_example",
                                            status_edited=True,
                                            url_id="url_id_example",
                                        ),
                                    ],
                                    project=ProjectResource(
                                        id=1,
                                        name="name_example",
                                        team_id=1,
                                        team=TeamResource(
                                            id=1,
                                            name="name_example",
                                            role="OWNER",
                                            users=[],
                                            organization=OrganizationResource(
                                                id=1,
                                                name="name_example",
                                                role="OWNER",
                                                org_feature_flag=OrganizationFeatureFlagResource(
                                                    organization_id=1,
                                                    sub_domain=True,
                                                    strict_domain=True,
                                                    sso=True,
                                                    whitelist_ip=True,
                                                    circle_ci=True,
                                                    test_ops_integration=True,
                                                ),
                                                quota_kse=1,
                                                machine_quota_kse=1,
                                                quota_unlimited_kse=1,
                                                quota_engine=1,
                                                machine_quota_engine=1,
                                                quota_unlimited_engine=1,
                                                used_kse=1,
                                                used_unlimited_kse=1,
                                                used_engine=1,
                                                used_unlimited_engine=1,
                                                quota_test_ops=1,
                                                used_test_ops=1,
                                                number_user=1,
                                                quota_floating_engine=1,
                                                used_floating_engine=1,
                                                can_create_offline_kse=True,
                                                can_create_offline_unlimited_kse=True,
                                                can_create_offline_re=True,
                                                can_create_offline_unlimited_engine=True,
                                                subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscribed=True,
                                                kse_paygo=True,
                                                kre_paygo=True,
                                                paygo_quota=1,
                                                domain="domain_example",
                                                subdomain_url="subdomain_url_example",
                                                strict_domain=True,
                                                logo_url="logo_url_example",
                                                saml_sso=True,
                                                kre_license=True,
                                                most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                account_id=1,
                                                test_ops_feature="KSE",
                                                platform_feature="KSE",
                                                tier="FREE",
                                                requested_user_verified=True,
                                            ),
                                            organization_id=1,
                                        ),
                                        timezone="timezone_example",
                                        status="ARCHIVE",
                                    ),
                                    alias="alias_example",
                                    last_execution_test_suite=ExecutionTestSuiteResource(ExecutionTestSuiteResource),
                                    updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    test_cases=[],
                                    test_project=TestProjectResource(TestProjectResource),
                                    created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    user=UserResource(
                                        id=1,
                                        email="email_example",
                                        first_name="first_name_example",
                                        last_name="last_name_example",
                                        password="password_example",
                                        inviting_url="inviting_url_example",
                                        avatar="avatar_example",
                                        configs=ConfigResource(
                                            web_socket_url="web_socket_url_example",
                                            store_url="store_url_example",
                                            profiles=[],
                                            stripe_public_api="stripe_public_api_example",
                                            build_version="build_version_example",
                                            commit_id="commit_id_example",
                                            sentry_dsn="sentry_dsn_example",
                                            sentry_env="sentry_env_example",
                                            sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                                            server_url="server_url_example",
                                            io_server_url="io_server_url_example",
                                            proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                                            max_execution_comparison=1,
                                            max_execution_download=1,
                                            agent_download_urls={},
                                            proxy_tunnel_download_urls={},
                                            report_uploader_download_url="report_uploader_download_url_example",
                                            report_uploader_latest_version="report_uploader_latest_version_example",
                                            sub_domain_pattern="sub_domain_pattern_example",
                                            cancellation_survey_url="cancellation_survey_url_example",
                                            launch_darkly_client_id="launch_darkly_client_id_example",
                                            launch_darkly_default_user="launch_darkly_default_user_example",
                                            launch_darkly_prefix="launch_darkly_prefix_example",
                                            min_test_execution_ordered=1,
                                            user_flow_token="user_flow_token_example",
                                            demo_project_url="demo_project_url_example",
                                            advanced_feature_enabled=True,
                                            using_sub_domain=True,
                                            test_ops_subscription_enabled=True,
                                            frameworks_integration_enabled=True,
                                        ),
                                        projects=[],
                                        teams=[],
                                        organizations=[],
                                        organization_feature=[],
                                        trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        system_role="USER",
                                        survey_status="NOT_SUBMITTED",
                                        session_timeout=1,
                                        business_user=True,
                                        can_create_offline_kse=True,
                                        can_create_offline_re=True,
                                        saml_sso=True,
                                        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        full_name="full_name_example",
                                    ),
                                    type="KATALON_STUDIO",
                                    test_folder=TestFolderResource(
                                        id=1,
                                        name="name_example",
                                        raw_path="raw_path_example",
                                        test_project=TestProjectResource(TestProjectResource),
                                        tree_path="tree_path_example",
                                        parent_id=1,
                                    ),
                                    url_id="url_id_example",
                                ),
                                platform=PlatformResource(
                                    id=1,
                                    os_name="os_name_example",
                                    os_version="os_version_example",
                                    browser_name="browser_name_example",
                                    browser_version="browser_version_example",
                                    device_name="device_name_example",
                                    app_name="app_name_example",
                                ),
                                execution_id=1,
                                profiles=[],
                                has_comment=True,
                                url_id="url_id_example",
                            ),
                        ],
                        release=ReleaseResource(
                            id=1,
                            name="name_example",
                            start_time=dateutil_parser('1970-01-01').date(),
                            end_time=dateutil_parser('1970-01-01').date(),
                            description="description_example",
                            project_id=1,
                            closed=True,
                            created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            external_release=ExternalReleaseResource(
                                id=1,
                                release_id="release_id_example",
                                description="description_example",
                                name="name_example",
                                archived=True,
                                released=True,
                                project_id="project_id_example",
                                external_project=ExternalProjectResource(
                                    id=1,
                                    external_project_id="external_project_id_example",
                                    external_project_key="external_project_key_example",
                                    name="name_example",
                                ),
                                web_url="web_url_example",
                                jira_release_status="RELEASED",
                                start_date=dateutil_parser('1970-01-01').date(),
                                release_date=dateutil_parser('1970-01-01').date(),
                            ),
                            release_statistics=ReleaseStatisticsResource(
                                id=1,
                                release=ReleaseResource(ReleaseResource),
                                total_passed=1,
                                total_failed=1,
                                total_execution=1,
                                total_defect=1,
                                total_duration=1,
                            ),
                            builds=[
                                BuildResource(
                                    id=1,
                                    project_id=1,
                                    project=ProjectResource(
                                        id=1,
                                        name="name_example",
                                        team_id=1,
                                        team=TeamResource(
                                            id=1,
                                            name="name_example",
                                            role="OWNER",
                                            users=[],
                                            organization=OrganizationResource(
                                                id=1,
                                                name="name_example",
                                                role="OWNER",
                                                org_feature_flag=OrganizationFeatureFlagResource(
                                                    organization_id=1,
                                                    sub_domain=True,
                                                    strict_domain=True,
                                                    sso=True,
                                                    whitelist_ip=True,
                                                    circle_ci=True,
                                                    test_ops_integration=True,
                                                ),
                                                quota_kse=1,
                                                machine_quota_kse=1,
                                                quota_unlimited_kse=1,
                                                quota_engine=1,
                                                machine_quota_engine=1,
                                                quota_unlimited_engine=1,
                                                used_kse=1,
                                                used_unlimited_kse=1,
                                                used_engine=1,
                                                used_unlimited_engine=1,
                                                quota_test_ops=1,
                                                used_test_ops=1,
                                                number_user=1,
                                                quota_floating_engine=1,
                                                used_floating_engine=1,
                                                can_create_offline_kse=True,
                                                can_create_offline_unlimited_kse=True,
                                                can_create_offline_re=True,
                                                can_create_offline_unlimited_engine=True,
                                                subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                subscribed=True,
                                                kse_paygo=True,
                                                kre_paygo=True,
                                                paygo_quota=1,
                                                domain="domain_example",
                                                subdomain_url="subdomain_url_example",
                                                strict_domain=True,
                                                logo_url="logo_url_example",
                                                saml_sso=True,
                                                kre_license=True,
                                                most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                                account_id=1,
                                                test_ops_feature="KSE",
                                                platform_feature="KSE",
                                                tier="FREE",
                                                requested_user_verified=True,
                                            ),
                                            organization_id=1,
                                        ),
                                        timezone="timezone_example",
                                        status="ARCHIVE",
                                    ),
                                    release_id=1,
                                    release=ReleaseResource(ReleaseResource),
                                    build_statistics=BuildStatisticsResource(
                                        id=1,
                                        build=BuildResource(BuildResource),
                                        total_execution=1,
                                        total_passed=1,
                                        total_failed=1,
                                    ),
                                    name="name_example",
                                    description="description_example",
                                    date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                ),
                            ],
                            release_status="NOT_READY",
                        ),
                        build=BuildResource(
                            id=1,
                            project_id=1,
                            project=ProjectResource(
                                id=1,
                                name="name_example",
                                team_id=1,
                                team=TeamResource(
                                    id=1,
                                    name="name_example",
                                    role="OWNER",
                                    users=[],
                                    organization=OrganizationResource(
                                        id=1,
                                        name="name_example",
                                        role="OWNER",
                                        org_feature_flag=OrganizationFeatureFlagResource(
                                            organization_id=1,
                                            sub_domain=True,
                                            strict_domain=True,
                                            sso=True,
                                            whitelist_ip=True,
                                            circle_ci=True,
                                            test_ops_integration=True,
                                        ),
                                        quota_kse=1,
                                        machine_quota_kse=1,
                                        quota_unlimited_kse=1,
                                        quota_engine=1,
                                        machine_quota_engine=1,
                                        quota_unlimited_engine=1,
                                        used_kse=1,
                                        used_unlimited_kse=1,
                                        used_engine=1,
                                        used_unlimited_engine=1,
                                        quota_test_ops=1,
                                        used_test_ops=1,
                                        number_user=1,
                                        quota_floating_engine=1,
                                        used_floating_engine=1,
                                        can_create_offline_kse=True,
                                        can_create_offline_unlimited_kse=True,
                                        can_create_offline_re=True,
                                        can_create_offline_unlimited_engine=True,
                                        subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        subscribed=True,
                                        kse_paygo=True,
                                        kre_paygo=True,
                                        paygo_quota=1,
                                        domain="domain_example",
                                        subdomain_url="subdomain_url_example",
                                        strict_domain=True,
                                        logo_url="logo_url_example",
                                        saml_sso=True,
                                        kre_license=True,
                                        most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        account_id=1,
                                        test_ops_feature="KSE",
                                        platform_feature="KSE",
                                        tier="FREE",
                                        requested_user_verified=True,
                                    ),
                                    organization_id=1,
                                ),
                                timezone="timezone_example",
                                status="ARCHIVE",
                            ),
                            release_id=1,
                            release=ReleaseResource(
                                id=1,
                                name="name_example",
                                start_time=dateutil_parser('1970-01-01').date(),
                                end_time=dateutil_parser('1970-01-01').date(),
                                description="description_example",
                                project_id=1,
                                closed=True,
                                created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                external_release=ExternalReleaseResource(
                                    id=1,
                                    release_id="release_id_example",
                                    description="description_example",
                                    name="name_example",
                                    archived=True,
                                    released=True,
                                    project_id="project_id_example",
                                    external_project=ExternalProjectResource(
                                        id=1,
                                        external_project_id="external_project_id_example",
                                        external_project_key="external_project_key_example",
                                        name="name_example",
                                    ),
                                    web_url="web_url_example",
                                    jira_release_status="RELEASED",
                                    start_date=dateutil_parser('1970-01-01').date(),
                                    release_date=dateutil_parser('1970-01-01').date(),
                                ),
                                release_statistics=ReleaseStatisticsResource(
                                    id=1,
                                    release=ReleaseResource(ReleaseResource),
                                    total_passed=1,
                                    total_failed=1,
                                    total_execution=1,
                                    total_defect=1,
                                    total_duration=1,
                                ),
                                builds=[],
                                release_status="NOT_READY",
                            ),
                            build_statistics=BuildStatisticsResource(
                                id=1,
                                build=BuildResource(BuildResource),
                                total_execution=1,
                                total_passed=1,
                                total_failed=1,
                            ),
                            name="name_example",
                            description="description_example",
                            date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        ),
                        has_comment=True,
                        user=UserResource(
                            id=1,
                            email="email_example",
                            first_name="first_name_example",
                            last_name="last_name_example",
                            password="password_example",
                            inviting_url="inviting_url_example",
                            avatar="avatar_example",
                            configs=ConfigResource(
                                web_socket_url="web_socket_url_example",
                                store_url="store_url_example",
                                profiles=[],
                                stripe_public_api="stripe_public_api_example",
                                build_version="build_version_example",
                                commit_id="commit_id_example",
                                sentry_dsn="sentry_dsn_example",
                                sentry_env="sentry_env_example",
                                sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                                server_url="server_url_example",
                                io_server_url="io_server_url_example",
                                proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                                max_execution_comparison=1,
                                max_execution_download=1,
                                agent_download_urls={},
                                proxy_tunnel_download_urls={},
                                report_uploader_download_url="report_uploader_download_url_example",
                                report_uploader_latest_version="report_uploader_latest_version_example",
                                sub_domain_pattern="sub_domain_pattern_example",
                                cancellation_survey_url="cancellation_survey_url_example",
                                launch_darkly_client_id="launch_darkly_client_id_example",
                                launch_darkly_default_user="launch_darkly_default_user_example",
                                launch_darkly_prefix="launch_darkly_prefix_example",
                                min_test_execution_ordered=1,
                                user_flow_token="user_flow_token_example",
                                demo_project_url="demo_project_url_example",
                                advanced_feature_enabled=True,
                                using_sub_domain=True,
                                test_ops_subscription_enabled=True,
                                frameworks_integration_enabled=True,
                            ),
                            projects=[],
                            teams=[],
                            organizations=[],
                            organization_feature=[],
                            trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            system_role="USER",
                            survey_status="NOT_SUBMITTED",
                            session_timeout=1,
                            business_user=True,
                            can_create_offline_kse=True,
                            can_create_offline_re=True,
                            saml_sso=True,
                            created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            full_name="full_name_example",
                        ),
                        session_id="session_id_example",
                        build_label="build_label_example",
                        build_url="build_url_example",
                        type="KATALON",
                        jobs=[
                            JobResource(JobResource),
                        ],
                        use_test_cloud_tunnel=True,
                        getk_eyes_execution=KEyesExecutionResource(
                            id=1,
                            status="RUNNING",
                            execution=ExecutionResource(ExecutionResource),
                            total_checkpoints=1,
                            passed_checkpoints=1,
                            failed_checkpoints=1,
                            unresolved_checkpoints=1,
                            unsaved=True,
                            baseline_collection=BaselineCollectionResource(
                                id=1,
                                version=1,
                                baselines=[
                                    BaselineResource(
                                        id=1,
                                        upload_file=UploadFileResource(
                                            path="path_example",
                                            file_name="file_name_example",
                                            type="TSC_EXECUTION",
                                            base64_content="base64_content_example",
                                            file_handle_id=1,
                                            thumbnail_id=1,
                                        ),
                                        screenshot_id=1,
                                        execution=ExecutionResource(ExecutionResource),
                                        screenshot=ScreenshotResource(
                                            name="name_example",
                                            width=3.14,
                                            height=3.14,
                                        ),
                                        width=3.14,
                                        height=3.14,
                                        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                        draft_ignoring_zones=[
                                            IgnoringZoneResource(
                                                uuid="uuid_example",
                                                x=1,
                                                y=1,
                                                w=1,
                                                h=1,
                                                type="ALL",
                                            ),
                                        ],
                                        ignoring_zones=[
                                            IgnoringZoneResource(
                                                uuid="uuid_example",
                                                x=1,
                                                y=1,
                                                w=1,
                                                h=1,
                                                type="ALL",
                                            ),
                                        ],
                                    ),
                                ],
                                number_of_baselines=1,
                                updated_by=UserResource(
                                    id=1,
                                    email="email_example",
                                    first_name="first_name_example",
                                    last_name="last_name_example",
                                    password="password_example",
                                    inviting_url="inviting_url_example",
                                    avatar="avatar_example",
                                    configs=ConfigResource(
                                        web_socket_url="web_socket_url_example",
                                        store_url="store_url_example",
                                        profiles=[],
                                        stripe_public_api="stripe_public_api_example",
                                        build_version="build_version_example",
                                        commit_id="commit_id_example",
                                        sentry_dsn="sentry_dsn_example",
                                        sentry_env="sentry_env_example",
                                        sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                                        server_url="server_url_example",
                                        io_server_url="io_server_url_example",
                                        proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                                        max_execution_comparison=1,
                                        max_execution_download=1,
                                        agent_download_urls={},
                                        proxy_tunnel_download_urls={},
                                        report_uploader_download_url="report_uploader_download_url_example",
                                        report_uploader_latest_version="report_uploader_latest_version_example",
                                        sub_domain_pattern="sub_domain_pattern_example",
                                        cancellation_survey_url="cancellation_survey_url_example",
                                        launch_darkly_client_id="launch_darkly_client_id_example",
                                        launch_darkly_default_user="launch_darkly_default_user_example",
                                        launch_darkly_prefix="launch_darkly_prefix_example",
                                        min_test_execution_ordered=1,
                                        user_flow_token="user_flow_token_example",
                                        demo_project_url="demo_project_url_example",
                                        advanced_feature_enabled=True,
                                        using_sub_domain=True,
                                        test_ops_subscription_enabled=True,
                                        frameworks_integration_enabled=True,
                                    ),
                                    projects=[],
                                    teams=[],
                                    organizations=[],
                                    organization_feature=[],
                                    trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    system_role="USER",
                                    survey_status="NOT_SUBMITTED",
                                    session_timeout=1,
                                    business_user=True,
                                    can_create_offline_kse=True,
                                    can_create_offline_re=True,
                                    saml_sso=True,
                                    created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    full_name="full_name_example",
                                ),
                                baseline_collection_group=BaselineCollectionGroupResource(
                                    id=1,
                                    name="name_example",
                                    latest_version=BaselineCollectionResource(BaselineCollectionResource),
                                    run_configurations=[
                                        RunConfigurationResource(RunConfigurationResource),
                                    ],
                                    updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    order=1,
                                    last_run=KEyesExecutionResource(KEyesExecutionResource),
                                ),
                                unsaved=True,
                                default_method="PIXEL",
                                draft_default_method="PIXEL",
                                threshold=1,
                                draft_threshold=1,
                                create_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            ),
                        ),
                        data_type="USER_DATA",
                    ),
                    agent=AgentResource(
                        id=1,
                        name="name_example",
                        ip="ip_example",
                        uuid="uuid_example",
                        last_ping=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        os="os_example",
                        team_id=1,
                        hostname="hostname_example",
                        active=True,
                        threshold=1,
                        num_executing_jobs=1,
                        num_assigned_jobs=1,
                        agent_version="agent_version_example",
                        deleted=True,
                    ),
                    test_cloud_agent=TestCloudAgentResource(
                        id=1,
                        name="name_example",
                        os="os_example",
                        os_version="os_version_example",
                        browser="browser_example",
                        browser_version="browser_version_example",
                        device_name="device_name_example",
                        app_id="app_id_example",
                        app_group_id="app_group_id_example",
                        app_name="app_name_example",
                        device_id="device_id_example",
                        num_executing_jobs=1,
                        num_assigned_jobs=1,
                        team_id=1,
                        deleted=True,
                        api_key="api_key_example",
                        total_duration=1,
                        headless=True,
                        execution_type="CHROME",
                    ),
                    k8s_agent=K8SAgentResource(
                        id=1,
                        name="name_example",
                        certificate_authority="certificate_authority_example",
                        url="url_example",
                        namespace="namespace_example",
                        username="username_example",
                        password="password_example",
                        token="token_example",
                        cluster="cluster_example",
                        region="region_example",
                        access_key="access_key_example",
                        private_access_key="private_access_key_example",
                        team_id=1,
                        api_key="api_key_example",
                        authentication_type="BASIC_AUTH",
                    ),
                    circle_ci_agent=CircleCIAgentResource(
                        id=1,
                        name="name_example",
                        url="url_example",
                        username="username_example",
                        token="token_example",
                        project="project_example",
                        vcs_type="vcs_type_example",
                        branch="branch_example",
                        team_id=1,
                        api_key="api_key_example",
                    ),
                    run_configuration=RunConfigurationResource(RunConfigurationResource),
                    order=1,
                    parameter=TriggerBuildParameter(
                        download_url="download_url_example",
                        command="command_example",
                        environment_variables=[
                            EnvironmentVariable(
                                name="name_example",
                                value="value_example",
                            ),
                        ],
                        session_id="session_id_example",
                        ks_version="ks_version_example",
                        ks_location="ks_location_example",
                        config_type="TSC",
                        type="KS",
                        git_repository_resource=GitRepositoryResource(
                            id=1,
                            test_project_id=1,
                            name="name_example",
                            repository="repository_example",
                            branch="branch_example",
                            username="username_example",
                            password="password_example",
                            access_key_id="access_key_id_example",
                            secret_access_key="secret_access_key_example",
                            project_id=1,
                            team_id=1,
                            created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            description="description_example",
                            vcs_type="GITHUB",
                            should_merge_test_results_for_new_script_repo=True,
                        ),
                        test_ops_download_url="test_ops_download_url_example",
                        extra_files=[
                            KSFile(
                                content_url="content_url_example",
                                path="path_example",
                                write_mode="OVERRIDE",
                            ),
                        ],
                        organization_id=1,
                    ),
                    trigger_by="MANUAL",
                    duration=1,
                    trigger_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    user=UserResource(
                        id=1,
                        email="email_example",
                        first_name="first_name_example",
                        last_name="last_name_example",
                        password="password_example",
                        inviting_url="inviting_url_example",
                        avatar="avatar_example",
                        configs=ConfigResource(
                            web_socket_url="web_socket_url_example",
                            store_url="store_url_example",
                            profiles=[],
                            stripe_public_api="stripe_public_api_example",
                            build_version="build_version_example",
                            commit_id="commit_id_example",
                            sentry_dsn="sentry_dsn_example",
                            sentry_env="sentry_env_example",
                            sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                            server_url="server_url_example",
                            io_server_url="io_server_url_example",
                            proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                            max_execution_comparison=1,
                            max_execution_download=1,
                            agent_download_urls={},
                            proxy_tunnel_download_urls={},
                            report_uploader_download_url="report_uploader_download_url_example",
                            report_uploader_latest_version="report_uploader_latest_version_example",
                            sub_domain_pattern="sub_domain_pattern_example",
                            cancellation_survey_url="cancellation_survey_url_example",
                            launch_darkly_client_id="launch_darkly_client_id_example",
                            launch_darkly_default_user="launch_darkly_default_user_example",
                            launch_darkly_prefix="launch_darkly_prefix_example",
                            min_test_execution_ordered=1,
                            user_flow_token="user_flow_token_example",
                            demo_project_url="demo_project_url_example",
                            advanced_feature_enabled=True,
                            using_sub_domain=True,
                            test_ops_subscription_enabled=True,
                            frameworks_integration_enabled=True,
                        ),
                        projects=[],
                        teams=[],
                        organizations=[],
                        organization_feature=[],
                        trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        system_role="USER",
                        survey_status="NOT_SUBMITTED",
                        session_timeout=1,
                        business_user=True,
                        can_create_offline_kse=True,
                        can_create_offline_re=True,
                        saml_sso=True,
                        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        full_name="full_name_example",
                    ),
                    scheduler=SchedulerResource(SchedulerResource),
                    project=ProjectResource(
                        id=1,
                        name="name_example",
                        team_id=1,
                        team=TeamResource(
                            id=1,
                            name="name_example",
                            role="OWNER",
                            users=[],
                            organization=OrganizationResource(
                                id=1,
                                name="name_example",
                                role="OWNER",
                                org_feature_flag=OrganizationFeatureFlagResource(
                                    organization_id=1,
                                    sub_domain=True,
                                    strict_domain=True,
                                    sso=True,
                                    whitelist_ip=True,
                                    circle_ci=True,
                                    test_ops_integration=True,
                                ),
                                quota_kse=1,
                                machine_quota_kse=1,
                                quota_unlimited_kse=1,
                                quota_engine=1,
                                machine_quota_engine=1,
                                quota_unlimited_engine=1,
                                used_kse=1,
                                used_unlimited_kse=1,
                                used_engine=1,
                                used_unlimited_engine=1,
                                quota_test_ops=1,
                                used_test_ops=1,
                                number_user=1,
                                quota_floating_engine=1,
                                used_floating_engine=1,
                                can_create_offline_kse=True,
                                can_create_offline_unlimited_kse=True,
                                can_create_offline_re=True,
                                can_create_offline_unlimited_engine=True,
                                subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscribed=True,
                                kse_paygo=True,
                                kre_paygo=True,
                                paygo_quota=1,
                                domain="domain_example",
                                subdomain_url="subdomain_url_example",
                                strict_domain=True,
                                logo_url="logo_url_example",
                                saml_sso=True,
                                kre_license=True,
                                most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                account_id=1,
                                test_ops_feature="KSE",
                                platform_feature="KSE",
                                tier="FREE",
                                requested_user_verified=True,
                            ),
                            organization_id=1,
                        ),
                        timezone="timezone_example",
                        status="ARCHIVE",
                    ),
                    process_id=1,
                    node_status="PENDING_CANCELED",
                    run_configuration_id=1,
                ),
                upload_file_name="upload_file_name_example",
                type="KS",
                git_repository=GitRepositoryResource(
                    id=1,
                    test_project_id=1,
                    name="name_example",
                    repository="repository_example",
                    branch="branch_example",
                    username="username_example",
                    password="password_example",
                    access_key_id="access_key_id_example",
                    secret_access_key="secret_access_key_example",
                    project_id=1,
                    team_id=1,
                    created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    description="description_example",
                    vcs_type="GITHUB",
                    should_merge_test_results_for_new_script_repo=True,
                ),
                test_suite_collections=[
                    TestSuiteCollectionResource(
                        id=1,
                        name="name_example",
                        project=ProjectResource(
                            id=1,
                            name="name_example",
                            team_id=1,
                            team=TeamResource(
                                id=1,
                                name="name_example",
                                role="OWNER",
                                users=[],
                                organization=OrganizationResource(
                                    id=1,
                                    name="name_example",
                                    role="OWNER",
                                    org_feature_flag=OrganizationFeatureFlagResource(
                                        organization_id=1,
                                        sub_domain=True,
                                        strict_domain=True,
                                        sso=True,
                                        whitelist_ip=True,
                                        circle_ci=True,
                                        test_ops_integration=True,
                                    ),
                                    quota_kse=1,
                                    machine_quota_kse=1,
                                    quota_unlimited_kse=1,
                                    quota_engine=1,
                                    machine_quota_engine=1,
                                    quota_unlimited_engine=1,
                                    used_kse=1,
                                    used_unlimited_kse=1,
                                    used_engine=1,
                                    used_unlimited_engine=1,
                                    quota_test_ops=1,
                                    used_test_ops=1,
                                    number_user=1,
                                    quota_floating_engine=1,
                                    used_floating_engine=1,
                                    can_create_offline_kse=True,
                                    can_create_offline_unlimited_kse=True,
                                    can_create_offline_re=True,
                                    can_create_offline_unlimited_engine=True,
                                    subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscribed=True,
                                    kse_paygo=True,
                                    kre_paygo=True,
                                    paygo_quota=1,
                                    domain="domain_example",
                                    subdomain_url="subdomain_url_example",
                                    strict_domain=True,
                                    logo_url="logo_url_example",
                                    saml_sso=True,
                                    kre_license=True,
                                    most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    account_id=1,
                                    test_ops_feature="KSE",
                                    platform_feature="KSE",
                                    tier="FREE",
                                    requested_user_verified=True,
                                ),
                                organization_id=1,
                            ),
                            timezone="timezone_example",
                            status="ARCHIVE",
                        ),
                        test_suite_collection_configurations=[
                            TestSuiteCollectionConfigurationResource(
                                id=1,
                                profile_name="profile_name_example",
                                browser_type="CHROME",
                                run_enabled=True,
                                sort_order=1,
                                test_suite_entity="test_suite_entity_example",
                            ),
                        ],
                        url_id="url_id_example",
                    ),
                ],
                dirty=True,
            ),
            agents=[
                AgentResource(
                    id=1,
                    name="name_example",
                    ip="ip_example",
                    uuid="uuid_example",
                    last_ping=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    os="os_example",
                    team_id=1,
                    hostname="hostname_example",
                    active=True,
                    threshold=1,
                    num_executing_jobs=1,
                    num_assigned_jobs=1,
                    agent_version="agent_version_example",
                    deleted=True,
                ),
            ],
            test_cloud_agents=[
                TestCloudAgentResource(
                    id=1,
                    name="name_example",
                    os="os_example",
                    os_version="os_version_example",
                    browser="browser_example",
                    browser_version="browser_version_example",
                    device_name="device_name_example",
                    app_id="app_id_example",
                    app_group_id="app_group_id_example",
                    app_name="app_name_example",
                    device_id="device_id_example",
                    num_executing_jobs=1,
                    num_assigned_jobs=1,
                    team_id=1,
                    deleted=True,
                    api_key="api_key_example",
                    total_duration=1,
                    headless=True,
                    execution_type="CHROME",
                ),
            ],
            k8s_agents=[
                K8SAgentResource(
                    id=1,
                    name="name_example",
                    certificate_authority="certificate_authority_example",
                    url="url_example",
                    namespace="namespace_example",
                    username="username_example",
                    password="password_example",
                    token="token_example",
                    cluster="cluster_example",
                    region="region_example",
                    access_key="access_key_example",
                    private_access_key="private_access_key_example",
                    team_id=1,
                    api_key="api_key_example",
                    authentication_type="BASIC_AUTH",
                ),
            ],
            circle_ci_agents=[
                CircleCIAgentResource(
                    id=1,
                    name="name_example",
                    url="url_example",
                    username="username_example",
                    token="token_example",
                    project="project_example",
                    vcs_type="vcs_type_example",
                    branch="branch_example",
                    team_id=1,
                    api_key="api_key_example",
                ),
            ],
            test_cloud_test_suite_collection_agents=[
                TestCloudTestSuiteCollectionAgentResource(
                    test_suite_collection_configuration_id=1,
                    test_cloud_agent=TestCloudAgentResource(
                        id=1,
                        name="name_example",
                        os="os_example",
                        os_version="os_version_example",
                        browser="browser_example",
                        browser_version="browser_version_example",
                        device_name="device_name_example",
                        app_id="app_id_example",
                        app_group_id="app_group_id_example",
                        app_name="app_name_example",
                        device_id="device_id_example",
                        num_executing_jobs=1,
                        num_assigned_jobs=1,
                        team_id=1,
                        deleted=True,
                        api_key="api_key_example",
                        total_duration=1,
                        headless=True,
                        execution_type="CHROME",
                    ),
                    updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                ),
            ],
            cloud_type="K8S",
            latest_job=JobResource(
                id=1,
                build_number=1,
                status="QUEUED",
                queued_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                stop_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                test_project=TestProjectResource(
                    id=1,
                    name="name_example",
                    description="description_example",
                    default_test_project=True,
                    upload_file_id=1,
                    project_id=1,
                    team_id=1,
                    created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    latest_job=JobResource(JobResource),
                    upload_file_name="upload_file_name_example",
                    type="KS",
                    git_repository=GitRepositoryResource(
                        id=1,
                        test_project_id=1,
                        name="name_example",
                        repository="repository_example",
                        branch="branch_example",
                        username="username_example",
                        password="password_example",
                        access_key_id="access_key_id_example",
                        secret_access_key="secret_access_key_example",
                        project_id=1,
                        team_id=1,
                        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        description="description_example",
                        vcs_type="GITHUB",
                        should_merge_test_results_for_new_script_repo=True,
                    ),
                    test_suite_collections=[],
                    dirty=True,
                ),
                execution=ExecutionResource(
                    status="PASSED",
                    start_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    end_time=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    duration=1,
                    elapsed_duration=1,
                    total_tests=1,
                    total_passed_tests=1,
                    total_failed_tests=1,
                    total_error_tests=1,
                    total_incomplete_tests=1,
                    total_skipped_tests=1,
                    total_diff_tests=1,
                    total_diff_passed_tests=1,
                    total_diff_failed_tests=1,
                    total_diff_error_tests=1,
                    total_diff_incomplete_tests=1,
                    id=1,
                    project_id=1,
                    project=ProjectResource(
                        id=1,
                        name="name_example",
                        team_id=1,
                        team=TeamResource(
                            id=1,
                            name="name_example",
                            role="OWNER",
                            users=[],
                            organization=OrganizationResource(
                                id=1,
                                name="name_example",
                                role="OWNER",
                                org_feature_flag=OrganizationFeatureFlagResource(
                                    organization_id=1,
                                    sub_domain=True,
                                    strict_domain=True,
                                    sso=True,
                                    whitelist_ip=True,
                                    circle_ci=True,
                                    test_ops_integration=True,
                                ),
                                quota_kse=1,
                                machine_quota_kse=1,
                                quota_unlimited_kse=1,
                                quota_engine=1,
                                machine_quota_engine=1,
                                quota_unlimited_engine=1,
                                used_kse=1,
                                used_unlimited_kse=1,
                                used_engine=1,
                                used_unlimited_engine=1,
                                quota_test_ops=1,
                                used_test_ops=1,
                                number_user=1,
                                quota_floating_engine=1,
                                used_floating_engine=1,
                                can_create_offline_kse=True,
                                can_create_offline_unlimited_kse=True,
                                can_create_offline_re=True,
                                can_create_offline_unlimited_engine=True,
                                subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                subscribed=True,
                                kse_paygo=True,
                                kre_paygo=True,
                                paygo_quota=1,
                                domain="domain_example",
                                subdomain_url="subdomain_url_example",
                                strict_domain=True,
                                logo_url="logo_url_example",
                                saml_sso=True,
                                kre_license=True,
                                most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                account_id=1,
                                test_ops_feature="KSE",
                                platform_feature="KSE",
                                tier="FREE",
                                requested_user_verified=True,
                            ),
                            organization_id=1,
                        ),
                        timezone="timezone_example",
                        status="ARCHIVE",
                    ),
                    build_id=1,
                    order=1,
                    execution_stage="RUNNING",
                    web_url="web_url_example",
                    test_suite_collections=[],
                    execution_test_suite_resources=[],
                    release=ReleaseResource(
                        id=1,
                        name="name_example",
                        start_time=dateutil_parser('1970-01-01').date(),
                        end_time=dateutil_parser('1970-01-01').date(),
                        description="description_example",
                        project_id=1,
                        closed=True,
                        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        external_release=ExternalReleaseResource(
                            id=1,
                            release_id="release_id_example",
                            description="description_example",
                            name="name_example",
                            archived=True,
                            released=True,
                            project_id="project_id_example",
                            external_project=ExternalProjectResource(
                                id=1,
                                external_project_id="external_project_id_example",
                                external_project_key="external_project_key_example",
                                name="name_example",
                            ),
                            web_url="web_url_example",
                            jira_release_status="RELEASED",
                            start_date=dateutil_parser('1970-01-01').date(),
                            release_date=dateutil_parser('1970-01-01').date(),
                        ),
                        release_statistics=ReleaseStatisticsResource(
                            id=1,
                            release=ReleaseResource(ReleaseResource),
                            total_passed=1,
                            total_failed=1,
                            total_execution=1,
                            total_defect=1,
                            total_duration=1,
                        ),
                        builds=[],
                        release_status="NOT_READY",
                    ),
                    build=BuildResource(
                        id=1,
                        project_id=1,
                        project=ProjectResource(
                            id=1,
                            name="name_example",
                            team_id=1,
                            team=TeamResource(
                                id=1,
                                name="name_example",
                                role="OWNER",
                                users=[],
                                organization=OrganizationResource(
                                    id=1,
                                    name="name_example",
                                    role="OWNER",
                                    org_feature_flag=OrganizationFeatureFlagResource(
                                        organization_id=1,
                                        sub_domain=True,
                                        strict_domain=True,
                                        sso=True,
                                        whitelist_ip=True,
                                        circle_ci=True,
                                        test_ops_integration=True,
                                    ),
                                    quota_kse=1,
                                    machine_quota_kse=1,
                                    quota_unlimited_kse=1,
                                    quota_engine=1,
                                    machine_quota_engine=1,
                                    quota_unlimited_engine=1,
                                    used_kse=1,
                                    used_unlimited_kse=1,
                                    used_engine=1,
                                    used_unlimited_engine=1,
                                    quota_test_ops=1,
                                    used_test_ops=1,
                                    number_user=1,
                                    quota_floating_engine=1,
                                    used_floating_engine=1,
                                    can_create_offline_kse=True,
                                    can_create_offline_unlimited_kse=True,
                                    can_create_offline_re=True,
                                    can_create_offline_unlimited_engine=True,
                                    subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    subscribed=True,
                                    kse_paygo=True,
                                    kre_paygo=True,
                                    paygo_quota=1,
                                    domain="domain_example",
                                    subdomain_url="subdomain_url_example",
                                    strict_domain=True,
                                    logo_url="logo_url_example",
                                    saml_sso=True,
                                    kre_license=True,
                                    most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                    account_id=1,
                                    test_ops_feature="KSE",
                                    platform_feature="KSE",
                                    tier="FREE",
                                    requested_user_verified=True,
                                ),
                                organization_id=1,
                            ),
                            timezone="timezone_example",
                            status="ARCHIVE",
                        ),
                        release_id=1,
                        release=ReleaseResource(
                            id=1,
                            name="name_example",
                            start_time=dateutil_parser('1970-01-01').date(),
                            end_time=dateutil_parser('1970-01-01').date(),
                            description="description_example",
                            project_id=1,
                            closed=True,
                            created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            external_release=ExternalReleaseResource(
                                id=1,
                                release_id="release_id_example",
                                description="description_example",
                                name="name_example",
                                archived=True,
                                released=True,
                                project_id="project_id_example",
                                external_project=ExternalProjectResource(
                                    id=1,
                                    external_project_id="external_project_id_example",
                                    external_project_key="external_project_key_example",
                                    name="name_example",
                                ),
                                web_url="web_url_example",
                                jira_release_status="RELEASED",
                                start_date=dateutil_parser('1970-01-01').date(),
                                release_date=dateutil_parser('1970-01-01').date(),
                            ),
                            release_statistics=ReleaseStatisticsResource(
                                id=1,
                                release=ReleaseResource(ReleaseResource),
                                total_passed=1,
                                total_failed=1,
                                total_execution=1,
                                total_defect=1,
                                total_duration=1,
                            ),
                            builds=[],
                            release_status="NOT_READY",
                        ),
                        build_statistics=BuildStatisticsResource(
                            id=1,
                            build=BuildResource(BuildResource),
                            total_execution=1,
                            total_passed=1,
                            total_failed=1,
                        ),
                        name="name_example",
                        description="description_example",
                        date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    ),
                    has_comment=True,
                    user=UserResource(
                        id=1,
                        email="email_example",
                        first_name="first_name_example",
                        last_name="last_name_example",
                        password="password_example",
                        inviting_url="inviting_url_example",
                        avatar="avatar_example",
                        configs=ConfigResource(
                            web_socket_url="web_socket_url_example",
                            store_url="store_url_example",
                            profiles=[],
                            stripe_public_api="stripe_public_api_example",
                            build_version="build_version_example",
                            commit_id="commit_id_example",
                            sentry_dsn="sentry_dsn_example",
                            sentry_env="sentry_env_example",
                            sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                            server_url="server_url_example",
                            io_server_url="io_server_url_example",
                            proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                            max_execution_comparison=1,
                            max_execution_download=1,
                            agent_download_urls={},
                            proxy_tunnel_download_urls={},
                            report_uploader_download_url="report_uploader_download_url_example",
                            report_uploader_latest_version="report_uploader_latest_version_example",
                            sub_domain_pattern="sub_domain_pattern_example",
                            cancellation_survey_url="cancellation_survey_url_example",
                            launch_darkly_client_id="launch_darkly_client_id_example",
                            launch_darkly_default_user="launch_darkly_default_user_example",
                            launch_darkly_prefix="launch_darkly_prefix_example",
                            min_test_execution_ordered=1,
                            user_flow_token="user_flow_token_example",
                            demo_project_url="demo_project_url_example",
                            advanced_feature_enabled=True,
                            using_sub_domain=True,
                            test_ops_subscription_enabled=True,
                            frameworks_integration_enabled=True,
                        ),
                        projects=[],
                        teams=[],
                        organizations=[],
                        organization_feature=[],
                        trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        system_role="USER",
                        survey_status="NOT_SUBMITTED",
                        session_timeout=1,
                        business_user=True,
                        can_create_offline_kse=True,
                        can_create_offline_re=True,
                        saml_sso=True,
                        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        full_name="full_name_example",
                    ),
                    session_id="session_id_example",
                    build_label="build_label_example",
                    build_url="build_url_example",
                    type="KATALON",
                    jobs=[],
                    use_test_cloud_tunnel=True,
                    getk_eyes_execution=KEyesExecutionResource(
                        id=1,
                        status="RUNNING",
                        execution=ExecutionResource(ExecutionResource),
                        total_checkpoints=1,
                        passed_checkpoints=1,
                        failed_checkpoints=1,
                        unresolved_checkpoints=1,
                        unsaved=True,
                        baseline_collection=BaselineCollectionResource(
                            id=1,
                            version=1,
                            baselines=[],
                            number_of_baselines=1,
                            updated_by=UserResource(
                                id=1,
                                email="email_example",
                                first_name="first_name_example",
                                last_name="last_name_example",
                                password="password_example",
                                inviting_url="inviting_url_example",
                                avatar="avatar_example",
                                configs=ConfigResource(
                                    web_socket_url="web_socket_url_example",
                                    store_url="store_url_example",
                                    profiles=[],
                                    stripe_public_api="stripe_public_api_example",
                                    build_version="build_version_example",
                                    commit_id="commit_id_example",
                                    sentry_dsn="sentry_dsn_example",
                                    sentry_env="sentry_env_example",
                                    sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                                    server_url="server_url_example",
                                    io_server_url="io_server_url_example",
                                    proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                                    max_execution_comparison=1,
                                    max_execution_download=1,
                                    agent_download_urls={},
                                    proxy_tunnel_download_urls={},
                                    report_uploader_download_url="report_uploader_download_url_example",
                                    report_uploader_latest_version="report_uploader_latest_version_example",
                                    sub_domain_pattern="sub_domain_pattern_example",
                                    cancellation_survey_url="cancellation_survey_url_example",
                                    launch_darkly_client_id="launch_darkly_client_id_example",
                                    launch_darkly_default_user="launch_darkly_default_user_example",
                                    launch_darkly_prefix="launch_darkly_prefix_example",
                                    min_test_execution_ordered=1,
                                    user_flow_token="user_flow_token_example",
                                    demo_project_url="demo_project_url_example",
                                    advanced_feature_enabled=True,
                                    using_sub_domain=True,
                                    test_ops_subscription_enabled=True,
                                    frameworks_integration_enabled=True,
                                ),
                                projects=[],
                                teams=[],
                                organizations=[],
                                organization_feature=[],
                                trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                system_role="USER",
                                survey_status="NOT_SUBMITTED",
                                session_timeout=1,
                                business_user=True,
                                can_create_offline_kse=True,
                                can_create_offline_re=True,
                                saml_sso=True,
                                created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                full_name="full_name_example",
                            ),
                            baseline_collection_group=BaselineCollectionGroupResource(
                                id=1,
                                name="name_example",
                                latest_version=BaselineCollectionResource(BaselineCollectionResource),
                                run_configurations=[],
                                updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                                order=1,
                                last_run=KEyesExecutionResource(KEyesExecutionResource),
                            ),
                            unsaved=True,
                            default_method="PIXEL",
                            draft_default_method="PIXEL",
                            threshold=1,
                            draft_threshold=1,
                            create_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        ),
                    ),
                    data_type="USER_DATA",
                ),
                agent=AgentResource(
                    id=1,
                    name="name_example",
                    ip="ip_example",
                    uuid="uuid_example",
                    last_ping=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    os="os_example",
                    team_id=1,
                    hostname="hostname_example",
                    active=True,
                    threshold=1,
                    num_executing_jobs=1,
                    num_assigned_jobs=1,
                    agent_version="agent_version_example",
                    deleted=True,
                ),
                test_cloud_agent=TestCloudAgentResource(
                    id=1,
                    name="name_example",
                    os="os_example",
                    os_version="os_version_example",
                    browser="browser_example",
                    browser_version="browser_version_example",
                    device_name="device_name_example",
                    app_id="app_id_example",
                    app_group_id="app_group_id_example",
                    app_name="app_name_example",
                    device_id="device_id_example",
                    num_executing_jobs=1,
                    num_assigned_jobs=1,
                    team_id=1,
                    deleted=True,
                    api_key="api_key_example",
                    total_duration=1,
                    headless=True,
                    execution_type="CHROME",
                ),
                k8s_agent=K8SAgentResource(
                    id=1,
                    name="name_example",
                    certificate_authority="certificate_authority_example",
                    url="url_example",
                    namespace="namespace_example",
                    username="username_example",
                    password="password_example",
                    token="token_example",
                    cluster="cluster_example",
                    region="region_example",
                    access_key="access_key_example",
                    private_access_key="private_access_key_example",
                    team_id=1,
                    api_key="api_key_example",
                    authentication_type="BASIC_AUTH",
                ),
                circle_ci_agent=CircleCIAgentResource(
                    id=1,
                    name="name_example",
                    url="url_example",
                    username="username_example",
                    token="token_example",
                    project="project_example",
                    vcs_type="vcs_type_example",
                    branch="branch_example",
                    team_id=1,
                    api_key="api_key_example",
                ),
                run_configuration=RunConfigurationResource(RunConfigurationResource),
                order=1,
                parameter=TriggerBuildParameter(
                    download_url="download_url_example",
                    command="command_example",
                    environment_variables=[],
                    session_id="session_id_example",
                    ks_version="ks_version_example",
                    ks_location="ks_location_example",
                    config_type="TSC",
                    type="KS",
                    git_repository_resource=GitRepositoryResource(
                        id=1,
                        test_project_id=1,
                        name="name_example",
                        repository="repository_example",
                        branch="branch_example",
                        username="username_example",
                        password="password_example",
                        access_key_id="access_key_id_example",
                        secret_access_key="secret_access_key_example",
                        project_id=1,
                        team_id=1,
                        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                        description="description_example",
                        vcs_type="GITHUB",
                        should_merge_test_results_for_new_script_repo=True,
                    ),
                    test_ops_download_url="test_ops_download_url_example",
                    extra_files=[],
                    organization_id=1,
                ),
                trigger_by="MANUAL",
                duration=1,
                trigger_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                user=UserResource(
                    id=1,
                    email="email_example",
                    first_name="first_name_example",
                    last_name="last_name_example",
                    password="password_example",
                    inviting_url="inviting_url_example",
                    avatar="avatar_example",
                    configs=ConfigResource(
                        web_socket_url="web_socket_url_example",
                        store_url="store_url_example",
                        profiles=[],
                        stripe_public_api="stripe_public_api_example",
                        build_version="build_version_example",
                        commit_id="commit_id_example",
                        sentry_dsn="sentry_dsn_example",
                        sentry_env="sentry_env_example",
                        sentry_traces_sample_rate="sentry_traces_sample_rate_example",
                        server_url="server_url_example",
                        io_server_url="io_server_url_example",
                        proxy_tunnel_server_url="proxy_tunnel_server_url_example",
                        max_execution_comparison=1,
                        max_execution_download=1,
                        agent_download_urls={},
                        proxy_tunnel_download_urls={},
                        report_uploader_download_url="report_uploader_download_url_example",
                        report_uploader_latest_version="report_uploader_latest_version_example",
                        sub_domain_pattern="sub_domain_pattern_example",
                        cancellation_survey_url="cancellation_survey_url_example",
                        launch_darkly_client_id="launch_darkly_client_id_example",
                        launch_darkly_default_user="launch_darkly_default_user_example",
                        launch_darkly_prefix="launch_darkly_prefix_example",
                        min_test_execution_ordered=1,
                        user_flow_token="user_flow_token_example",
                        demo_project_url="demo_project_url_example",
                        advanced_feature_enabled=True,
                        using_sub_domain=True,
                        test_ops_subscription_enabled=True,
                        frameworks_integration_enabled=True,
                    ),
                    projects=[],
                    teams=[],
                    organizations=[],
                    organization_feature=[],
                    trial_expiration_date=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    system_role="USER",
                    survey_status="NOT_SUBMITTED",
                    session_timeout=1,
                    business_user=True,
                    can_create_offline_kse=True,
                    can_create_offline_re=True,
                    saml_sso=True,
                    created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    full_name="full_name_example",
                ),
                scheduler=SchedulerResource(SchedulerResource),
                project=ProjectResource(
                    id=1,
                    name="name_example",
                    team_id=1,
                    team=TeamResource(
                        id=1,
                        name="name_example",
                        role="OWNER",
                        users=[],
                        organization=OrganizationResource(
                            id=1,
                            name="name_example",
                            role="OWNER",
                            org_feature_flag=OrganizationFeatureFlagResource(
                                organization_id=1,
                                sub_domain=True,
                                strict_domain=True,
                                sso=True,
                                whitelist_ip=True,
                                circle_ci=True,
                                test_ops_integration=True,
                            ),
                            quota_kse=1,
                            machine_quota_kse=1,
                            quota_unlimited_kse=1,
                            quota_engine=1,
                            machine_quota_engine=1,
                            quota_unlimited_engine=1,
                            used_kse=1,
                            used_unlimited_kse=1,
                            used_engine=1,
                            used_unlimited_engine=1,
                            quota_test_ops=1,
                            used_test_ops=1,
                            number_user=1,
                            quota_floating_engine=1,
                            used_floating_engine=1,
                            can_create_offline_kse=True,
                            can_create_offline_unlimited_kse=True,
                            can_create_offline_re=True,
                            can_create_offline_unlimited_engine=True,
                            subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscribed=True,
                            kse_paygo=True,
                            kre_paygo=True,
                            paygo_quota=1,
                            domain="domain_example",
                            subdomain_url="subdomain_url_example",
                            strict_domain=True,
                            logo_url="logo_url_example",
                            saml_sso=True,
                            kre_license=True,
                            most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            account_id=1,
                            test_ops_feature="KSE",
                            platform_feature="KSE",
                            tier="FREE",
                            requested_user_verified=True,
                        ),
                        organization_id=1,
                    ),
                    timezone="timezone_example",
                    status="ARCHIVE",
                ),
                process_id=1,
                node_status="PENDING_CANCELED",
                run_configuration_id=1,
            ),
            generic_command="generic_command_example",
            ks_version="ks_version_example",
            ks_location="ks_location_example",
            next_run_scheduler=SchedulerResource(SchedulerResource),
            release=ReleaseResource(
                id=1,
                name="name_example",
                start_time=dateutil_parser('1970-01-01').date(),
                end_time=dateutil_parser('1970-01-01').date(),
                description="description_example",
                project_id=1,
                closed=True,
                created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                external_release=ExternalReleaseResource(
                    id=1,
                    release_id="release_id_example",
                    description="description_example",
                    name="name_example",
                    archived=True,
                    released=True,
                    project_id="project_id_example",
                    external_project=ExternalProjectResource(
                        id=1,
                        external_project_id="external_project_id_example",
                        external_project_key="external_project_key_example",
                        name="name_example",
                    ),
                    web_url="web_url_example",
                    jira_release_status="RELEASED",
                    start_date=dateutil_parser('1970-01-01').date(),
                    release_date=dateutil_parser('1970-01-01').date(),
                ),
                release_statistics=ReleaseStatisticsResource(
                    id=1,
                    release=ReleaseResource(ReleaseResource),
                    total_passed=1,
                    total_failed=1,
                    total_execution=1,
                    total_defect=1,
                    total_duration=1,
                ),
                builds=[],
                release_status="NOT_READY",
            ),
            build=BuildResource(
                id=1,
                project_id=1,
                project=ProjectResource(
                    id=1,
                    name="name_example",
                    team_id=1,
                    team=TeamResource(
                        id=1,
                        name="name_example",
                        role="OWNER",
                        users=[],
                        organization=OrganizationResource(
                            id=1,
                            name="name_example",
                            role="OWNER",
                            org_feature_flag=OrganizationFeatureFlagResource(
                                organization_id=1,
                                sub_domain=True,
                                strict_domain=True,
                                sso=True,
                                whitelist_ip=True,
                                circle_ci=True,
                                test_ops_integration=True,
                            ),
                            quota_kse=1,
                            machine_quota_kse=1,
                            quota_unlimited_kse=1,
                            quota_engine=1,
                            machine_quota_engine=1,
                            quota_unlimited_engine=1,
                            used_kse=1,
                            used_unlimited_kse=1,
                            used_engine=1,
                            used_unlimited_engine=1,
                            quota_test_ops=1,
                            used_test_ops=1,
                            number_user=1,
                            quota_floating_engine=1,
                            used_floating_engine=1,
                            can_create_offline_kse=True,
                            can_create_offline_unlimited_kse=True,
                            can_create_offline_re=True,
                            can_create_offline_unlimited_engine=True,
                            subscription_expiry_date_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_unlimited_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_unlimited_kse=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_floating_engine=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscription_expiry_date_test_ops=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            subscribed=True,
                            kse_paygo=True,
                            kre_paygo=True,
                            paygo_quota=1,
                            domain="domain_example",
                            subdomain_url="subdomain_url_example",
                            strict_domain=True,
                            logo_url="logo_url_example",
                            saml_sso=True,
                            kre_license=True,
                            most_recent_project_accessed_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                            account_id=1,
                            test_ops_feature="KSE",
                            platform_feature="KSE",
                            tier="FREE",
                            requested_user_verified=True,
                        ),
                        organization_id=1,
                    ),
                    timezone="timezone_example",
                    status="ARCHIVE",
                ),
                release_id=1,
                release=ReleaseResource(
                    id=1,
                    name="name_example",
                    start_time=dateutil_parser('1970-01-01').date(),
                    end_time=dateutil_parser('1970-01-01').date(),
                    description="description_example",
                    project_id=1,
                    closed=True,
                    created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
                    external_release=ExternalReleaseResource(
                        id=1,
                        release_id="release_id_example",
                        description="description_example",
                        name="name_example",
                        archived=True,
                        released=True,
                        project_id="project_id_example",
                        external_project=ExternalProjectResource(
                            id=1,
                            external_project_id="external_project_id_example",
                            external_project_key="external_project_key_example",
                            name="name_example",
                        ),
                        web_url="web_url_example",
                        jira_release_status="RELEASED",
                        start_date=dateutil_parser('1970-01-01').date(),
                        release_date=dateutil_parser('1970-01-01').date(),
                    ),
                    release_statistics=ReleaseStatisticsResource(
                        id=1,
                        release=ReleaseResource(ReleaseResource),
                        total_passed=1,
                        total_failed=1,
                        total_execution=1,
                        total_defect=1,
                        total_duration=1,
                    ),
                    builds=[],
                    release_status="NOT_READY",
                ),
                build_statistics=BuildStatisticsResource(
                    id=1,
                    build=BuildResource(BuildResource),
                    total_execution=1,
                    total_passed=1,
                    total_failed=1,
                ),
                name="name_example",
                description="description_example",
                date=dateutil_parser('1970-01-01T00:00:00.00Z'),
            ),
            execution_mode="SEQUENTIAL",
            enabled_kobiton_integration=True,
            enabled_test_cloud_tunnel=True,
            trigger_mode="TESTOPS_SCHEDULER",
            browser_type="CHROME",
            xray_import_report_type="PUSH_MANUALLY",
            external_test_plan_id="external_test_plan_id_example",
            custom_field_options=[],
            tags=[
                TagResource(
                    id=1,
                    name="name_example",
                    project_id=1,
                    organization_id=1,
                ),
            ],
        ),
        exceeded_limit_time=True,
    ) # SchedulerResource | 

    # example passing only required values which don't have defaults set
    try:
        # Updates a schedule detail. Returns the updated schedule detail.
        api_response = api_instance.update1(id, scheduler_id, scheduler_resource)
        pprint(api_response)
    except testops_api.ApiException as e:
        print("Exception when calling TestProjectApi->update1: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**|  |
 **scheduler_id** | **int**|  |
 **scheduler_resource** | [**SchedulerResource**](SchedulerResource.md)|  |

### Return type

[**SchedulerResource**](SchedulerResource.md)

### Authorization

[basicScheme](../README.md#basicScheme)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: */*

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_git_repo**
> GitRepositoryResource update_git_repo(git_repository_resource)

Updates a Git Test Project detail. Returns the updated Git Test Project detail.

### Example

* Basic Authentication (basicScheme):
```python
import time
import testops_api
from testops_api.api import test_project_api
from testops_api.model.git_repository_resource import GitRepositoryResource
from pprint import pprint
# Defining the host is optional and defaults to http://localhost:8443
# See configuration.py for a list of all supported configuration parameters.
configuration = testops_api.Configuration(
    host = "http://localhost:8443"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicScheme
configuration = testops_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Enter a context with an instance of the API client
with testops_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = test_project_api.TestProjectApi(api_client)
    git_repository_resource = GitRepositoryResource(
        id=1,
        test_project_id=1,
        name="name_example",
        repository="repository_example",
        branch="branch_example",
        username="username_example",
        password="password_example",
        access_key_id="access_key_id_example",
        secret_access_key="secret_access_key_example",
        project_id=1,
        team_id=1,
        created_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
        updated_at=dateutil_parser('1970-01-01T00:00:00.00Z'),
        description="description_example",
        vcs_type="GITHUB",
        should_merge_test_results_for_new_script_repo=True,
    ) # GitRepositoryResource | 

    # example passing only required values which don't have defaults set
    try:
        # Updates a Git Test Project detail. Returns the updated Git Test Project detail.
        api_response = api_instance.update_git_repo(git_repository_resource)
        pprint(api_response)
    except testops_api.ApiException as e:
        print("Exception when calling TestProjectApi->update_git_repo: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **git_repository_resource** | [**GitRepositoryResource**](GitRepositoryResource.md)|  |

### Return type

[**GitRepositoryResource**](GitRepositoryResource.md)

### Authorization

[basicScheme](../README.md#basicScheme)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: */*

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_script_repo**
> TestProjectResource update_script_repo(id, batch, folder_path, file_name, uploaded_path)

Update a Test Project package. Returns the updated Test Project detail. Use to update script repository

### Example

* Basic Authentication (basicScheme):
```python
import time
import testops_api
from testops_api.api import test_project_api
from testops_api.model.test_project_resource import TestProjectResource
from pprint import pprint
# Defining the host is optional and defaults to http://localhost:8443
# See configuration.py for a list of all supported configuration parameters.
configuration = testops_api.Configuration(
    host = "http://localhost:8443"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicScheme
configuration = testops_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Enter a context with an instance of the API client
with testops_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = test_project_api.TestProjectApi(api_client)
    id = 1 # int | 
    batch = "batch_example" # str | 
    folder_path = "folderPath_example" # str | 
    file_name = "fileName_example" # str | 
    uploaded_path = "uploadedPath_example" # str | 

    # example passing only required values which don't have defaults set
    try:
        # Update a Test Project package. Returns the updated Test Project detail. Use to update script repository
        api_response = api_instance.update_script_repo(id, batch, folder_path, file_name, uploaded_path)
        pprint(api_response)
    except testops_api.ApiException as e:
        print("Exception when calling TestProjectApi->update_script_repo: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**|  |
 **batch** | **str**|  |
 **folder_path** | **str**|  |
 **file_name** | **str**|  |
 **uploaded_path** | **str**|  |

### Return type

[**TestProjectResource**](TestProjectResource.md)

### Authorization

[basicScheme](../README.md#basicScheme)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **upload_script_repo**
> TestProjectResource upload_script_repo(name, project_id, batch, folder_path, file_name, uploaded_path)

Creates a new Test Project. Returns the created Test Project. Use to create script repository

### Example

* Basic Authentication (basicScheme):
```python
import time
import testops_api
from testops_api.api import test_project_api
from testops_api.model.test_project_resource import TestProjectResource
from pprint import pprint
# Defining the host is optional and defaults to http://localhost:8443
# See configuration.py for a list of all supported configuration parameters.
configuration = testops_api.Configuration(
    host = "http://localhost:8443"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicScheme
configuration = testops_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Enter a context with an instance of the API client
with testops_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = test_project_api.TestProjectApi(api_client)
    name = "name_example" # str | 
    project_id = "projectId_example" # str | 
    batch = "batch_example" # str | 
    folder_path = "folderPath_example" # str | 
    file_name = "fileName_example" # str | 
    uploaded_path = "uploadedPath_example" # str | 
    description = "description_example" # str |  (optional)
    default_test_project = True # bool |  (optional)

    # example passing only required values which don't have defaults set
    try:
        # Creates a new Test Project. Returns the created Test Project. Use to create script repository
        api_response = api_instance.upload_script_repo(name, project_id, batch, folder_path, file_name, uploaded_path)
        pprint(api_response)
    except testops_api.ApiException as e:
        print("Exception when calling TestProjectApi->upload_script_repo: %s\n" % e)

    # example passing only required values which don't have defaults set
    # and optional values
    try:
        # Creates a new Test Project. Returns the created Test Project. Use to create script repository
        api_response = api_instance.upload_script_repo(name, project_id, batch, folder_path, file_name, uploaded_path, description=description, default_test_project=default_test_project)
        pprint(api_response)
    except testops_api.ApiException as e:
        print("Exception when calling TestProjectApi->upload_script_repo: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **name** | **str**|  |
 **project_id** | **str**|  |
 **batch** | **str**|  |
 **folder_path** | **str**|  |
 **file_name** | **str**|  |
 **uploaded_path** | **str**|  |
 **description** | **str**|  | [optional]
 **default_test_project** | **bool**|  | [optional]

### Return type

[**TestProjectResource**](TestProjectResource.md)

### Authorization

[basicScheme](../README.md#basicScheme)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

